@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../../freediams/plugins/coreplugin/appaboutpage.cpp" line="46"/>
-        <source>&lt;p align=center&gt;&lt;b&gt;Welcome to FreeDiams&lt;/b&gt;&lt;br /&gt;(C) 2008-%1 by Eric MAEKER, MD&lt;/p&gt;&lt;p align=left&gt;This application is a stable release but can still contains some bugs.&lt;br /&gt;This software is release without any warranty and only for test purposal.&lt;br /&gt;Please refer to web site for more informations.&lt;br /&gt;&lt;a href=&quot;%2&quot;&gt;Web site&lt;/a&gt;&lt;/p&gt;</source>
+        <source>&lt;p align=center&gt;&lt;b&gt;Welcome to FreeDiams&lt;/b&gt;&lt;br /&gt;(C) 2008-%1 by Eric MAEKER, MD&lt;/p&gt;&lt;p align=left&gt;This application is a stable release but can still contains some bugs.&lt;br /&gt;This software is release without any warranty and only for test purposal.&lt;br /&gt;Please refer to web site for more information.&lt;br /&gt;&lt;a href=&quot;%2&quot;&gt;Web site&lt;/a&gt;&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -177,7 +177,7 @@
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="43"/>
-        <source>4. Build informations</source>
+        <source>4. Build information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -228,24 +228,24 @@
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="101"/>
-        <source>Sending debugging informations to dev team</source>
+        <source>Sending debugging information to dev team</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="102"/>
-        <source>Trying to send informations to dev team.
+        <source>Trying to send information to dev team.
 Using Url : %1 
 Please wait...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="123"/>
-        <source>Debugging informations correctly sent.</source>
+        <source>Debugging information correctly sent.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="126"/>
-        <source>Debugging informations correctly send to dev team.
+        <source>Debugging information correctly send to dev team.
 Using Url : %1 
 %2</source>
         <translation type="unfinished"></translation>
@@ -409,11 +409,6 @@ Using Url : %1
         <source>Value</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="915"/>
-        <source>System informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../plugins/coreplugin/settings.cpp" line="917"/>
         <source>Operating System</source>
@@ -567,6 +562,11 @@ Using Url : %1
         <source>DocumentationPath</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="915"/>
+        <source>System information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../plugins/coreplugin/settings.cpp" line="933"/>
         <source>SVN version</source>
@@ -808,12 +808,12 @@ Using Url : %1
 <context>
     <name>Core::SettingsDialog</name>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="62"/>
+        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="65"/>
         <source>Apply all changes (all pages)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="63"/>
+        <location filename="../../plugins/coreplugin/dialogs/settingsdialog.cpp" line="66"/>
         <source>Reset to default the current page</source>
         <translation type="unfinished"></translation>
     </message>
