@@ -4,123 +4,123 @@
 <context>
     <name>MainWin::Internal::MainWindow</name>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="115"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="115"/>
         <source>DOB</source>
         <translation>DDN</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="107"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="107"/>
         <source>Patient information</source>
         <translation>Informations concernant le patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="128"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="128"/>
         <source>yyyy/MM/dd</source>
         <comment>Format de date</comment>
         <translation>dd/MM/yyyy</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="135"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="135"/>
         <source>Weight</source>
         <translation>Poids</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="156"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="156"/>
         <source>Kg</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="161"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="161"/>
         <source>lbs</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="190"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="190"/>
         <source>cm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="195"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="195"/>
         <source>m</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="200"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="200"/>
         <source>inches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="208"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="208"/>
         <source>Gender</source>
         <translation>Sexe</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="169"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="169"/>
         <source>Height</source>
         <translation>Taille</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="20"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="20"/>
         <source>Patient Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="27"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="27"/>
         <source>Family or occidental last names</source>
         <translation>Nom(s) de famille</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="34"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="34"/>
         <source>Firstname</source>
         <translation>Prénom(s)</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="41"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="41"/>
         <source>Given names</source>
         <translation>Prénom(s)</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="222"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="222"/>
         <source>Creatinine clearance</source>
         <translation>Clearance de la créatinine</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="243"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="243"/>
         <source>mL/min</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="248"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="248"/>
         <source>mL/sec</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="256"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="256"/>
         <source>Creatinine</source>
         <translation>Créatinine</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="277"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="277"/>
         <source>mg/L</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="282"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="282"/>
         <source>mg/dL</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="287"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="287"/>
         <source>mmol/L</source>
         <translation></translation>
     </message>
     <message utf8="true">
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="292"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="292"/>
         <source>µmol/L</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.ui" line="304"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="304"/>
         <source>Drugs precautions</source>
         <translation>Précautions</translation>
     </message>
@@ -128,80 +128,75 @@
 <context>
     <name>MainWin::MainWindow</name>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="234"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="245"/>
         <source>Creating Main Window</source>
         <translation>Création de la fenêtre principale</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="331"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="342"/>
         <source>Transmitting posologies...</source>
         <translation>Transmition des posologies...</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="356"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="367"/>
         <source>Connected to</source>
         <translation>Connecté à</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="371"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="382"/>
         <source>Initializing drugs database</source>
         <translation>Initialisation de la base de données thérapeutique</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="377"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="388"/>
         <source>Entering selection mode</source>
         <translation>Entrée dans le mode de sélection seulement</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="386"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="397"/>
         <source>Reading exchange file...</source>
         <translation>Ouverture du fichier d&apos;échange...</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="718"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="730"/>
         <source>Save actual prescription ?</source>
         <translation>Sauvegarder la prescription actuelle ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="719"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="731"/>
         <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
         <translation>La prescription actuelle n&apos;est pas vide. Voulez-vous la sauvegarder avant d&apos;en créer une nouvelle ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="821"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="835"/>
         <source>Opening a prescription : merge or replace ?</source>
         <translation>Ouverture d&apos;une prescription : fusionner ou remplacer ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="822"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="836"/>
         <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
         <translation>Il existe déjà une prescription dans l&apos;éditeur, voulez-vous la remplacer ou ajouter la nouvelle prescription ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="837"/>
         <source>Replace prescription</source>
         <translation>Remplacer la prescription</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="823"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="837"/>
         <source>Add to prescription</source>
         <translation>Ajouter à la prescription</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="824"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="838"/>
         <source>Open a prescription</source>
         <translation>Ouvrerture d&apos;une prescription</translation>
     </message>
-    <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="865"/>
-        <source>Toggle patient&apos;s precautions</source>
-        <translation>Afficher/cacher les précautions</translation>
-    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/mainwindow.cpp" line="213"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="223"/>
         <source>Preparing dosage transmission</source>
         <translation>Préparation de la transmission des posologies</translation>
     </message>
@@ -209,12 +204,12 @@
 <context>
     <name>diMedinTux</name>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="91"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="92"/>
         <source>Automatic configuration for MedinTux usage</source>
         <translation>Configuration automatique pour l&apos;utilisation avec MedinTux</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="92"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="93"/>
         <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
 You can create a new prescription by clicking this menu.
 Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
@@ -223,66 +218,121 @@ Vous pourrez créer de nouvelles prescriptions depuis ce menu.
 Attention, assurez-vous de reconfigurer MedinTux grâce à cet assistant à chaque fois que MedinTux ou FreeDiams changera de répertoire.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="97"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="98"/>
         <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
 Please refer to the documentation.</source>
         <translation>Cet assistant va essayer de trouver votre configuration de MedinTux. S&apos;il ne trouve pas, vous devrez l&apos;en informer. Ensuite, cet assistant configurera un nouveau menu utilisateur et ajoutera une liste dans vos listes par défauts des prescriptions.
 Merci de prendre connaissance de la documentation.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="112"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="113"/>
         <source>Please select Manager&apos;s binary path</source>
         <translation>Veuillez sélectionner le répertoire contenant le binaire de Manager</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="123"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="117"/>
+        <source>Unable to find Manager binary path.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="126"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="128"/>
         <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
         <translation>Impossible de configurer MedinTux : le répertoire des ressources n&apos;existe pas. Chemin vers DrTux : %1</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="128"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="132"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="134"/>
         <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
         <translation>Impossible de configurer MedinTux : le menu utilisateur n&apos;existe pas et ne peut pas être créer. Chemin vers DrTux : %1</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="140"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="145"/>
         <source>Can not deleted old DrugsInteractions menu entry %1</source>
         <translation>Impossible d&apos;effacer l&apos;ancienne entrée de DrugsInteractions du menu %1</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="147"/>
-        <source>Unable to configure MedinTux : DrugsInteractions menu does not exists and can not be created. Path to DrTux binary : %1</source>
-        <translation>Impossible de configurer MedinTux : le menu de FreeDiams n&apos;existe pas et ne peut pas être créé. Chemin vers Drux : %1</translation>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="152"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="154"/>
+        <source>Unable to configure MedinTux: FreeDiams menu does not exists and can not be created. Path to DrTux binary : %1</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="224"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="181"/>
+        <source>Unable to configure MedinTux user menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="184"/>
+        <source>MedinTux user&apos;s menu correctly updated.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="197"/>
+        <source>Select path to the Prescription Menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="199"/>
+        <source>Can not find menu list directory. Asking user.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="204"/>
+        <source>Using %1 as prescription menu directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="219"/>
+        <source>Prescription menu correctly updated.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="228"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="230"/>
+        <source>Unable to find the prescription list directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="236"/>
+        <source>MedinTux cache has been correctly cleared.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="238"/>
+        <source>Unable to clear the MedinTux cache.
+You have to do this by hand.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="243"/>
         <source>DrTux is now fully configured for %1.</source>
         <translation>DrTux est maintenant configuré pour %1.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="225"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="244"/>
         <source>You can run %1 using DrTux User&apos;s Menu.</source>
         <translation>Vous pouvez utiliser %1 grâce au menu utilisateur de DrTux.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="226"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="245"/>
         <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
 %1</source>
         <translation>Si vous rencontrez des difficultés avec l&apos;intégration à DrTux, veuillez vous référer à la documentation des deux applications.
 %1</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="228"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="247"/>
         <source>DrTux is not correctly configured.</source>
         <translation>DrTux n&apos;est pas correctement configuré.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="229"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="248"/>
         <source>This assitant encountered errors during its process.</source>
         <translation>Cet assistant a rencontré des erreurs pendant la configuration.</translation>
     </message>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="230"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="249"/>
         <source>This is the log of the processes 
 %1</source>
         <translation>Voici les messages des processus 
@@ -292,7 +342,7 @@ Merci de prendre connaissance de la documentation.</translation>
 <context>
     <name>diMedintux</name>
     <message>
-        <location filename="../../plugins/fdmainwindowplugin/medintux.cpp" line="50"/>
+        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="51"/>
         <source>Prescribe with FreeDiams</source>
         <translation>Prescrire avec FreeDiams</translation>
     </message>
