@@ -9,7 +9,7 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="138"/>
+        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="135"/>
         <source>Name, Secondname - firstname</source>
         <translation></translation>
     </message>
@@ -30,42 +30,42 @@
 <context>
     <name>Patients</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="53"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="39"/>
         <source>Search by Name</source>
         <translation>Chercher par nom</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="54"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="40"/>
         <source>Search by Firstname</source>
         <translation>Chercher par prénom</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="55"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="41"/>
         <source>Search by Name and Firstname</source>
         <translation>Chercher par nom et prénom</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="56"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="42"/>
         <source>Search by Date Of Birth</source>
         <translation>Chercher par date de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="58"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="44"/>
         <source>Type the name or second name of the patient</source>
         <translation>Saisissez le nom de naissance ou marital du patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="59"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="45"/>
         <source>Type the firstname of the patient</source>
         <translation>Saisissez le prénom du patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="60"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="46"/>
         <source>Type the name or second name followed by ; and the firstname</source>
         <translation>Saisissez le nom de naissance ou marital suivi du prénom du patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="61"/>
+        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="47"/>
         <source>Type the date of birth (yyyy/MM/dd)</source>
         <translation>Saisissez la date de naissance (yyyy/MM/dd)</translation>
     </message>
@@ -73,7 +73,7 @@
 <context>
     <name>Patients::IdentityPage</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="104"/>
+        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="101"/>
         <source>Please enter the patient&apos;s identity.</source>
         <translation>Veuillez saisir l&apos;identité du patient.</translation>
     </message>
@@ -81,72 +81,72 @@
 <context>
     <name>Patients::IdentityWidget</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="191"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="201"/>
         <source>born on</source>
         <translation>né(e) le</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="204"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="215"/>
         <source>You must specify a birthname.</source>
         <translation>Vous devez spécifier un nom de naissance.</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="205"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
         <source>You can not create a patient without a birthname</source>
         <translation>Vous ne pouvez pas créer un patient sans nom de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="206"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
         <source>No birthname</source>
         <translation>Pas de nom de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="210"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="221"/>
         <source>You must specify a firstname.</source>
         <translation>Vous devez spécifier un prénom.</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="211"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
         <source>You can not create a patient without a firstname</source>
         <translation>Vous ne pouvez pas créer un patient sans prénom</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="212"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
         <source>No firstname</source>
         <translation>Pas de prénom</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="227"/>
         <source>You must specify a date of birth.</source>
         <translation>Vous devez spécifier une date de naissance.</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="228"/>
         <source>You can not create a patient without a date of birth</source>
         <translation>Vous ne pouvez pas créer un patient sans date de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="218"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="229"/>
         <source>No date of birth</source>
         <translation>Pas de date de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="233"/>
         <source>You must specify a gender.</source>
         <translation>Vous devez spécifier un sexe.</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="234"/>
         <source>You can not create a patient without a gender</source>
         <translation>Vous ne pouvez pas créer un patient sans sexe</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="224"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="235"/>
         <source>No gender</source>
         <translation>Pas de sexe</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="276"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="295"/>
         <source>Choose a photo</source>
         <translation>Choisissez une photographie</translation>
     </message>
@@ -159,12 +159,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="163"/>
+        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="148"/>
         <source>Address</source>
         <translation>Adresse</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="186"/>
+        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="171"/>
         <source>Contact</source>
         <translation></translation>
     </message>
@@ -217,27 +217,32 @@
         <translation>Date de naissance</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="130"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="123"/>
+        <source>dd/MM/yyyy</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
         <source>Adress</source>
         <translation>Adresse</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="142"/>
         <source>Street</source>
         <translation>Rue</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="143"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="149"/>
         <source>City</source>
         <translation>Ville</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="153"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="159"/>
         <source>Zipcode</source>
         <translation>Code postal</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="163"/>
+        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="169"/>
         <source>Country</source>
         <translation>Pays</translation>
     </message>
@@ -245,12 +250,12 @@
 <context>
     <name>Patients::Internal::PatientActionHandler</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
+        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
         <source>Fatal Error</source>
         <translation>Erreur fatale</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
+        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
         <source>%1 : Unable to retreive patients menu.</source>
         <translation>%1 : Impossible de récupérer le menu patient.</translation>
     </message>
@@ -258,28 +263,20 @@
 <context>
     <name>Patients::Internal::PatientBase</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
-        <source>Unable to connect the Patient&apos;s database host.</source>
-        <translation>Impossible de se connecter à la base de données patient.</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
+        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="322"/>
+        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="330"/>
+        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="336"/>
+        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="346"/>
         <source>Please contact dev team.</source>
         <translation>Veuillez contacter l&apos;équipe de développement.</translation>
     </message>
+</context>
+<context>
+    <name>Patients::Internal::PatientBasePreferencesPage</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
-        <source>Unable to create the Patients database.</source>
-        <translation>Impossible de créer la base de données patients.</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
-        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
-        <source>Unable to connect the Patients database.</source>
-        <translation>Impossible de se connecter à la base de données patients.</translation>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.cpp" line="67"/>
+        <source>Patient database preferences</source>
+        <translation>Préférences pour la base de données patients</translation>
     </message>
 </context>
 <context>
@@ -290,62 +287,61 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
-        <source>Patient database preferences</source>
-        <translation>Préférences pour la base de données patients</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="43"/>
-        <source>Virtual patients</source>
-        <translation>Patients virtuels</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="49"/>
-        <source>Show virtual patients</source>
-        <translation>Montrer les patients virtuels</translation>
-    </message>
-    <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="59"/>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="20"/>
         <source>Patient selector</source>
         <translation>Sélectionneur de patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="65"/>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
         <source>Use color to differentiate genders</source>
         <translation>Différentier les sexes par des couleurs différentes</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="88"/>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="33"/>
+        <source>Select newly created patients</source>
+        <translation>Sélectionner les patients nouvellement créés</translation>
+    </message>
+    <message>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="56"/>
         <source>Patient bar</source>
         <translation>Barre patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="94"/>
+        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="62"/>
         <source>Background color</source>
         <translation>Couleur de fond</translation>
     </message>
 </context>
+<context>
+    <name>Patients::PatientBasePlugin</name>
+    <message>
+        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="106"/>
+        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="153"/>
+        <source>Initializing patients database plugin...</source>
+        <translation>Initialisation de la base de données patients...</translation>
+    </message>
+</context>
 <context>
     <name>Patients::PatientCreatorWizard</name>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="66"/>
+        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="59"/>
         <source>New Patient</source>
         <translation>Nouveau patient</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="81"/>
+        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="73"/>
         <source>WARNING ! You don&apos;t saved this patient.</source>
         <translation>ATTENTION ! Vous n&apos;avez pas sauvegarder ce patient.</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="82"/>
+        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="74"/>
         <source>If you continue changes will be lost.
 Do you really want to close this dialog ?</source>
         <translation>Si vous continuez, les changements seront perdus.
 Voulez-vous réellement fermer ce dialogue ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="84"/>
+        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="76"/>
         <source>Patient not saved</source>
         <translation>Patient non sauvegardé</translation>
     </message>
