@@ -151,57 +151,57 @@
         <translation>Couleur de fond des cellules</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="36"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="44"/>
         <source>None</source>
         <translation>Aucune</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="37"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="45"/>
         <source>Dotted</source>
         <translation>Pointillés</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="38"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="46"/>
         <source>Dashed</source>
         <translation>Traits</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="39"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="47"/>
         <source>Solid</source>
         <translation>Solide</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="40"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="48"/>
         <source>Double</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="41"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="49"/>
         <source>Dot dash</source>
         <translation>Point trait</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="42"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="50"/>
         <source>Dot dot dash</source>
         <translation>Point point trait</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="43"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="51"/>
         <source>Groove</source>
         <translation>Rythmée</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="44"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="52"/>
         <source>Rigde</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="45"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="53"/>
         <source>Inset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="46"/>
+        <location filename="../../plugins/texteditorplugin/tablepropertieswidget.cpp" line="54"/>
         <source>Outset</source>
         <translation type="unfinished"></translation>
     </message>
@@ -209,18 +209,18 @@
 <context>
     <name>Editor::TextEditor</name>
     <message>
-        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="424"/>
-        <source>HTML files (*.htm *.html);;Text files (*.txt);;All Files (*)</source>
-        <translation>Fichiers HTML (*.htm *.html);;FichiersTexte (*.txt);;Tous les fichiers (*)</translation>
+        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="500"/>
+        <source>Save in pure textual format ?</source>
+        <translation>Sauvegarder en format textuel ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="444"/>
-        <source>HTML-Files (*.htm *.html);;All Files (*)</source>
-        <translation>Fichiers HTML (*.htm *.html);;Tous les fichiers (*)</translation>
+        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="501"/>
+        <source>The conversion of the document to a pure textual format will cause the lost of the paragraph and characters format. Do you really want to save in pure textual format ?</source>
+        <translation>La conversion de ce document en format texte causera la perte du formattage des caractères et des paragraphes. Voulez-vous sauvegarder en mode textuel pure ?</translation>
     </message>
     <message>
-        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="462"/>
-        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="464"/>
+        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="523"/>
+        <location filename="../../plugins/texteditorplugin/texteditor.cpp" line="525"/>
         <source>Font format</source>
         <translation>Format de police</translation>
     </message>
