@@ -313,11 +313,6 @@
         <source>Unlocked</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
-        <source>Templates database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="210"/>
         <source>PMHx</source>
@@ -495,11 +490,6 @@
         <source>Configure MedinTux</source>
         <translation>Konfiguriere MedinTux</translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
-        <source>View update informations</source>
-        <translation>Zeige Updateinformationen an</translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="252"/>
         <source>Print Preview</source>
@@ -536,16 +526,6 @@
         <source>Drugs database</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
-        <source>Protocols database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
-        <source>Interactions database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="268"/>
         <source>Interactions database</source>
@@ -663,6 +643,7 @@
     </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="295"/>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
         <source>Information</source>
         <translation>Information</translation>
     </message>
@@ -1062,16 +1043,6 @@
         <source>Show details</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
-        <source>More informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
-        <source>Hide extra informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="417"/>
         <source>Users</source>
@@ -1147,6 +1118,16 @@
         <source>User %1 correctly created</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
+        <source>Build information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
+        <source>Version information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="538"/>
         <source>Agenda</source>
@@ -1162,11 +1143,6 @@
         <source>Agenda events</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
-        <source>Agenda database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="542"/>
         <source>No availability</source>
@@ -1302,6 +1278,11 @@
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
+        <source>Patient information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="590"/>
         <source>Clear patient&apos;s information</source>
@@ -1372,6 +1353,36 @@
         <source>This feature is not yet implemented.</source>
         <translation>Dieses Feature ist noch nicht implementiert.</translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
+        <source>Templates database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
+        <source>View update information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
+        <source>Drugs database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
+        <source>Protocols database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
+        <source>Interactions database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
+        <source>Past medical history database information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="388"/>
         <source>Raising Application...</source>
@@ -1452,11 +1463,6 @@
         <source>Saving file %1</source>
         <translation>Speichere Datei %1</translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
-        <source>Informations</source>
-        <translation>Informationen</translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="455"/>
         <source>Version</source>
@@ -1587,16 +1593,6 @@
         <source>Toggle full screen</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
-        <source>Drugs database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
-        <source>Past medical history database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="269"/>
         <source>Drugs</source>
@@ -1642,6 +1638,16 @@
         <source>Reading settings file</source>
         <translation>Lese Einstellungen</translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
+        <source>More information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
+        <source>Hide extra information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="414"/>
         <source>Connected as
@@ -1854,16 +1860,6 @@ Place : %2</source>
         <source>Webmaster</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
-        <source>Build informations</source>
-        <translation>Bauinformation</translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
-        <source>Version informations</source>
-        <translation>Version Informationen</translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="524"/>
         <source>Build on %1 %2</source>
@@ -1914,6 +1910,11 @@ Place : %2</source>
         <source>Printing</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
+        <source>Agenda database information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="555"/>
         <source>Previous month</source>
@@ -1954,11 +1955,6 @@ Place : %2</source>
         <source>Patients</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
-        <source>Patient informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="589"/>
         <source>Patient database</source>
