@@ -308,11 +308,6 @@
         <source>Unlocked</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
-        <source>Templates database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="214"/>
         <source>Bold</source>
@@ -474,11 +469,6 @@
         <source>Configure MedinTux</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
-        <source>View update informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="252"/>
         <source>Print Preview</source>
@@ -515,16 +505,6 @@
         <source>Drugs database</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
-        <source>Protocols database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
-        <source>Interactions database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="268"/>
         <source>Interactions database</source>
@@ -597,6 +577,7 @@
     </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="295"/>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
@@ -665,6 +646,16 @@
         <source>quarter(s)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
+        <source>More information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
+        <source>Hide extra information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="414"/>
         <source>Connected as
@@ -676,6 +667,36 @@
         <source>decade(s)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
+        <source>Templates database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
+        <source>View update information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
+        <source>Drugs database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
+        <source>Protocols database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
+        <source>Interactions database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
+        <source>Past medical history database information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="354"/>
         <source>wake up</source>
@@ -757,16 +778,6 @@
         <source>Toggle full screen</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
-        <source>Drugs database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
-        <source>Past medical history database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="269"/>
         <source>Drugs</source>
@@ -1169,13 +1180,23 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
-        <source>More informations</source>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
+        <source>Build information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
-        <source>Hide extra informations</source>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
+        <source>Version information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
+        <source>Agenda database information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
+        <source>Patient information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1328,11 +1349,6 @@
         <source>Document type name mismatch.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
-        <source>Informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="453"/>
         <source>Cancel</source>
@@ -1634,16 +1650,6 @@ Place : %2</source>
         <source>Webmaster</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
-        <source>Build informations</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
-        <source>Version informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="524"/>
         <source>Build on %1 %2</source>
@@ -1709,11 +1715,6 @@ Place : %2</source>
         <source>Agenda events</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
-        <source>Agenda database informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="542"/>
         <source>No availability</source>
@@ -1889,11 +1890,6 @@ Place : %2</source>
         <source>Patients</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
-        <source>Patient informations</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../libs/translationutils/constanttranslations.h" line="589"/>
         <source>Patient database</source>
