@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,19 +19,16 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 
 /**
-  \namespace Trans::ConstantTranslations
-  \brief This namespace regroups some usefull translations that you can easily use in your app ou plugs
-  The tkTr() function helps you to translate its constants.\n
-  There are a lot of enums defined here for data comprehension. You should them for your models/database...\n
+  \namespace Trans
+  \brief Contains all translated strings, and members to ease the access to some translations.
 */
 
-
 #include "constanttranslations.h"
 
 #include <QLocale>
