@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -47,6 +47,9 @@
 #include <QPushButton>
 #include <QAbstractButton>
 #include <QTextDocument>
+#include <QCryptographicHash>
+#include <QMainWindow>
+#include <QModelIndex>
 
 /**
   \namespace Utils
@@ -56,6 +59,256 @@
 using namespace Utils;
 using namespace Trans::ConstantTranslations;
 
+
+namespace {
+static const unsigned char two_letter_country_code_list[] =
+"  " // Default
+"AF" // Afghanistan
+"AL" // Albania
+"DZ" // Algeria
+"AS" // AmericanSamoa
+"AD" // Andorra
+"AO" // Angola
+"AI" // Anguilla
+"AQ" // Antarctica
+"AG" // AntiguaAndBarbuda
+"AR" // Argentina
+"AM" // Armenia
+"AW" // Aruba
+"AU" // Australia
+"AT" // Austria
+"AZ" // Azerbaijan
+"BS" // Bahamas
+"BH" // Bahrain
+"BD" // Bangladesh
+"BB" // Barbados
+"BY" // Belarus
+"BE" // Belgium
+"BZ" // Belize
+"BJ" // Benin
+"BM" // Bermuda
+"BT" // Bhutan
+"BO" // Bolivia
+"BA" // BosniaAndHerzegowina
+"BW" // Botswana
+"BV" // BouvetIsland
+"BR" // Brazil
+"IO" // BritishIndianOceanTerritory
+"BN" // BruneiDarussalam
+"BG" // Bulgaria
+"BF" // BurkinaFaso
+"BI" // Burundi
+"KH" // Cambodia
+"CM" // Cameroon
+"CA" // Canada
+"CV" // CapeVerde
+"KY" // CaymanIslands
+"CF" // CentralAfricanRepublic
+"TD" // Chad
+"CL" // Chile
+"CN" // China
+"CX" // ChristmasIsland
+"CC" // CocosIslands
+"CO" // Colombia
+"KM" // Comoros
+"CD" // DemocraticRepublicOfCongo
+"CG" // PeoplesRepublicOfCongo
+"CK" // CookIslands
+"CR" // CostaRica
+"CI" // IvoryCoast
+"HR" // Croatia
+"CU" // Cuba
+"CY" // Cyprus
+"CZ" // CzechRepublic
+"DK" // Denmark
+"DJ" // Djibouti
+"DM" // Dominica
+"DO" // DominicanRepublic
+"TL" // EastTimor
+"EC" // Ecuador
+"EG" // Egypt
+"SV" // ElSalvador
+"GQ" // EquatorialGuinea
+"ER" // Eritrea
+"EE" // Estonia
+"ET" // Ethiopia
+"FK" // FalklandIslands
+"FO" // FaroeIslands
+"FJ" // Fiji
+"FI" // Finland
+"FR" // France
+"FX" // MetropolitanFrance
+"GF" // FrenchGuiana
+"PF" // FrenchPolynesia
+"TF" // FrenchSouthernTerritories
+"GA" // Gabon
+"GM" // Gambia
+"GE" // Georgia
+"DE" // Germany
+"GH" // Ghana
+"GI" // Gibraltar
+"GR" // Greece
+"GL" // Greenland
+"GD" // Grenada
+"GP" // Guadeloupe
+"GU" // Guam
+"GT" // Guatemala
+"GN" // Guinea
+"GW" // GuineaBissau
+"GY" // Guyana
+"HT" // Haiti
+"HM" // HeardAndMcDonaldIslands
+"HN" // Honduras
+"HK" // HongKong
+"HU" // Hungary
+"IS" // Iceland
+"IN" // India
+"ID" // Indonesia
+"IR" // Iran
+"IQ" // Iraq
+"IE" // Ireland
+"IL" // Israel
+"IT" // Italy
+"JM" // Jamaica
+"JP" // Japan
+"JO" // Jordan
+"KZ" // Kazakhstan
+"KE" // Kenya
+"KI" // Kiribati
+"KP" // DemocraticRepublicOfKorea
+"KR" // RepublicOfKorea
+"KW" // Kuwait
+"KG" // Kyrgyzstan
+"LA" // Lao
+"LV" // Latvia
+"LB" // Lebanon
+"LS" // Lesotho
+"LR" // Liberia
+"LY" // LibyanArabJamahiriya
+"LI" // Liechtenstein
+"LT" // Lithuania
+"LU" // Luxembourg
+"MO" // Macau
+"MK" // Macedonia
+"MG" // Madagascar
+"MW" // Malawi
+"MY" // Malaysia
+"MV" // Maldives
+"ML" // Mali
+"MT" // Malta
+"MH" // MarshallIslands
+"MQ" // Martinique
+"MR" // Mauritania
+"MU" // Mauritius
+"YT" // Mayotte
+"MX" // Mexico
+"FM" // Micronesia
+"MD" // Moldova
+"MC" // Monaco
+"MN" // Mongolia
+"MS" // Montserrat
+"MA" // Morocco
+"MZ" // Mozambique
+"MM" // Myanmar
+"NA" // Namibia
+"NR" // Nauru
+"NP" // Nepal
+"NL" // Netherlands
+"AN" // NetherlandsAntilles
+"NC" // NewCaledonia
+"NZ" // NewZealand
+"NI" // Nicaragua
+"NE" // Niger
+"NG" // Nigeria
+"NU" // Niue
+"NF" // NorfolkIsland
+"MP" // NorthernMarianaIslands
+"NO" // Norway
+"OM" // Oman
+"PK" // Pakistan
+"PW" // Palau
+"PS" // PalestinianTerritory
+"PA" // Panama
+"PG" // PapuaNewGuinea
+"PY" // Paraguay
+"PE" // Peru
+"PH" // Philippines
+"PN" // Pitcairn
+"PL" // Poland
+"PT" // Portugal
+"PR" // PuertoRico
+"QA" // Qatar
+"RE" // Reunion
+"RO" // Romania
+"RU" // RussianFederation
+"RW" // Rwanda
+"KN" // SaintKittsAndNevis
+"LC" // StLucia
+"VC" // StVincentAndTheGrenadines
+"WS" // Samoa
+"SM" // SanMarino
+"ST" // SaoTomeAndPrincipe
+"SA" // SaudiArabia
+"SN" // Senegal
+"SC" // Seychelles
+"SL" // SierraLeone
+"SG" // Singapore
+"SK" // Slovakia
+"SI" // Slovenia
+"SB" // SolomonIslands
+"SO" // Somalia
+"ZA" // SouthAfrica
+"GS" // SouthGeorgiaAndTheSouthSandwichIslands
+"ES" // Spain
+"LK" // SriLanka
+"SH" // StHelena
+"PM" // StPierreAndMiquelon
+"SD" // Sudan
+"SR" // Suriname
+"SJ" // SvalbardAndJanMayenIslands
+"SZ" // Swaziland
+"SE" // Sweden
+"CH" // Switzerland
+"SY" // SyrianArabRepublic
+"TW" // Taiwan
+"TJ" // Tajikistan
+"TZ" // Tanzania
+"TH" // Thailand
+"TG" // Togo
+"TK" // Tokelau
+"TO" // Tonga
+"TT" // TrinidadAndTobago
+"TN" // Tunisia
+"TR" // Turkey
+"TM" // Turkmenistan
+"TC" // TurksAndCaicosIslands
+"TV" // Tuvalu
+"UG" // Uganda
+"UA" // Ukraine
+"AE" // UnitedArabEmirates
+"GB" // UnitedKingdom
+"US" // UnitedStates
+"UM" // UnitedStatesMinorOutlyingIslands
+"UY" // Uruguay
+"UZ" // Uzbekistan
+"VU" // Vanuatu
+"VA" // VaticanCityState
+"VE" // Venezuela
+"VN" // VietNam
+"VG" // BritishVirginIslands
+"VI" // USVirginIslands
+"WF" // WallisAndFutunaIslands
+"EH" // WesternSahara
+"YE" // Yemen
+"YU" // Yugoslavia
+"ZM" // Zambia
+"ZW" // Zimbabwe
+"CS" // SerbiaAndMontenegro
+;
+
+} // End anonymous namespace
+
+
 namespace Utils {
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -69,6 +322,7 @@ bool isDebugCompilation()
     return false;
 #endif
 }
+bool isReleaseCompilation() {return !isDebugCompilation();}
 bool isSvnBuild()
 {
 #ifdef FULLAPPLICATION_BUILD
@@ -85,6 +339,10 @@ bool isFullApplication()
     return false;
 #endif
 }
+bool isAlpha()
+{
+    return qApp->applicationVersion().contains("alpha", Qt::CaseInsensitive);
+}
 bool isRunningOnMac()
 {
 #ifdef Q_OS_MAC
@@ -185,26 +443,69 @@ bool removeDir(const QString &name, QString *error)
     return true;
 }
 
-QFileInfoList getFiles(QDir fromDir, const QStringList& filters, bool recursive)
+bool removeDirRecursively(const QString &absPath, QString *error)
+{
+    error->clear();
+    QDir dir(absPath);
+    if (!dir.exists()) {
+        error->append(Trans::ConstantTranslations::tkTr(Trans::Constants::PATH_1_DOESNOT_EXISTS).arg(absPath));
+        return false;
+    }
+
+    // remove all dirs inside this dir (recursively)
+    foreach(const QString &dirPath, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+        QString er;
+        if (!removeDirRecursively(dir.absolutePath() + QDir::separator() + dirPath, &er)) {
+            error->append(er);
+            return false;
+        }
+    }
+
+    // remove this dir
+    QString er;
+    if (!removeDir(dir.absolutePath(), &er)) {
+        error->append(er);
+        return false;
+    }
+
+    return true;
+}
+
+QFileInfoList getFiles(QDir fromDir, const QStringList &filters, DirSearchType recursive)
 {
     QFileInfoList files;
     foreach (const QFileInfo & file, fromDir.entryInfoList(QDir::AllEntries | QDir::NoDotAndDotDot, QDir::DirsFirst | QDir::Name)) {
         if (file.isFile() && (filters.isEmpty() || QDir::match(filters, file.fileName())))
             files << file;
-        else if (file.isDir() && recursive) {
+        else if (file.isDir() && recursive==Recursively) {
             fromDir.cd(file.filePath());
-            files << getFiles(fromDir, filters);
+            files << getFiles(fromDir, filters, recursive);
             fromDir.cdUp();
         }
     }
     return files;
 }
 
-QFileInfoList getFiles(QDir fromDir, const QString& filter, bool recursive)
+QFileInfoList getFiles(QDir fromDir, const QString &filter, DirSearchType recursive)
 {
     return getFiles(fromDir, filter.isEmpty() ? QStringList() : QStringList(filter), recursive);
 }
 
+QFileInfoList getDirs(QDir fromDir, const QStringList &filters, DirSearchType recursive)
+{
+    QFileInfoList dirs;
+    foreach (const QFileInfo &file, fromDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::DirsFirst | QDir::IgnoreCase)) {
+        if (file.isFile() && (filters.isEmpty() || QDir::match(filters, file.fileName())))
+            dirs << file;
+        else if (file.isDir() && recursive==Recursively) {
+            fromDir.cd(file.filePath());
+            dirs << getFiles(fromDir, filters, recursive);
+            fromDir.cdUp();
+        }
+    }
+    return dirs;
+}
+
 /**
    \brief Test a dir, try to create it if it does not exist.
    \param absPath : AbsolutePath of the directory to test
@@ -213,18 +514,18 @@ QFileInfoList getFiles(QDir fromDir, const QString& filter, bool recursive)
 **/
 bool checkDir(const QString & absPath, bool createIfNotExist, const QString & logDirName)
 {
-    if (! QFile::exists(absPath)) {
+    if (!QFile::exists(absPath)) {
         if (createIfNotExist) {
-            Utils::Log::addMessage("Utils", QCoreApplication::translate("Utils", "%1 : %2 does not exist. Trying to create it.")
+            LOG_FOR("Utils", QCoreApplication::translate("Utils", "%1 : %2 does not exist. Trying to create it.")
                                .arg(logDirName, absPath));
-            if (! QDir().mkpath(absPath)) {
+            if (!QDir().mkpath(absPath)) {
                 Utils::Log::addError("Utils", QCoreApplication::translate("Utils", "Unable to create the %1 : %2.")
                                  .arg(logDirName, absPath) ,
                                  __FILE__, __LINE__);
                 return false;
             }
         } else {
-            Utils::Log::addMessage("Utils", QCoreApplication::translate("Utils", "%1 : %2 does not exist.")
+            LOG_FOR("Utils", QCoreApplication::translate("Utils", "%1 : %2 does not exist.")
                                .arg(logDirName, absPath));
             return false;
         }
@@ -275,9 +576,9 @@ bool saveStringToFile(const QString &toSave, const QString &toFile, IOMode iomod
                 return false;
             }
             file.write(toSave.toAscii());
-            Utils::Log::addMessage("Utils", QCoreApplication::translate("Utils", "%1 correctly saved").arg(file.fileName()));
+            LOG_FOR("Utils", QCoreApplication::translate("Utils", "%1 correctly saved").arg(file.fileName()));
         } else {
-            Utils::Log::addMessage("Utils", QCoreApplication::translate("Utils", "Save file aborted by user (file already exists) : ") + file.fileName());
+            LOG_FOR("Utils", QCoreApplication::translate("Utils", "Save file aborted by user (file already exists) : ") + file.fileName());
             return false;
         }
     } else {
@@ -288,7 +589,7 @@ bool saveStringToFile(const QString &toSave, const QString &toFile, IOMode iomod
             return false;
         }
         file.write(toSave.toAscii());
-        Utils::Log::addMessage("Utils", QCoreApplication::translate("Utils", "%1 correctly saved").arg(file.fileName()));
+        LOG_FOR("Utils", QCoreApplication::translate("Utils", "%1 correctly saved").arg(file.fileName()));
     }
     return true;
 }
@@ -311,7 +612,13 @@ bool saveStringToFile(const QString &toSave, const QString &dirPath, const QStri
 QString readTextFile(const QString &toRead, const Warn warnUser, QWidget *parent)
 {return readTextFile(toRead, QString("UTF-8"), warnUser, parent);}
 
-/** \brief Return the content of a text file. You can choose to warn the user or not is an error is encountered. **/
+/**
+ \brief Return the content of a text file.
+  You can choose:
+  - to warn the user if an error is encountered.
+  - the encoding of the file (using the QTextCodec supported encodings)
+  - the parent widget used for the message box error
+**/
 QString readTextFile(const QString &toRead, const QString &encoder, const Warn warnUser, QWidget *parent)
 {
     if (toRead.isEmpty())
@@ -334,15 +641,14 @@ QString readTextFile(const QString &toRead, const QString &encoder, const Warn w
     } else {
         QFile file(correctFileName);
         if (!file.open(QFile::ReadOnly | QIODevice::Text)) {
-            Utils::Log::addError("Utils", QCoreApplication::translate("Utils", "Error %1 while trying to open file %2")
-                             .arg(correctFileName, file.errorString()),
-                             __FILE__, __LINE__);
+            LOG_ERROR_FOR("Utils", QCoreApplication::translate("Utils", "Error %1 while trying to open file %2")
+                          .arg(correctFileName, file.errorString()));
             return QString::null;
         }
         QByteArray data = file.readAll();
         QTextCodec *codec = QTextCodec::codecForName(encoder.toUtf8());
         QString str = codec->toUnicode(data);
-        Utils::Log::addMessage("Utils", tkTr(Trans::Constants::FILE_1_LOADED).arg(toRead));
+        LOG_FOR("Utils", tkTr(Trans::Constants::FILE_1_LOADED).arg(toRead));
         return str;
     }
     return QString::null;
@@ -398,7 +704,7 @@ void informativeMessageBox(const QString &text, const QString &infoText, const Q
 /** \brief Creates a warning messagebox. **/
 void warningMessageBox(const QString &text, const QString &infoText, const QString &detail, const QString &title)
 {
-    Utils::Log::addMessage("Warning Dialog", infoText);
+    LOG_FOR("Warning Dialog", infoText);
     QWidget *parent = qApp->activeWindow();
     QMessageBox mb(parent);
     mb.setWindowModality(Qt::WindowModal);
@@ -439,6 +745,8 @@ bool yesNoMessageBox(const QString &text, const QString&infoText, const QString&
         mb.setWindowTitle(qApp->applicationName());
     else
         mb.setWindowTitle(title);
+    mb.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    mb.setDefaultButton(QMessageBox::Yes);
     mb.setText(text);
     mb.setInformativeText(infoText);
     if (!detail.isEmpty()) {
@@ -450,8 +758,6 @@ bool yesNoMessageBox(const QString &text, const QString&infoText, const QString&
             mb.setDetailedText(detail);
         }
     }
-    mb.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-    mb.setDefaultButton(QMessageBox::Yes);
     int r = mb.exec();
     qApp->setActiveWindow(parent);
     if (r==QMessageBox::Yes)
@@ -643,7 +949,6 @@ bool defaultLicenceAgreementDialog(const QString &message, Utils::LicenseTerms::
     return false;
 }
 
-
 /** \brief Creates a Dialog for simple user's input.  **/
 QString askUser(const QString &title, const QString &question)
 {
@@ -660,10 +965,26 @@ QString askUser(const QString &title, const QString &question)
 /** \brief Center the widget into the desktop. **/
 void centerWidget(QWidget *win, QWidget *reference)
 {
+    if (!win)
+        return;
     QPoint center;
     if (!reference) {
-        reference = qApp->desktop();
-        center = reference->rect().center();
+        // try to find the mainwindow
+        QMainWindow *win = 0;
+        QWidgetList list = qApp->topLevelWidgets();
+        for(int i = 0; i < list.count(); ++i) {
+            win = qobject_cast<QMainWindow*>(list.at(i));
+            if (win && win->isVisible()) {
+                break;
+            }
+        }
+        if (win) {
+            reference = win;
+            center = reference->rect().center() + reference->pos();
+        } else {
+            reference = qApp->desktop();
+            center = reference->rect().center();
+        }
     } else {
         center = reference->rect().center() + reference->pos();
     }
@@ -680,12 +1001,12 @@ void setFullScreen(QWidget* win, bool on)
 
     if (on) {
         win->setWindowState(win->windowState() | Qt::WindowFullScreen);
-        Utils::Log::addMessage("mfGlobal", QCoreApplication::translate("Utils", "%1 is now in fullScreen Mode.").arg(win->objectName()));
+        LOG_FOR("mfGlobal", QCoreApplication::translate("Utils", "%1 is now in fullScreen Mode.").arg(win->objectName()));
         //statusBar()->hide();
         //menuBar()->hide();
     } else {
         win->setWindowState(win->windowState() & ~Qt::WindowFullScreen);
-        Utils::Log::addMessage("mfGlobal", QCoreApplication::translate("Utils", "%1 is now in non fullScreen Mode.").arg(win->objectName()));
+        LOG_FOR("mfGlobal", QCoreApplication::translate("Utils", "%1 is now in non fullScreen Mode.").arg(win->objectName()));
         //menuBar()->show();
         //statusBar()->show();
     }
@@ -697,6 +1018,10 @@ void resizeAndCenter(QWidget *widget, QWidget *reference)
     QWidget *ref = reference;
     if (!reference)
         ref = qApp->activeWindow();
+    if (!ref) {
+        widget->adjustSize();
+        return;
+    }
     QSize size = ref->size();
     size = QSize(size.width()*0.9, size.height()*0.9);
     widget->resize(size);
@@ -713,6 +1038,71 @@ void switchEchoMode(QLineEdit * l)
         l->setEchoMode(QLineEdit::Normal);
 }
 
+/** Rounds the \e date to the number of minutes \e minutesRound. */
+QDateTime roundDateTime(const QDateTime &date, const int minutesRound)
+{
+    if (date.isNull())
+        return QDateTime();
+    if (date.time().minute() % minutesRound == 0)
+        return QDateTime(date.date(), QTime(date.time().hour(), date.time().minute(), 0));
+    QDateTime dt = QDateTime(date.date(), QTime(date.time().hour(), date.time().minute(), 0));
+    dt = dt.addSecs(60);
+    int minToRound = dt.time().minute() % minutesRound;
+    dt = dt.addSecs((minutesRound - minToRound)*60);
+    return dt;
+}
+
+bool inRange(const int min, const int max, const int value)
+{
+    return ((value >= min) && (value <= max));
+}
+
+bool inRange(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QModelIndex &value)
+{
+    // row in range ?
+    if (!inRange(topLeft.row(), bottomRight.row(), value.row()))
+        return false;
+    int min = (topLeft.row() * 1000) + topLeft.column();
+    int max = (bottomRight.row() * 1000) + bottomRight.column();
+    int val = (value.row() * 1000) + value.column();
+    return inRange(min, max, val);
+}
+
+/** Return the ISO 2 char encoded of the \e country */
+QString countryToIso(QLocale::Country country)
+{
+    if (country == QLocale::AnyCountry)
+        return QString();
+
+    QString code;
+    code.resize(2);
+    const unsigned char *c = two_letter_country_code_list + 2 * (uint(country));
+    code[0] = ushort(c[0]);
+    code[1] = ushort(c[1]);
+    return code;
+}
+
+QString countryIsoToName(const QString &country)
+{
+    if (country.size() != 2)
+        return QString();
+    QString t;
+    t.resize(2);
+    int c = 2;
+    int max = sizeof(two_letter_country_code_list)/sizeof (*two_letter_country_code_list);
+    int i = c;
+    while (i < max) {
+        const unsigned char *c = two_letter_country_code_list + i;
+        t[0] = ushort(c[0]);
+        t[1] = ushort(c[1]);
+        if (t.compare(country, Qt::CaseInsensitive)==0) {
+            return QLocale::countryToString(QLocale::Country(i/2));
+        }
+        i += 2;
+    }
+    return QString();
+}
+
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////   HTML FUNCTIONS   //////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -758,6 +1148,7 @@ QString textAlignmentToHtml(const Qt::Alignment &align)
     }
     return toReturn;
 }
+
 /** \brief Assumes a better encoding of HTML files by replacing special characters with the html code (é==&eacute;) **/
 QString toHtmlAccent(const QString &html)
 {
@@ -779,6 +1170,7 @@ QString toHtmlAccent(const QString &html)
     accents.insert(QString::fromUtf8("ô"), "&ocirc;");
     accents.insert(QString::fromUtf8("û"), "&ucirc;");
 
+    accents.insert(QString::fromUtf8("ä"), "&auml;");
     accents.insert(QString::fromUtf8("ë"), "&euml;");
     accents.insert(QString::fromUtf8("ï"), "&iuml;");
     accents.insert(QString::fromUtf8("ö"), "&ouml;");
@@ -803,11 +1195,17 @@ QString toHtmlAccent(const QString &html)
     accents.insert(QString::fromUtf8("Ô"), "&Ocirc;");
     accents.insert(QString::fromUtf8("Û"), "&Ucirc;");
 
+    accents.insert(QString::fromUtf8("Ä"), "&Auml;");
     accents.insert(QString::fromUtf8("Ë"), "&Euml;");
     accents.insert(QString::fromUtf8("Ï"), "&Iuml;");
     accents.insert(QString::fromUtf8("Ö"), "&Ouml;");
     accents.insert(QString::fromUtf8("Ü"), "&Uuml;");
 
+    accents.insert(QString::fromUtf8("ã"), "&atilde;");
+    accents.insert(QString::fromUtf8("õ"), "&otilde;");
+    accents.insert(QString::fromUtf8("Ã"), "&Atilde;");
+    accents.insert(QString::fromUtf8("Õ"), "&Otilde;");
+
     accents.insert(QString::fromUtf8("Œ"), "&OElig;");
     accents.insert(QString::fromUtf8("Æ"), "&AElig;");
     accents.insert(QString::fromUtf8("Ç"), "&Ccedil;");
@@ -822,7 +1220,6 @@ QString toHtmlAccent(const QString &html)
     accents.insert(QString::fromUtf8("¤"), "&curren;");
     accents.insert(QString::fromUtf8("¥"), "&yen;");
     accents.insert(QString::fromUtf8("¦"), "&brvbar;");
-    accents.insert(QString::fromUtf8("Ã"), "&Atilde;");
     accents.insert(QString::fromUtf8("µ"), "&micro;");
     accents.insert(QString::fromUtf8("·"), "&middot;");
     accents.insert(QString::fromUtf8("»"), "&raquo;");
@@ -847,6 +1244,77 @@ QString toHtmlAccent(const QString &html)
     return toReturn;
 }
 
+QString firstLetterUpperCase(const QString &s)
+{
+    QString tmp = s;
+    tmp[0] = tmp[0].toUpper();
+    return tmp;
+}
+
+QString removeAccents(const QString &text)
+{
+    QHash< QString, QString > accents;
+    accents.insert(QString::fromUtf8("é"), "e;");
+    accents.insert(QString::fromUtf8("è"), "e");
+    accents.insert(QString::fromUtf8("à"), "a");
+    accents.insert(QString::fromUtf8("ù"), "u");
+
+    accents.insert(QString::fromUtf8("ê"), "e");
+    accents.insert(QString::fromUtf8("â"), "a");
+    accents.insert(QString::fromUtf8("î"), "i");
+    accents.insert(QString::fromUtf8("ô"), "o");
+    accents.insert(QString::fromUtf8("û"), "u");
+
+    accents.insert(QString::fromUtf8("ä"), "a");
+    accents.insert(QString::fromUtf8("ë"), "e");
+    accents.insert(QString::fromUtf8("ï"), "i");
+    accents.insert(QString::fromUtf8("ö"), "o");
+    accents.insert(QString::fromUtf8("ü"), "u");
+
+    accents.insert(QString::fromUtf8("œ"), "oe");
+    accents.insert(QString::fromUtf8("æ"), "ae");
+    accents.insert(QString::fromUtf8("ç"), "c");
+
+    accents.insert(QString::fromUtf8("ø"), "o");
+    accents.insert(QString::fromUtf8("Ø"), "O");
+
+    accents.insert(QString::fromUtf8("É"), "E");
+
+    accents.insert(QString::fromUtf8("È"), "E");
+    accents.insert(QString::fromUtf8("À"), "A");
+    accents.insert(QString::fromUtf8("Ù"), "U");
+
+    accents.insert(QString::fromUtf8("Â"), "A");
+    accents.insert(QString::fromUtf8("Ê"), "E");
+    accents.insert(QString::fromUtf8("Î"), "I");
+    accents.insert(QString::fromUtf8("Ô"), "O");
+    accents.insert(QString::fromUtf8("Û"), "U");
+
+    accents.insert(QString::fromUtf8("Ä"), "A");
+    accents.insert(QString::fromUtf8("Ë"), "E");
+    accents.insert(QString::fromUtf8("Ï"), "I");
+    accents.insert(QString::fromUtf8("Ö"), "O");
+    accents.insert(QString::fromUtf8("Ü"), "U");
+
+    accents.insert(QString::fromUtf8("Œ"), "OE");
+    accents.insert(QString::fromUtf8("Æ"), "AE");
+    accents.insert(QString::fromUtf8("Ç"), "C");
+
+    accents.insert(QString::fromUtf8("ø"), "o");
+    accents.insert(QString::fromUtf8("Ø"), "O");
+
+    accents.insert(QString::fromUtf8("ã"), "a");
+    accents.insert(QString::fromUtf8("õ"), "o");
+    accents.insert(QString::fromUtf8("Ã"), "A");
+    accents.insert(QString::fromUtf8("Õ"), "O");
+
+    QString toReturn = text;
+    foreach(const QString &k, accents.keys()) {
+        toReturn.replace(k, accents.value(k));
+    }
+    return toReturn;
+}
+
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////////////   XML FUNCTIONS   //////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1082,4 +1550,53 @@ int replaceTokens(QString &textToAnalyse, const QHash<QString, QString> &tokens_
     return i;
 }
 
+/** First crypt string using SHA1 logarythm then transform crypted result to base64 (so it can be added into database without problem - no special characters). */
+QString cryptPassword(const QString &toCrypt)
+{
+    QCryptographicHash crypter( QCryptographicHash::Sha1 );
+    crypter.addData( toCrypt.toAscii() );
+    return crypter.result().toBase64();
+}
+
+/** Crypt a clear login. */
+QString loginForSQL(const QString &log)
+{ return log.toAscii().toBase64(); }
+
+/** Decrypt a crypted login. */
+QString loginFromSQL(const QVariant &sql)
+{ return QByteArray::fromBase64( sql.toByteArray() ); }
+
+/** Decrypt a crypted login. */
+QString loginFromSQL(const QString &sql)
+{ return QByteArray::fromBase64(sql.toAscii()); }
+
+
+QByteArray crypt(const QString &texte)
+{
+    QByteArray texteEnBytes = texte.toAscii();
+    QString k = QCryptographicHash::hash(qApp->applicationName().left(qApp->applicationName().indexOf("_d")).toAscii(), QCryptographicHash::Sha1);
+    QByteArray cle = k.toAscii().toBase64();
+    QByteArray codeFinal;
+    int tailleCle = cle.length();
+    for (int i = 0; i < texteEnBytes.length(); ++i) {
+        codeFinal += char(texteEnBytes[i] ^ cle[i % tailleCle]);
+    }
+    return codeFinal.toHex().toBase64();
+}
+
+// "MTEwZjI5MGQxODNhNDQwODMzMmI=" "CacaBoudin"
+
+QString decrypt(const QByteArray &texte)
+{
+    QByteArray texteEnBytes = QByteArray::fromHex(QByteArray::fromBase64(texte));
+    QString k = QCryptographicHash::hash(qApp->applicationName().left(qApp->applicationName().indexOf("_d")).toAscii(), QCryptographicHash::Sha1);
+    QByteArray cle = k.toAscii().toBase64();
+    QByteArray codeFinal;
+    int tailleCle = cle.length();
+    for (int i = 0; i < texteEnBytes.length(); ++i) {
+        codeFinal += char(texteEnBytes[i] ^ cle[i % tailleCle]);
+    }
+    return codeFinal;
+}
+
 } // End Utils
