@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,12 +19,12 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
-#ifndef UTILSGLOBAL_H
-#define UTILSGLOBAL_H
+#ifndef UTILS_GLOBAL_H
+#define UTILS_GLOBAL_H
 
 #include <utils/global_exporter.h>
 #include <utils/licenseterms.h>
@@ -35,18 +35,20 @@ class QDir;
 class QFont;
 class QDomElement;
 class QWidget;
+class QModelIndex;
 QT_END_NAMESPACE
 
 #include <QFileInfo>
 #include <QString>
 #include <QHash>
 #include <QMessageBox>
+#include <QLocale>
 
 /**
  * \file global.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.0.18
- * \date 10 Aug 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 29 May 2011
 */
 
 namespace Utils {
@@ -66,14 +68,22 @@ enum IOMode {
     AppendToFile
 };
 
+enum DirSearchType {
+    Recursively = 0,
+    NotRecursively
+};
 
 // Libs and OS informations
 /** \brief Return true if the application was build in debug mode. */
 UTILS_EXPORT bool isDebugCompilation();
+/** \brief Return true if the application was build in release mode. */
+UTILS_EXPORT bool isReleaseCompilation();
 /** \brief Return true if the application was build using the SVN. */
 UTILS_EXPORT bool isSvnBuild();
 /** \brief Return true if the application was build with all private parts. */
 UTILS_EXPORT bool isFullApplication();
+/** \brief Return true if the application is an alpha build (release or debug). */
+UTILS_EXPORT bool isAlpha();
 /** \brief Return true if the application is running on MacOs. */
 UTILS_EXPORT bool isRunningOnMac();
 /** \brief Return true if the application is running on Windows. */
@@ -108,10 +118,12 @@ UTILS_EXPORT bool defaultLicenceAgreementDialog(const QString &message, Utils::L
 UTILS_EXPORT QString askUser( const QString &title, const QString &question );
 
 // Working with files and dirs
-UTILS_EXPORT bool removeDir(const QString &name, QString *error);
-UTILS_EXPORT QFileInfoList getFiles( QDir fromDir, const QStringList& filters, bool recursive = true );
-UTILS_EXPORT QFileInfoList getFiles( QDir fromDir, const QString& filters = QString::null, bool recursive = true );
-UTILS_EXPORT bool checkDir( const QString & absPath, bool createIfNotExist, const QString & logDirName = QString::null );
+UTILS_EXPORT bool removeDir(const QString &absPath, QString *error);
+UTILS_EXPORT bool removeDirRecursively(const QString &absPath, QString *error);
+UTILS_EXPORT QFileInfoList getFiles(QDir fromDir, const QStringList &filters, DirSearchType recursive = Recursively);
+UTILS_EXPORT QFileInfoList getFiles(QDir fromDir, const QString &filters = QString::null, DirSearchType recursive = Recursively);
+UTILS_EXPORT QFileInfoList getDirs(QDir fromDir, const QStringList &filters, DirSearchType recursive = Recursively);
+UTILS_EXPORT bool checkDir( const QString &absPath, bool createIfNotExist, const QString & logDirName = QString::null );
 UTILS_EXPORT bool saveStringToFile( const QString &toSave, const QString &toFile, IOMode mode = Overwrite, const Warn warnUser = WarnUser, QWidget *parent=0 );
 UTILS_EXPORT bool saveStringToFile( const QString &toSave,  const QString &dirPath, const QString &filters, QWidget *parent = 0 );
 UTILS_EXPORT QString readTextFile( const QString &toRead, const QString &encoder, const Warn warnUser = WarnUser, QWidget *parent = 0 );
@@ -123,10 +135,21 @@ UTILS_EXPORT QString isFileExists(const QString &absPath);
 /** \brief Toggle the echomode of a QLineEdit. */
 UTILS_EXPORT void switchEchoMode( QLineEdit * l );
 
+// Some date & numbering functions
+UTILS_EXPORT QDateTime roundDateTime(const QDateTime &date, const int minutesRound);
+UTILS_EXPORT bool inRange(const int min, const int max, const int value);
+UTILS_EXPORT bool inRange(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QModelIndex &value);
+
+// Some locale functions
+UTILS_EXPORT QString countryToIso(QLocale::Country country);
+UTILS_EXPORT QString countryIsoToName(const QString &country);
+
 // Some functions for HTML work
 UTILS_EXPORT QString fontToHtml( const QFont &font, const QColor &color = QColor("black") );
 UTILS_EXPORT QString textAlignmentToHtml( const Qt::Alignment &align );
-UTILS_EXPORT QString toHtmlAccent( const QString &html );
+UTILS_EXPORT QString toHtmlAccent(const QString &html);
+UTILS_EXPORT QString firstLetterUpperCase(const QString &s);
+UTILS_EXPORT QString removeAccents(const QString &text);
 
 // Some functions for XML Handling
 UTILS_EXPORT QString createXml( const QString &mainTag, const QHash<QString,QString> &datas, const int indent = 0, const bool valueToBase64 = false );
@@ -146,6 +169,16 @@ UTILS_EXPORT void    xmlWrite(QDomElement &father, const QString &name, bool val
 UTILS_EXPORT int replaceToken( QString &textToAnalyse, const QString &token, const QString &value );
 UTILS_EXPORT int replaceTokens(QString &textToAnalyse, const QHash<QString, QString> &tokens_values);
 
+// Some database identifiers helpers
+// Login and password transformations
+UTILS_EXPORT QString cryptPassword(const QString &toCrypt);
+UTILS_EXPORT QString loginForSQL(const QString &log);
+UTILS_EXPORT QString loginFromSQL(const QVariant &sql);
+UTILS_EXPORT QString loginFromSQL(const QString &sql);
+
+UTILS_EXPORT QByteArray crypt(const QString &texte);
+UTILS_EXPORT QString decrypt(const QByteArray &texte);
+
 }  // end Utils
 
-#endif  // UTILSGLOBAL_H
+#endif  // UTILS_GLOBAL_H
