@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -35,6 +35,8 @@
 #include <time.h>
 
 #include <QFile>
+#include <QFileInfo>
+#include <QDir>
 #include <QVector>
 
 #include <time.h>
@@ -105,8 +107,7 @@ public:
             return;
         QString c = Utils::readTextFile(m_Path + "/listemotsfr.txt");
         if (c.isEmpty())
-            Utils::Log::addError("Randomizer", "Can not read french words.",
-                                 __FILE__, __LINE__);
+            LOG_ERROR_FOR("Randomizer", "Can not read french words.");
         foreach(const QString &s, c.split("\n", QString::SkipEmptyParts)) {
             words.append(s.toUpper());
         }
@@ -195,15 +196,33 @@ QString Randomizer::getRandomName()
     return d->words.at(makeRand(d->words.count() - 1));
 }
 
+QString Randomizer::randomWords(int nbOfWords)
+{
+    QStringList t;
+    for(int i=0; i < nbOfWords; ++i) {
+        t <<  getRandomName();
+    }
+    return t.join(" ");
+}
+
 int Randomizer::randomInt(int max)
 {
     return makeRand(max);
 }
 
+bool Randomizer::randomBool()
+{
+    int z = 0;
+    for(int i=0; i < randomInt(1, 50); ++i) {
+        z += randomInt(0,1);
+    }
+    return (z%1==0);
+}
+
 int Randomizer::randomInt(int min, int max)
 {
     Q_ASSERT(min < max);
-    int i = min;
+    int i = min - 10;
     int z = 0;
     while (i < min) {
         i = makeRand(max);
@@ -260,3 +279,17 @@ QDateTime Randomizer::randomDateTime(const QDateTime &minDate)
     }
     return toReturn;
 }
+
+QTime Randomizer::randomTime(const int minHour, const int maxHour)
+{
+    int h = randomInt(minHour, maxHour);
+    int m = randomInt(0, 59);
+    int s = randomInt(0, 59);
+    return QTime(h,m,s);
+}
+
+QFileInfo Randomizer::randomFile(const QDir &inDir, const QStringList &filters)
+{
+    QFileInfoList list = inDir.entryInfoList(filters);
+    return list.at(randomInt(0, list.count()));
+}
