@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -29,9 +29,17 @@
 #include <utils/global_exporter.h>
 
 #include <QString>
+#include <QStringList>
+#include <QFileInfo>
 #include <QPair>
 #include <QDate>
 
+/**
+ * \file randomizer.h
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 19 Jun 2011
+*/
 
 namespace Utils {
 namespace Internal {
@@ -55,9 +63,15 @@ public:
 
     int randomInt(int max);
     int randomInt(int min, int max);
+    bool randomBool();
+
+    QString randomWords(int nbOfWords);
 
     QDate randomDate(const int minYear, const int minMonth = 1, const int minDay = 1);
     QDateTime randomDateTime(const QDateTime &mindate);
+    QTime randomTime(const int minHour, const int maxHour);
+
+    QFileInfo randomFile(const QDir &inDir, const QStringList &filters);
 
 private:
     Internal::RandomizerPrivate *d;
