@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -64,6 +64,7 @@
 #include <QLocale>
 #include <QStatusBar>
 #include <QLabel>
+#include <QDesktopServices>
 
 using namespace Core;
 using namespace Core::Internal;
@@ -106,6 +107,7 @@ MainWindowActionHandler::MainWindowActionHandler(QWidget *parent) :
         aMedinTux(0),
         aLanguageGroup(0),
         aAppAbout(0),
+        aAppGoToWebSite(0),
         aPlugsAbout(0),
         aAppHelp(0),
         aQtAbout(0),
@@ -126,14 +128,7 @@ MainWindowActionHandler::~MainWindowActionHandler()
 void MainWindowActionHandler::createGeneralMenu()
 {
     // creates menu bar
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
-    if (!menubar) {
-        menubar = actionManager()->createMenuBar(Constants::MENUBAR);
-#ifndef Q_WS_MAC
-        setMenuBar(menubar->menuBar());
-#endif
-    }
-    menubar->appendGroup(Constants::G_GENERAL);
+    ActionContainer *menubar = menubarContainer(true);
 
     // Create menu
     ActionContainer *menu = actionManager()->createMenu(Constants::M_GENERAL);
@@ -252,7 +247,6 @@ void MainWindowActionHandler::createGeneralActions(const int actions)
         cmd->setTranslations(Trans::Constants::FILEEXIT_TEXT );
         cmd->action()->setMenuRole(QAction::QuitRole);
         menu->addAction(cmd, group);
-        connect(aQuit, SIGNAL(triggered()), this, SLOT(close()));
     }
 
 //    group = Constants::G_GENERAL_EDIT;
@@ -326,16 +320,17 @@ void MainWindowActionHandler::createGeneralActions(const int actions)
     if (actions & Core::MainWindowActions::A_Patients_New) {
         a = aGeneralPatientNew = new QAction(this);
         a->setObjectName("aGeneralPatientNew");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_NEW, ctx);
-        cmd->setTranslations(Trans::Constants::PATIENT);
+        cmd->setDefaultKeySequence(Qt::CTRL + Qt::Key_N);
+        cmd->setTranslations(Trans::Constants::PATIENTNEW_TEXT);
         newmenu->addAction(cmd, Constants::G_GENERAL_NEW);
     }
     // Patient's identity
     if (actions & Core::MainWindowActions::A_Patients_ViewIdentity) {
         a = aGeneralPatientViewIdentity = new QAction(this);
         a->setObjectName("aGeneralPatientViewIdentity");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_VIEWIDENTITY, ctx);
         cmd->setTranslations(Trans::Constants::PATIENTVIEWIDENTITY_TEXT);
         menu->addAction(cmd, group);
@@ -344,7 +339,7 @@ void MainWindowActionHandler::createGeneralActions(const int actions)
     if (actions & Core::MainWindowActions::A_Patients_Remove) {
         a = aGeneralPatientRemove = new QAction(this);
         a->setObjectName("aGeneralPatientRemove");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_REMOVE, ctx);
         cmd->setTranslations(Trans::Constants::PATIENTREMOVE_TEXT);
         menu->addAction(cmd, group);
@@ -356,6 +351,7 @@ void MainWindowActionHandler::createGeneralActions(const int actions)
     if (actions & Core::MainWindowActions::A_AppConfigurator) {
         a = aGeneralAppConfigurator = new QAction(this);
         a->setObjectName("aGeneralAppConfigurator");
+        a->setMenuRole(QAction::NoRole);
         a->setIcon(theme()->icon(Constants::ICONPREFERENCES));
         cmd = actionManager()->registerAction(a, Constants::A_APPCONFIGURATOR, ctx);
         cmd->setTranslations(Trans::Constants::APPCONFIGURATOR_TEXT);
@@ -502,14 +498,24 @@ void MainWindowActionHandler::connectGeneralActions()
 Core::ActionContainer *MainWindowActionHandler::menubarContainer(bool createIfNotExist)
 {
     // creates menu bar
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
-    if (createIfNotExist && !menubar) {
-        menubar = actionManager()->createMenuBar(Constants::MENUBAR);
+    ActionContainer *mb = actionManager()->actionContainer(Constants::MENUBAR);
+    if (createIfNotExist && !mb) {
+        mb = actionManager()->createMenuBar(Constants::MENUBAR);
+        mb->appendGroup(Core::Constants::G_GENERAL);
+        mb->appendGroup(Core::Constants::G_FILE);
+        mb->appendGroup(Core::Constants::G_EDIT);
+        mb->appendGroup(Core::Constants::G_FORMAT);
+        mb->appendGroup(Core::Constants::G_PLUGINS);
+        mb->appendGroup(Core::Constants::G_TEMPLATES);
+        mb->appendGroup(Core::Constants::G_PATIENTS);
+        mb->appendGroup(Core::Constants::G_CONFIGURATION);
+        mb->appendGroup(Core::Constants::G_HELP);
+        mb->appendGroup(Core::Constants::G_UPDATE);
 #ifndef Q_WS_MAC
-        setMenuBar(menubar->menuBar());
+        setMenuBar(mb->menuBar());
 #endif
     }
-    return menubar;
+    return mb;
 }
 
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID. Menu bar is automaticcaly created if necessary. */
@@ -517,7 +523,6 @@ void MainWindowActionHandler::createFileMenu()
 {
     // creates menu bar
     ActionContainer *menubar = menubarContainer(true);
-    menubar->appendGroup(Constants::G_FILE);
 
     // Create menu
     ActionContainer *filemenu = actionManager()->createMenu(Constants::M_FILE);
@@ -541,7 +546,6 @@ void MainWindowActionHandler::createTemplatesMenu()
 {
     ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_TEMPLATES);
 
     // Create menu
     ActionContainer *menu = actionManager()->createMenu(Constants::M_TEMPLATES);
@@ -559,7 +563,6 @@ void MainWindowActionHandler::createEditMenu()
 {
     ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_EDIT);
 
     // Edit Menu groups
     ActionContainer *editmenu = actionManager()->createMenu(Constants::M_EDIT);
@@ -581,19 +584,18 @@ void MainWindowActionHandler::createPatientMenu()
 {
     ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_PATIENTS);
 
     ActionContainer *menu = actionManager()->createMenu(Constants::M_PATIENTS);
-    menu->appendGroup(Core::Constants::G_PATIENT_HISTORY);
     menu->appendGroup(Core::Constants::G_PATIENTS);
+    menu->appendGroup(Core::Constants::G_PATIENT_NAVIGATION);
     menu->appendGroup(Core::Constants::G_PATIENT_INFORMATIONS);
 
     menubar->addMenu(menu, Constants::G_PATIENTS);
     menu->setTranslations(Trans::Constants::PATIENTS);
 
-    ActionContainer *historyMenu = actionManager()->createMenu(Constants::M_PATIENTS_HISTORY);
-    historyMenu->setTranslations(Trans::Constants::M_PATIENT_HISTORY_TEXT);
-    menu->addMenu(historyMenu, Constants::G_PATIENT_HISTORY);
+    ActionContainer *historyMenu = actionManager()->createMenu(Constants::M_PATIENTS_NAVIGATION);
+    historyMenu->setTranslations(Trans::Constants::M_PATIENT_NAVIGATION_TEXT);
+    menu->addMenu(historyMenu, Constants::G_PATIENT_NAVIGATION);
 }
 
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
@@ -601,7 +603,7 @@ void MainWindowActionHandler::createFormatMenu()
 {
     ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_FORMAT);
+
     ActionContainer *formatmenu = actionManager()->createMenu(Constants::M_FORMAT);
     menubar->addMenu(formatmenu, Constants::G_FORMAT);
     formatmenu->setTranslations(Trans::Constants::M_FORMAT_TEXT);
@@ -616,7 +618,6 @@ void MainWindowActionHandler::createPluginsMenu()
 {
     ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_PLUGINS);
 
     ActionContainer *confmenu = actionManager()->createMenu(Constants::M_PLUGINS);
     //    confmenu->setEmptyAction(ActionContainer::EA_Hide);
@@ -625,6 +626,7 @@ void MainWindowActionHandler::createPluginsMenu()
     confmenu->appendGroup(Constants::G_PLUGINS_USERMANAGER);
     confmenu->appendGroup(Constants::G_PLUGINS_DRUGS);
     confmenu->appendGroup(Constants::G_PLUGINS_CALENDAR);
+    confmenu->appendGroup(Constants::G_PLUGINS_ACCOUNT);
     confmenu->appendGroup(Constants::G_PLUGINS_OTHERS);
 }
 
@@ -633,7 +635,6 @@ void MainWindowActionHandler::createConfigurationMenu()
 {
     ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_CONFIGURATION);
 
     ActionContainer *confmenu = actionManager()->createMenu(Constants::M_CONFIGURATION);
     //    confmenu->setEmptyAction(ActionContainer::EA_Hide);
@@ -650,7 +651,6 @@ void MainWindowActionHandler::createHelpMenu()
 {
     ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_HELP);
 
     ActionContainer *m = actionManager()->createMenu(Constants::M_HELP);
     menubar->addMenu(m, Constants::G_HELP);
@@ -673,7 +673,6 @@ void MainWindowActionHandler::createUpdateMenu()
 {
     ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
-    menubar->appendGroup(Constants::G_UPDATE);
 
     // Upadate Menu groups
     ActionContainer *upmenu = actionManager()->createMenu(Constants::M_UPDATE);
@@ -917,15 +916,16 @@ void MainWindowActionHandler::createPatientsActions(int actions)
     if (actions & Core::MainWindowActions::A_Patients_New) {
         a = aPatientNew = new QAction(this);
         a->setObjectName("aPatientNew");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_NEW, ctx);
+        cmd->setDefaultKeySequence(Qt::CTRL + Qt::Key_N);
         cmd->setTranslations(Trans::Constants::PATIENTNEW_TEXT);
         menu->addAction(cmd, Constants::G_PATIENTS);
     }
     if (actions & Core::MainWindowActions::A_Patients_ViewIdentity) {
         a = aPatientViewIdentity = new QAction(this);
         a->setObjectName("aPatientViewIdentity");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_VIEWIDENTITY, ctx);
         cmd->setTranslations(Trans::Constants::PATIENTVIEWIDENTITY_TEXT);
         menu->addAction(cmd, Constants::G_PATIENTS);
@@ -933,7 +933,7 @@ void MainWindowActionHandler::createPatientsActions(int actions)
     if (actions & Core::MainWindowActions::A_Patients_Remove) {
         a = aPatientRemove = new QAction(this);
         a->setObjectName("aPatientRemove");
-        a->setIcon(theme()->icon(Constants::ICONPATIENTS));
+        a->setIcon(theme()->icon(Constants::ICONPATIENT));
         cmd = actionManager()->registerAction(a, Constants::A_PATIENT_REMOVE, ctx);
         cmd->setTranslations(Trans::Constants::PATIENTREMOVE_TEXT);
         menu->addAction(cmd, Constants::G_PATIENTS);
@@ -968,6 +968,7 @@ void MainWindowActionHandler::createConfigurationActions(int actions)
         a = aAppConfigurator = new QAction(this);
         a->setObjectName("aAppConfigurator");
         a->setIcon(theme()->icon(Constants::ICONPREFERENCES));
+        a->setMenuRole(QAction::NoRole);
         cmd = actionManager()->registerAction(a, Constants::A_APPCONFIGURATOR, ctx);
         cmd->setTranslations(Trans::Constants::APPCONFIGURATOR_TEXT);
         menu->addAction(cmd, Constants::G_APP_CONFIGURATION);
@@ -1014,7 +1015,7 @@ void MainWindowActionHandler::createConfigurationActions(int actions)
 
         QString lang = settings()->value(Constants::S_PREFEREDLANGUAGE, QLocale().name().left(2)).toString();
         foreach( const QString &loc, loc_lang.keys() ) {
-            i++;
+            ++i;
             QAction *action = new QAction(this);  // QString("&%1 %2").arg(QString::number(i), loc_lang.value(loc)), this);
             action->setText(loc_lang.value(loc));
             action->setObjectName(loc);
@@ -1078,6 +1079,13 @@ void MainWindowActionHandler::createHelpActions(int actions)
         cmd->setTranslations(Trans::Constants::ABOUT_TEXT);
         menu->addAction(cmd, Constants::G_HELP_ABOUT);
     }
+    if (actions & Core::MainWindowActions::A_AppGoToWebSite) {
+        a = aAppGoToWebSite = new QAction(this);
+        a->setIcon(theme()->icon(Constants::ICONINTERNET));
+        cmd = actionManager()->registerAction(a, Constants::A_APPWEBSITE, ctx);
+        cmd->setTranslations(Trans::Constants::WEBSITE_TEXT);
+        menu->addAction(cmd, Constants::G_HELP_ABOUT);
+    }
     if (actions & Core::MainWindowActions::A_PluginsAbout) {
         a = aPlugsAbout = new QAction(this);
         a->setIcon(theme()->icon(Constants::ICONHELP));
@@ -1147,6 +1155,9 @@ void MainWindowActionHandler::connectHelpActions()
 
     if (aCheckUpdate)
         connect(aCheckUpdate, SIGNAL(triggered()), this, SLOT(checkUpdate()));
+
+    if (aAppGoToWebSite)
+        connect(aAppGoToWebSite, SIGNAL(triggered()), this, SLOT(goToAppWebSite()));
 }
 
 void MainWindowActionHandler::createTemplatesActions(int actions)
@@ -1190,14 +1201,14 @@ void MainWindowActionHandler::createTemplatesActions(int actions)
 bool MainWindowActionHandler::debugDialog()
 {
     DebugDialog dlg(this);
-    dlg.showDialog();
+    dlg.exec();
     return true;
 }
 
 /** \brief Shows the standard Preferences dialog. \sa Core::SettingsDialog */
 bool MainWindowActionHandler::applicationPreferences()
 {
-    Core::SettingsDialog dlg(this);
+    Core::SettingsDialog dlg (this);
     dlg.exec();
     return true;
 }
@@ -1206,10 +1217,10 @@ bool MainWindowActionHandler::applicationPreferences()
 bool MainWindowActionHandler::aboutApplication()
 {
     AboutDialog dlg(this);
-    dlg.showDialog();
+    dlg.exec();
     return true;
 }
-/** \shows the standard About Plugins dialog. \sa Core::PluginDialog */
+/** \brief Shows the standard About Plugins dialog. \sa Core::PluginDialog */
 bool MainWindowActionHandler::aboutPlugins()
 {
     Core::PluginDialog dlg(this);
@@ -1281,3 +1292,11 @@ void MainWindowActionHandler::updateCheckerEnd(bool error)
     /** \todo improve this for FreeMedForms (delete only label and progressbar) */
     delete statusBar();
 }
+
+/** \brief If the Core::ISettings::WebSiteUrl is informed in the Core::ISettings::path(), opens the URL. */
+void MainWindowActionHandler::goToAppWebSite()
+{
+    if (!settings()->path(Core::ISettings::WebSiteUrl).isEmpty())
+        QDesktopServices::openUrl(QUrl(settings()->path(Core::ISettings::WebSiteUrl)));
+}
+
