@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -34,9 +34,9 @@
 
 /**
  * \file MainWindowActionHandler.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.0.8
- * \date 20 Oct 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 06 Nov 2011
 */
 
 namespace Utils {
@@ -122,6 +122,7 @@ public Q_SLOTS: // Slots automatically connected to actions is requiered
     virtual bool aboutQt()          {return false;}
     virtual bool debugDialog();
     virtual bool checkUpdate();
+    virtual void goToAppWebSite();
 
 public Q_SLOTS:
     virtual void switchLanguage(QAction * action);
@@ -162,6 +163,7 @@ protected:
     QActionGroup *aLanguageGroup;
 
     QAction *aAppAbout;
+    QAction *aAppGoToWebSite;
     QAction *aPlugsAbout;
     QAction *aAppHelp;
     QAction *aQtAbout;
