@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -32,7 +32,7 @@
 
 /**
  * \file mainwindowactions.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.0.6
  * \date 13 Aug 2009
 */
@@ -83,12 +83,13 @@ public:
         A_DebugDialog            = 0x00010000,
         A_PluginsAbout           = 0x00020000,
         A_FormsAbout             = 0x00040000,
-        A_CheckUpdate            = 0x00080000
+        A_CheckUpdate            = 0x00080000,
+        A_AppGoToWebSite         = 0x00100000
     };
     enum TemplatesAction {
-        A_Templates_New          = 0x00100000,
-        A_Templates_Manager      = 0x00200000,
-        A_Templates_ToogleViewer = 0x00400000
+        A_Templates_New          = 0x00200000,
+        A_Templates_Manager      = 0x00400000,
+        A_Templates_ToogleViewer = 0x00800000
     };
     enum PatientsAction {
         A_Patients_New           = 0x08000000,
