@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -28,7 +28,7 @@
 
 /**
  * \file constants_icons.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 13 June 2010
 */
@@ -83,6 +83,7 @@ const char * const  ICONCOPY =         "editcopy.png";
 const char * const  ICONCUT =          "editcut.png";
 const char * const  ICONPASTE =        "editpaste.png";
 const char * const  ICONCLEAR =        "editclear.png";
+const char * const  ICONCLEARLINEEDIT= "editclearlineedit.png";
 const char * const  ICONADD =          "add.png";
 const char * const  ICONREMOVE =       "remove.png";
 const char * const  ICONMOVEUP =       "1uparrow.png";
@@ -95,6 +96,7 @@ const char * const  ICONOK =           "ok.png";
 const char * const  ICONERROR =        "warning.png";
 const char * const  ICONWARNING =      "warning.png";
 const char * const  ICONFORBIDDEN =    "deconseille.png";
+const char * const  ICONTRANSLATE =    "translate.png";
 
 // menu Navigation
 const char * const  ICONNEXT =         "next.png";
@@ -106,12 +108,18 @@ const char * const  ICONONELEFTARROW = "1leftarrow.png";
 const char * const  ICONTWOLEFTARROW = "2leftarrow.png";
 const char * const  ICONONERIGHTARROW = "1rightarrow.png";
 const char * const  ICONTWORIGHTARROW = "2rightarrow.png";
+const char * const  ICONBOOKMARK      = "bookmark_add.png";
+const char * const  ICONINTERNET      = "www.png";
 
 // menu View
 const char * const  ICONEYES =         "eyes.png";
 const char * const  ICONVIEWSIDE =     "view_sidetree.png";
 const char * const  ICONFULLSCREEN =   "view-fullscreen.png";
 
+// Network
+const char * const  ICONCOMPUTER = "computer.png";
+const char * const  ICONNETWORK =  "network.png";
+
 // menu TextFormat
 const char * const  ICONBOLD =          "format-text-bold.png";
 const char * const  ICONUNDERLINE =     "format-text-underline.png";
@@ -149,10 +157,22 @@ const char * const  ICONCRASHRECOVER = "crashrecoverer.png";
 const char * const  ICONSOFTWAREUPDATEAVAILABLE = "updateavailable.png";
 const char * const  ICONMEDINTUX    =  "medintux.png";
 const char * const  ICONPENCIL    =  "pencil.png";
+const char * const  ICONFORMS    =  "forms.png";
+const char * const  ICONCRITICAL    =  "critical.png";
+const char * const  ICONPATIENTSYNTHESIS  =  "patientsynthesis.png";
 
 // date and time Icons
 const char * const  ICONDATE        =  "date.png";
 
+// categories icons
+const char * const  ICONCATEGORY_MANAGER  =  "category_manager.png";
+const char * const  ICONCATEGORY_ADD  =  "category_add.png";
+const char * const  ICONCATEGORY_REMOVE  =  "category_remove.png";
+
+// Agenda icons
+const char * const  ICONAGENDA =  "x-office-calendar.png";
+const char * const  ICONAGENDA_NEW =  "appointment-new.png";
+
 // menu Users --> MediumSize
 const char * const  ICONUSER          = "user.png";
 const char * const  ICONPERSONAL      = "personal.png";
@@ -160,15 +180,24 @@ const char * const  ICONUSERMANAGER   = "usermanager.png";
 const char * const  ICONEDITUSER      = "edituser.png";
 const char * const  ICONCLEARUSER     = "editclear.png";
 const char * const  ICONDELETEUSER    = "deleteuser.png";
+const char * const  ICONSEARCHUSER    = "searchuser.png";
 const char * const  ICONNEWUSER       = "adduser.png";
+const char * const  ICONNEWUSER_QUICK = "adduser-quick.png";
+const char * const  ICONDOCTOR        = "people-doctor.png";
+const char * const  ICONSECRETARY     = "people-secretary.png";
+const char * const  ICONSERVERADMIN   = "people-serveradmin.png";
 
 // patients icons --> MediumSize / BigSize
+const char * const  ICONPATIENT       = "patient.png";
 const char * const  ICONPATIENTS      = "patientsearch.png";
 const char * const  ICONMALE          = "male.png";
 const char * const  ICONFEMALE        = "female.png";
 const char * const  ICONHERMAPHRODISM = "";
 const char * const  ICONPATIENTFILES  = "patientfiles.png";
 const char * const  ICONPATIENTHISTORY= "patienthistory.png";
+const char * const  ICONCHROMOSOME    = "chromosome.png";
+const char * const  ICONDRUGMODE      = "drugmode.png";
+const char * const  ICONACCOUNTMODE   = "accountancymode.png";
 
 
 }  // end Constants
