@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -28,7 +28,7 @@
 
 /**
  * \file constants_menus.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 13 June 2010
  * \brief Regroups Menus, Actions, Groups and Modes identifiers
@@ -45,14 +45,14 @@ const char * const  M_GENERAL_NEW        = "menuGeneral.New";
 const char * const  M_FILE               = "menuFile";          /*!< \brief Default menu File object name  \ingroup constants_actionmanager */
 const char * const  M_FILE_RECENTFILES   = "menuFile.recents";  /*!< \brief Default menu File object name  \ingroup constants_actionmanager */
 const char * const  M_TEMPLATES          = "menuTemplates";          /*!< \brief Default menu Edit object name  \ingroup constants_actionmanager */
-const char * const  M_EDIT               = "menuEdit";          /*!< \brief Default menu Edit object name  \ingroup constants_actionmanager */
-const char * const  M_PATIENTS           = "menuPatients";          /*!< \brief Default menu Patients object name  \ingroup constants_actionmanager */
-const char * const  M_PATIENTS_HISTORY   = "menuPatients.history";
-const char * const  M_EDITOR_EDIT        = "menu.editor.edition";
-const char * const  M_EDITOR_FILE        = "menu.editor.file";
-const char * const  M_EDIT_SELECT        = "menuEdit.Select";   /*!< \brief Default menu Edit/Select object name  \ingroup constants_actionmanager */
-const char * const  M_EDIT_LIST          = "menuEdit.List";     /*!< \brief Default menu Edit/List object name  \ingroup constants_actionmanager */
-const char * const  M_EDIT_TEMPLATES     = "menuEdit.Templates";     /*!< \brief Default menu Edit/List object name  \ingroup constants_actionmanager */
+const char * const  M_EDIT               = "mEdit";          /*!< \brief Default menu Edit object name  \ingroup constants_actionmanager */
+const char * const  M_PATIENTS           = "mPatients";          /*!< \brief Default menu Patients object name  \ingroup constants_actionmanager */
+const char * const  M_PATIENTS_NAVIGATION= "mPatients.Navigation";
+const char * const  M_EDITOR_EDIT        = "m.editor.edition";
+const char * const  M_EDITOR_FILE        = "m.editor.file";
+const char * const  M_EDIT_SELECT        = "mEdit.Select";   /*!< \brief Default menu Edit/Select object name  \ingroup constants_actionmanager */
+const char * const  M_EDIT_LIST          = "mEdit.List";     /*!< \brief Default menu Edit/List object name  \ingroup constants_actionmanager */
+const char * const  M_EDIT_TEMPLATES     = "mEdit.Templates";     /*!< \brief Default menu Edit/List object name  \ingroup constants_actionmanager */
 const char * const  M_FORMAT             = "menuFormat";        /*!< \brief Default menu Format object name  \ingroup constants_actionmanager */
 const char * const  M_FORMAT_FONT        = "menuFormat.Font";  /*!< \brief Default menu Format object name  \ingroup constants_actionmanager */
 const char * const  M_FORMAT_PARAGRAPH   = "menuFormat.Paragraph";  /*!< \brief Default menu Format object name  \ingroup constants_actionmanager */
@@ -119,7 +119,7 @@ const char * const G_EDIT_OTHER          = "grEdit.Other";     /*!< \brief Defau
 
 // patients menu groups
 const char * const G_PATIENTS             = "grPatients";     /*!< \brief Default group name  \ingroup constants_actionmanager */
-const char * const G_PATIENT_HISTORY      = "grPatientsHist";
+const char * const G_PATIENT_NAVIGATION   = "grPatientsNavigation";
 const char * const G_PATIENT_INFORMATIONS = "grPatientsInfos";
 
 // format menu groups
@@ -148,6 +148,7 @@ const char * const G_FORMAT_OTHER        = "grFormat.Other";      /*!< \brief De
 const char * const G_PLUGINS              =   "grPlugins";
 const char * const G_PLUGINS_USERMANAGER  =   "grPlugins.usermanager";
 const char * const G_PLUGINS_DRUGS        =   "grPlugins.drugs";
+const char * const G_PLUGINS_ACCOUNT      =   "grPlugins.account";
 const char * const G_PLUGINS_CALENDAR     =   "grPlugins.calendar";
 const char * const G_PLUGINS_OTHERS       =   "grPlugins.others";
 
@@ -277,6 +278,7 @@ const char * const  A_CREATEUSER      = "aCreateUser";      /*!< \brief Default
 
 // About Menu Action's name
 const char * const  A_ABOUT              = "actionAbout";             /*!< \brief Default action object name  \ingroup constants_actionmanager */
+const char * const  A_APPWEBSITE         = "actionWebSite";             /*!< \brief Default action object name  \ingroup constants_actionmanager */
 const char * const  A_ABOUTPLUGINS       = "actionPluginsAbout";      /*!< \brief Default action object name  \ingroup constants_actionmanager */
 const char * const  A_ABOUTQT            = "actionAboutQt";           /*!< \brief Default action object name  \ingroup constants_actionmanager */
 const char * const  A_ABOUTFORM          = "actionAboutThisForm";     /*!< \brief Default action object name  \ingroup constants_actionmanager */
@@ -296,12 +298,21 @@ const char * const  A_VIEWUPDATE       = "actionViewUpdate";      /*!< \brief De
 
 
 //modes
-const char * const MODE_PATIENT_SEARCH   = "PatientSearch";
-const char * const MODE_PATIENT_FILE     = "PatientFile";
-const char * const MODE_PATIENT_HISTORY  = "PatientHistory";
-const int          P_MODE_PATIENT_SEARCH = 100;
-const int          P_MODE_PATIENT_HISTORY= 80;
-const int          P_MODE_PATIENT_FILE   = 60;
+const char * const MODE_PATIENT_SEARCH    = "PatientSearch";
+const char * const MODE_PATIENT_FILE      = "central";
+const char * const MODE_PATIENT_HISTORY   = "PatientHistory";
+const char * const MODE_PATIENT_DRUGS     = "drugs";
+const char * const MODE_ACCOUNT           = "account";
+const char * const MODE_AGENDA            = "agenda";
+const char * const MODE_USERMANAGER       = "usermanager";
+
+const int          P_MODE_PATIENT_SEARCH  = 100;
+const int          P_MODE_AGENDA          = 90;
+const int          P_MODE_PATIENT_HISTORY = 80;
+const int          P_MODE_PATIENT_DRUGS   = 60;
+const int          P_MODE_PATIENT_FILE    = 40;
+const int          P_MODE_USERMANAGER     = 30;
+const int          P_MODE_ACCOUNT         = 20;
 
 // Contexts
 const char* const   C_GLOBAL             = "context.global";
@@ -309,17 +320,23 @@ const int           C_GLOBAL_ID          = 0;
 const char* const   C_EDITOR_BASIC       = "context.Editor";
 const char* const   C_EDITOR_TABLE       = "context.Editor.Table";
 const char* const   C_EDITOR_IO          = "context.Editor.IO";
+const char* const   C_EDITOR_ADDTEXT     = "context.Editor.AddText";
 const char* const   C_USERMANAGER        = "context.UserManager";
 
 // EDITOR
 const char * const A_EDITOR_TOOGLETOOLBAR= "actionEditorToggleToolbar";
 const char * const M_EDITOR              = "menu.Editor";
 const char * const M_EDITOR_CONTEXT      = "menu.Popup.Editor";
+const char * const M_EDITOR_ADDTEXT      = "menu.Editor.AddText";
 const char * const G_EDITOR_FILE         = "group.Editor.File";
 const char * const G_EDITOR_CONTEXT      = "group.Editor.Context";
+const char * const G_EDITOR_ADDTEXT      = "group.Editor.AddText";
 const char * const A_EDITOR_FILEOPEN     = "action.Editor.Open";
 const char * const A_EDITOR_FILESAVE     = "action.Editor.Save";
 const char * const A_EDITOR_FILEPRINT    = "action.Editor.Print";
+const char * const A_EDITOR_ADDDATE      = "action.Editor.AddDate";
+const char * const A_EDITOR_ADDUSERNAME    = "action.Editor.AddUserName";
+const char * const A_EDITOR_ADDPATIENTNAME = "action.Editor.AddPatientName";
 
 }  // end Constants
 } // end Core
