@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -28,7 +28,7 @@
 
 /**
  * \file constants_tokensandsettings.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 13 June 2010
 */
@@ -78,8 +78,10 @@ const char * const  TOKEN_USERFULLCONTACT    = "USERFULLCONTACT";
 
 
 // Some path tags
-const char * const  TAG_APPLICATION_RESOURCES_PATH = "%appResources%";
-const char * const  TAG_APPLICATION_THEME_PATH     = "%theme%";
+const char * const  TAG_APPLICATION_RESOURCES_PATH = "__appResources__";
+const char * const  TAG_APPLICATION_THEME_PATH     = "__theme__";
+const char * const  TAG_APPLICATION_COMPLETEFORMS_PATH = "__completeForms__";
+const char * const  TAG_APPLICATION_SUBFORMS_PATH = "__subForms__";
 
 // Settings keys
 const char * const  S_RECENTFILES_GROUP = "RecentFiles";
@@ -93,7 +95,7 @@ const char * const  S_LASTPASSWORD      = "Login/userPassword";
 const char * const  S_DATEFORMAT        = "Dates/Format";
 const char * const  S_PREFEREDLANGUAGE  = "Core/PreferedLanguage";
 
-const char * const  S_PATIENTFORMS_FILENAME  = "Core/PatientFormsFile";
+const char * const  S_DEF_PATIENTFORMS_FILENAME  = "gp_basic1";
 
 const char * const  S_USE_EXTERNAL_DATABASE  = "ExternalDatabase/UseIt";
 const char * const  S_EXTERNAL_DATABASE_LOG  = "ExternalDatabase/Log";
@@ -102,6 +104,7 @@ const char * const  S_EXTERNAL_DATABASE_HOST = "ExternalDatabase/Host";
 const char * const  S_EXTERNAL_DATABASE_PORT = "ExternalDatabase/Port";
 
 const char * const  S_ALWAYS_SAVE_WITHOUT_PROMPTING = "Core/SaveInDatabaseWithoutPrompringUser";
+const char * const  S_ALLOW_VIRTUAL_DATA = "Core/AllowAndUseVirtuals";
 
 }  // end Constants
 } // end Core
