@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -31,7 +31,7 @@
 
 /**
  * \file aboutdialog.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.0.8
  * \date 08 Sept 2009
 */
@@ -63,16 +63,9 @@ class AboutDialog : public QDialog
 public:
     explicit AboutDialog(QWidget *parent = 0);
     virtual ~AboutDialog();
-    void setPages(const QList<IAboutPage*> pages);
-    void showDialog();
-
-private Q_SLOTS:
-    void currentItemChanged(QTreeWidgetItem *cat);
 
 private:
     Ui::AboutDialog *m_ui;
-    QStackedLayout  *m_slayout;
-    QHash<QTreeWidgetItem *, QWidget *> m_Widgets;
 };
 
 } // End Internal
