@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,12 +19,13 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 #include "applicationgeneralpreferences.h"
+
 #include "ui_applicationgeneralpreferences.h"
 
 #include <utils/log.h>
@@ -50,47 +51,14 @@ ApplicationGeneralPreferencesWidget::ApplicationGeneralPreferencesWidget(QWidget
 {
     setObjectName("ApplicationGeneralPreferencesWidget");
     ui->setupUi(this);
-    connect(ui->useExternalDB, SIGNAL(clicked(bool)), this, SLOT(toggleDatabaseConfiguration(bool)));
-    connect(ui->testButton, SIGNAL(clicked()), this, SLOT(on_testButton_clicked()));
     setDatasToUi();
-    ui->log->setIcon(theme()->icon(Core::Constants::ICONEYES));
-    ui->pass->setIcon(theme()->icon(Core::Constants::ICONEYES));
-    ui->pass->toogleEchoMode();
-    if (settings()->value(Core::Constants::S_USE_EXTERNAL_DATABASE, false).toBool())
-        on_testButton_clicked();
-}
-
-void ApplicationGeneralPreferencesWidget::toggleDatabaseConfiguration(bool state)
-{
-    ui->server->setEnabled(state);
-    ui->host->setEnabled(state);
-    ui->log->setEnabled(state);
-    ui->pass->setEnabled(state);
-    ui->port->setEnabled(state);
-    ui->testButton->setEnabled(state);
 }
 
 void ApplicationGeneralPreferencesWidget::setDatasToUi()
 {
     ui->autoSave->setChecked(settings()->value(Core::Constants::S_ALWAYS_SAVE_WITHOUT_PROMPTING).toBool());
     ui->updateCheckingCombo->setCurrentIndex(settings()->value(Utils::Constants::S_CHECKUPDATE).toInt());
-    ui->useExternalDB->setChecked(settings()->value(Core::Constants::S_USE_EXTERNAL_DATABASE).toBool());
-    ui->host->setText(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_HOST).toByteArray()));
-    ui->log->setText(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_LOG).toByteArray()));
-    ui->pass->setText(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_PASS).toByteArray()));
-    ui->port->setValue(QString(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_PORT).toByteArray())).toInt());
-}
-
-static void saveExternalDatabase(Core::ISettings *s, bool use, const QString &host, const QString &log, const QString &pass, const int port)
-{
-    if (s->value(Core::Constants::S_USE_EXTERNAL_DATABASE).toBool() != use) {
-        s->setValue(Core::Constants::S_USE_EXTERNAL_DATABASE, use);
-        s->setValue(Core::Constants::S_EXTERNAL_DATABASE_HOST, QString(host.toAscii().toBase64()));
-        s->setValue(Core::Constants::S_EXTERNAL_DATABASE_PORT, QString::number(port).toAscii().toBase64());
-        s->setValue(Core::Constants::S_EXTERNAL_DATABASE_LOG, QString(log.toAscii().toBase64()));
-        s->setValue(Core::Constants::S_EXTERNAL_DATABASE_PASS, QString(pass.toAscii().toBase64()));
-        Core::ICore::instance()->databaseServerLoginChanged();
-    }
+    ui->virtualDataCheck->setChecked(settings()->value(Core::Constants::S_ALLOW_VIRTUAL_DATA).toBool());
 }
 
 void ApplicationGeneralPreferencesWidget::saveToSettings(Core::ISettings *sets)
@@ -103,7 +71,7 @@ void ApplicationGeneralPreferencesWidget::saveToSettings(Core::ISettings *sets)
 
     s->setValue(Core::Constants::S_ALWAYS_SAVE_WITHOUT_PROMPTING, ui->autoSave->isChecked());
     s->setValue(Utils::Constants::S_CHECKUPDATE, ui->updateCheckingCombo->currentIndex());
-    saveExternalDatabase(s, ui->useExternalDB->isChecked(), ui->host->text(), ui->log->text(), ui->pass->text(), ui->port->value());
+    s->setValue(Core::Constants::S_ALLOW_VIRTUAL_DATA, ui->virtualDataCheck->isChecked());
 }
 
 void ApplicationGeneralPreferencesWidget::writeDefaultSettings(Core::ISettings *s)
@@ -112,29 +80,9 @@ void ApplicationGeneralPreferencesWidget::writeDefaultSettings(Core::ISettings *
     Utils::Log::addMessage("ApplicationGeneralPreferencesWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("FreeDiamsMainWindow"));
     s->setValue(Core::Constants::S_ALWAYS_SAVE_WITHOUT_PROMPTING, true);
     s->setValue(Utils::Constants::S_CHECKUPDATE, Utils::UpdateChecker::Check_AtStartup);
-    s->setValue(Core::Constants::S_USE_EXTERNAL_DATABASE, false);
-    s->sync();
-}
+    s->setValue(Core::Constants::S_ALLOW_VIRTUAL_DATA, true);
 
-void ApplicationGeneralPreferencesWidget::on_testButton_clicked()
-{
-    ui->testConnectionLabel->setText(tr("Test in progress..."));
-    {
-        QSqlDatabase test = QSqlDatabase::addDatabase("QMYSQL", "__APP_CONNECTION_TESTER");
-        test.setHostName(ui->host->text());
-        test.setPort(ui->port->value());
-        test.setUserName(ui->log->text());
-        test.setPassword(ui->pass->text());
-        if (!test.open()) {
-            ui->testButton->setIcon(theme()->icon(Core::Constants::ICONERROR));
-            ui->testConnectionLabel->setText(tr("Connection error: %1").arg(test.lastError().number()));
-            ui->testConnectionLabel->setToolTip(test.lastError().text());
-        } else {
-            ui->testButton->setIcon(theme()->icon(Core::Constants::ICONOK));
-            ui->testConnectionLabel->setText(tr("Connected"));
-        }
-    }
-    QSqlDatabase::removeDatabase("__APP_CONNECTION_TESTER");
+    s->sync();
 }
 
 void ApplicationGeneralPreferencesWidget::changeEvent(QEvent *e)
@@ -164,7 +112,8 @@ ApplicationGeneralPreferencesPage::~ApplicationGeneralPreferencesPage()
 
 QString ApplicationGeneralPreferencesPage::id() const { return objectName(); }
 QString ApplicationGeneralPreferencesPage::name() const { return tkTr(Trans::Constants::GENERAL); }
-QString ApplicationGeneralPreferencesPage::category() const { return tkTr(Trans::Constants::GENERAL); }
+QString ApplicationGeneralPreferencesPage::title() const {return tkTr(Trans::Constants::GENERAL_PREFERENCES);}
+QString ApplicationGeneralPreferencesPage::category() const { return tkTr(Trans::Constants::GENERAL_PREFERENCES); }
 
 void ApplicationGeneralPreferencesPage::resetToDefaults()
 {
@@ -186,13 +135,14 @@ void ApplicationGeneralPreferencesPage::checkSettingsValidity()
     QHash<QString, QVariant> defaultvalues;
     defaultvalues.insert(Core::Constants::S_ALWAYS_SAVE_WITHOUT_PROMPTING, true);
     defaultvalues.insert(Utils::Constants::S_CHECKUPDATE, Utils::UpdateChecker::Check_AtStartup);
-    defaultvalues.insert(Core::Constants::S_USE_EXTERNAL_DATABASE, false);
+    defaultvalues.insert(Core::Constants::S_ALLOW_VIRTUAL_DATA, true);
+    defaultvalues.insert("Dialogs/Settings/LastPage", id());
+    defaultvalues.insert("Dialogs/Settings/LastCategory", category());
 
     foreach(const QString &k, defaultvalues.keys()) {
         if (settings()->value(k) == QVariant())
             settings()->setValue(k, defaultvalues.value(k));
     }
-    settings()->sync();
 }
 
 QWidget *ApplicationGeneralPreferencesPage::createPage(QWidget *parent)
