@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -37,7 +37,7 @@
 
 /**
  * \file applicationgeneralpreferences.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 15 June 2010
 */
@@ -64,8 +64,6 @@ public:
 
 public Q_SLOTS:
     void saveToSettings(Core::ISettings *s = 0);
-    void on_testButton_clicked();
-    void toggleDatabaseConfiguration(bool state);
 
 protected:
     virtual void changeEvent(QEvent *e);
@@ -88,6 +86,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
