@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -53,9 +53,9 @@ LogErrorDebugPage::~LogErrorDebugPage()
 QString LogErrorDebugPage::name() const     { return Trans::ConstantTranslations::tkTr(Trans::Constants::LOGGED_ERRORS); }
 QString LogErrorDebugPage::category() const { return Trans::ConstantTranslations::tkTr(Trans::Constants::ERRORS); }
 
-QWidget *LogErrorDebugPage::widget()
+QWidget *LogErrorDebugPage::createPage(QWidget *parent)
 {
-    QWidget *m_Widget = new QWidget();
+    QWidget *m_Widget = new QWidget(parent);
     QGridLayout *layout = new QGridLayout(m_Widget);
     layout->setSpacing(0);
     layout->setMargin(0);
@@ -82,9 +82,9 @@ QString LogMessageDebugPage::name() const
 QString LogMessageDebugPage::category() const
 { return Trans::ConstantTranslations::tkTr(Trans::Constants::MESSAGES); }
 
-QWidget *LogMessageDebugPage::widget()
+QWidget *LogMessageDebugPage::createPage(QWidget *parent)
 {
-    QWidget *m_Widget = new QWidget();
+    QWidget *m_Widget = new QWidget(parent);
     QGridLayout *layout = new QGridLayout(m_Widget);
     layout->setSpacing(0);
     layout->setMargin(0);
@@ -108,9 +108,9 @@ SettingDebugPage::~SettingDebugPage()
 {
 }
 
-QWidget *SettingDebugPage::widget()
+QWidget *SettingDebugPage::createPage(QWidget *parent)
 {
-    QWidget *m_Widget = new QWidget();
+    QWidget *m_Widget = new QWidget(parent);
     QGridLayout *layout = new QGridLayout(m_Widget);
     layout->setSpacing(0);
     layout->setMargin(0);
