@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -48,7 +48,7 @@ public:
     QString name() const;
     QString category() const;
 
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent = 0);
 };
 
 
@@ -63,7 +63,7 @@ public:
     QString name() const;
     QString category() const;
 
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent = 0);
 };
 
 
@@ -78,9 +78,7 @@ public:
     QString name() const     { return tr("Settings"); }
     QString category() const { return tr("Settings"); }
 
-    void refreshContents();
-
-    QWidget *widget();
+    QWidget *createPage(QWidget *parent = 0);
 
 private:
     QPointer<QWidget> m_Widget;
