@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -33,7 +33,7 @@
 
 /**
  * \file debugdialog.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.0.9
  * \date 09 Sept 2009
 */
@@ -62,23 +62,12 @@ class DebugDialog : public QDialog
 public:
     explicit DebugDialog(QWidget * parent);
     ~DebugDialog();
-    void showDialog();
-
-private Q_SLOTS:
-//    void done( int code );
-    void currentItemChanged(QTreeWidgetItem *cat);
-
-    void setPages(const QList<IDebugPage*> pages);
 
 private Q_SLOTS:
     void on_fullScreenButton_clicked();
     void on_butSend_clicked();
     void onSendMessage_done();
     bool on_butSave_clicked();
-//    void on_expandedMessagesButton_clicked();
-//    void on_chronologicMessagesButton_clicked();
-//    void on_expandedErrorButton_clicked();
-//    void on_chronologicErrorButton_clicked();
 
 private:
     Ui::DebugDialog *m_ui;
