@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -27,6 +27,7 @@
 #define IABOUTPAGE_H
 
 #include <coreplugin/core_exporter.h>
+#include <coreplugin/igenericpage.h>
 
 #include <QtCore/QObject>
 #include <QtCore/QString>
@@ -34,7 +35,7 @@
 
 /**
  * \file iaboutpage.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 13 June 2010
  * \class Core::IAboutPage
@@ -43,19 +44,14 @@
 
 namespace Core {
 
-class CORE_EXPORT IAboutPage : public QObject
+class CORE_EXPORT IAboutPage : public Core::IGenericPage
 {
     Q_OBJECT
 public:
-    IAboutPage(QObject *parent = 0) : QObject(parent) {}
+    IAboutPage(QObject *parent = 0) : Core::IGenericPage(parent) {}
     virtual ~IAboutPage() {}
 
-    virtual QString id() const = 0;
-    virtual QString name() const = 0;
-    virtual QString category() const = 0;
-
-    // widget will be deleted after the show
-    virtual QWidget *widget() = 0;
+    QString title() const {return name();}
 };
 
 } // namespace Core
