@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -31,9 +31,9 @@
 #include <QVariant>
 /**
  * \file icommandline.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.0.10
- * \date 09 Aug 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 09 Aug 2011
  * \class Core::ICommandLine
  * \brief Command line parser interface.
 */
@@ -42,8 +42,18 @@ namespace Core {
 
 class CORE_EXPORT ICommandLine : public QObject
 {
+    Q_OBJECT
 public:
-    ICommandLine() {}
+    enum Params {
+        Chrono = 1000,
+        ConfigFile,
+        RunningUnderWine,
+        ClearUserDatabases,
+        CreateVirtuals,
+        ResetUserPreferences
+    };
+
+    ICommandLine(QObject *parent = 0) : QObject(parent) {}
     virtual ~ICommandLine() {}
 
     virtual QVariant value(int param, const QVariant &def = QVariant()) const = 0;
