@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -35,7 +35,7 @@
 
 /**
  * \file ipatient.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.5.0
  * \date 23 Aug 2010
 */
@@ -60,22 +60,24 @@ public:
         UsersUidList,
         GroupsUidList,
         FamilyUid,
-        IconizedGender,
         Title,
         TitleIndex,
         FullName,
         BirthName,
-        SecondName,
+        SecondName,  // 10
         Firstname,
         Gender,
         GenderIndex,
+        IconizedGender,
+        GenderPixmap,
         DateOfBirth,
         Age,
         YearsOld,
         MaritalStatus,
-        Profession,
+        Profession,  // 20
         DateOfDeath,
-        Photo,
+        Photo_32x32,
+        Photo_64x64,
 
         // Contact
         Street,
@@ -85,7 +87,7 @@ public:
         AddressNote,
         FullAddress,
         Mails,
-        Tels,
+        Tels,  // 30
         Faxes,
 
         // Biometrics
@@ -97,23 +99,23 @@ public:
         Creatinine,
         CreatinineUnit,
         CreatinClearance,
-        CreatinClearanceUnit,
+        CreatinClearanceUnit,  // 40
 
         // Drugs and diseases
         // Allergies
         DrugsAllergiesWithoutPrecision,
-        DrugsUidAllergies,     //  see tkSerializer --> string<->stringlist
-        DrugsAtcAllergies,     //  see tkSerializer --> string<->stringlist
-        DrugsInnAllergies,     //  see tkSerializer --> string<->stringlist
+        DrugsUidAllergies,
+        DrugsAtcAllergies,
+        DrugsInnAllergies,
         // Intolerances
         DrugsIntolerancesWithoutPrecision,
-        DrugsUidIntolerances,     //  see tkSerializer --> string<->stringlist
-        DrugsAtcIntolerances,     //  see tkSerializer --> string<->stringlist
-        DrugsInnIntolerances,     //  see tkSerializer --> string<->stringlist
-        DrugsInnAtcIntolerances,     //  see tkSerializer --> string<->stringlist
+        DrugsUidIntolerances,
+        DrugsAtcIntolerances,
+        DrugsInnIntolerances,
+        DrugsInnAtcIntolerances,
 
         DrugsChronicTherapeutics,
-        ICD10Diseases,      //  see tkSerializer --> string<->stringlist
+        ICD10Diseases,
 
         // For debugging purpose
         PractitionnerLkID,
@@ -126,22 +128,31 @@ public:
     virtual void clear() = 0;
     virtual bool has(const int ref) const = 0;
 
+    QString uuid() const {return data(Uid).toString();}
+
     int	columnCount(const QModelIndex & = QModelIndex()) const {return NumberOfColumns;}
     int	rowCount(const QModelIndex & = QModelIndex()) const {return 1;}
 
+    virtual QModelIndex currentPatientIndex() const = 0;
+
     virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const = 0;
-    virtual QVariant data(int column) const {return data(index(0, column));}
+    virtual QVariant data(int column) const = 0;
 
     /** \todo remove this and use setData instead **/
-    virtual bool setValue(int ref, const QVariant &value) {return setData(index(0,ref), value);}
+    virtual bool setValue(int ref, const QVariant &value) = 0;
 
     virtual QString toXml() const = 0;
     virtual bool fromXml(const QString &xml) = 0;
 
     void replaceTokens(QString &stringWillBeModified);
 
+    virtual void hidePatientBar() = 0;
+    virtual void showPatientBar() = 0;
+    virtual bool isPatientBarVisible() const = 0;
+
 Q_SIGNALS:
     void currentPatientChanged();
+    void patientCreated(const QString &uuid);
 };
 
 }  // End Core
