@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -29,6 +29,8 @@
 #include <coreplugin/core_exporter.h>
 #include <coreplugin/isettings.h>
 
+#include <utils/databaseconnector.h>
+
 #include <QSettings>
 #include <QStringList>
 #include <QDir>
@@ -41,63 +43,80 @@ QT_END_NAMESPACE
 
 /**
  * \file settings_p.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 23 Mar 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 01 Jun 2011
 */
 
 namespace Core {
 namespace Internal {
 
-class CORE_EXPORT SettingsPrivate : public ISettings, public QSettings
+class CORE_EXPORT SettingsPrivate : public ISettings
 {
+    Q_OBJECT
 public:
-    SettingsPrivate(QObject *parent = 0, const QString &appName = QString::null, const QString &fileName = QString::null );
+    SettingsPrivate(QObject *parent = 0, const QString &appName = QString::null, const QString &fileName = QString::null);
     ~SettingsPrivate();
 
+    void setUserSettings(const QString &file);
+    QString userSettings() const;
+
     QSettings *getQSettings();
 
     // QSettings wrappers
-    inline void beginGroup ( const QString & prefix ) { QSettings::beginGroup(prefix); }
-    inline QStringList childGroups () const { return QSettings::childGroups(); }
-    inline QStringList childKeys () const { return QSettings::childKeys(); }
-    inline bool contains ( const QString & key ) const { return QSettings::contains(key); }
-    inline void endGroup () { QSettings::endGroup(); }
-    inline QString fileName () const { return QSettings::fileName(); }
-    inline QString group () const { return QSettings::group();}
+    void beginGroup(const QString &prefix);
+    QStringList childGroups() const;
+    QStringList childKeys() const;
+    bool contains(const QString &key) const;
+    void endGroup();
+    QString fileName() const;
+    QString group() const;
 
-    inline void setValue( const QString & key, const QVariant & value ) { QSettings::setValue(key,value); }
-    inline QVariant value( const QString & key, const QVariant & defaultValue = QVariant() ) const { return QSettings::value(key,defaultValue); }
+    void setValue(const QString &key, const QVariant &value);
+    QVariant value(const QString &key, const QVariant &defaultValue = QVariant()) const;
 
-    inline void sync() {QSettings::sync();}
+    void sync();
 
     // first time running ?
-    bool firstTimeRunning() const;
-    void noMoreFirstTimeRunning();
+    bool firstTimeRunning(const QString &subProcess = QString::null) const;
+    void setFirstTimeRunning(const bool state, const QString &subProcess = QString::null);
+    void noMoreFirstTimeRunning(const QString &subProcess = QString::null);
+
     QString licenseApprovedApplicationNumber() const;
     void setLicenseApprovedApplicationNumber(const QString &version);
+    void setDefaultForm(const QString &formUid);
+    QString defaultForm() const;
 
     // manage mainwindow
-    void restoreState( QMainWindow * window, const QString & prefix = QString::null );
-    void saveState( QMainWindow * window, const QString & prefix = QString::null );
+    void restoreState(QMainWindow *window, const QString &prefix = QString::null);
+    void saveState(QMainWindow *window, const QString &prefix = QString::null);
 
     // paths
-    void setPath( const int type, const QString & absPath );
-    QString path( const int type ) const;
+    void setPath(const int type, const QString &absPath);
+    QString path(const int type) const;
 
     // for debugging functions : to treewidget and to string
-    QTreeWidget* getTreeWidget( QWidget * parent ) const;
+    QTreeWidget *getTreeWidget(QWidget *parent) const;
     QString toString() const;
 
+    // Network datas
+    Utils::DatabaseConnector databaseConnector() const;
+    void setDatabaseConnector(Utils::DatabaseConnector &dbConnector);
+    void readDatabaseConnector();
+    void writeDatabaseConnector();
+
     // values management
-    void appendToValue( const QString &key, const QString &value );    
+    void appendToValue(const QString &key, const QString &value);
 
 protected:
     QString getIniFile(const QString &name = QString::null, const QString &version = QString::null);
 
 private:
-    QHash< int, QString >   m_Enum_Path;
-    bool                    m_FirstTime;
+    QSettings *m_NetworkSettings, *m_UserSettings;
+    QHash< int, QString > m_Enum_Path;
+    bool m_FirstTime;
+    Utils::DatabaseConnector m_DbConnector;
+    bool m_NeedsSync;
 };
 
 } // End Internal
