@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -49,10 +49,10 @@
 #include "dosagemodel.h"
 
 #include <drugsbaseplugin/constants.h>
-#include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/drugsmodel.h>
 #include <drugsbaseplugin/drugsbase.h>
 #include <drugsbaseplugin/drugsdatabaseselector.h>
+#include <drugsbaseplugin/idrug.h>
 
 #include <utils/global.h>
 #include <utils/log.h>
@@ -69,7 +69,6 @@
 #include <QSqlError>
 #include <QApplication>
 #include <QStringList>
-#include <QUuid>
 #include <QDateTime>
 #include <QColor>
 #include <QLocale>
@@ -205,6 +204,7 @@ bool DosageModel::setData(const QModelIndex &index, const QVariant &value, int r
     Q_ASSERT_X(!m_UID.isNull(), "DosageModel::setData", "before using the dosagemodel, you must specify the UID of the related drug");
     if (! index.isValid())
         return false;
+
     if (role == Qt::EditRole || role == Qt::DisplayRole) {
 
         QVariant q = data(index);
@@ -231,19 +231,32 @@ bool DosageModel::setData(const QModelIndex &index, const QVariant &value, int r
 //        }
 
         if (index.column()==Dosages::Constants::Route) {
-            if (value.toString().contains(QRegExp("\\D"))) {
-                // Fing the routeId
-                int routeId = drugsBase()->getRouteId(value.toString());
-                if (!QSqlTableModel::setData(index, routeId, role)) {
-                    Utils::Log::addError(this, "Can not set data to QSqlTableModel", __FILE__, __LINE__);
-                    Utils::Log::addQueryError(this, query(), __FILE__, __LINE__);
-                    return false;
+//            qWarning() << "DOSAGE -> setData Route" << value.toString();
+            m_Route = value.toString();
+            // Find the routeId
+            IDrug *drug = m_DrugsModel->getDrug(m_UID);
+            int routeId = -1;
+            for(int i = 0; i < drug->drugRoutes().count(); ++i) {
+                if (drug->drugRoutes().at(i)->label()==value.toString()) {
+                    routeId = drug->drugRoutes().at(i)->routeId();
+                    break;
                 }
             }
+//            qWarning() << "    routeId" << routeId  << drug->drugRoutes();
+            if (routeId != -1) {
+                if (!QSqlTableModel::setData(QSqlTableModel::index(index.row(), Dosages::Constants::RouteId), routeId, role)) {
+                    LOG_ERROR("Can not set data to QSqlTableModel");
+                    LOG_QUERY_ERROR(query());
+                    return false;
+                }
+            } else {
+                LOG_ERROR("Route not found: " + value.toString());
+            }
+            return true;
         } else {
             if (!QSqlTableModel::setData(index, value, role)) {
-                Utils::Log::addError(this, "Can not set data to QSqlTableModel", __FILE__, __LINE__);
-                Utils::Log::addQueryError(this, query(), __FILE__, __LINE__);
+                LOG_ERROR("Can not set data to QSqlTableModel");
+                LOG_QUERY_ERROR(query());
                 return false;
             }
         }
@@ -282,6 +295,23 @@ QVariant DosageModel::data(const QModelIndex & item, int role) const
     case Qt::DisplayRole:
     case Qt::EditRole:
         {
+            if (item.column() == Dosages::Constants::Route) {
+//                qWarning() << "DOSAGE data Route" << m_Route;
+                if (m_Route.isEmpty()) {
+                    // get routeId
+                    int routeId = index(item.row(), Dosages::Constants::RouteId).data().toInt();
+                    // get label (from IDrug)
+                    IDrug *drug = m_DrugsModel->getDrug(m_UID);
+                    for(int i = 0; i < drug->drugRoutes().count(); ++i) {
+                        if (drug->drugRoutes().at(i)->routeId()==routeId) {
+                            m_Route = drug->drugRoutes().at(i)->label();
+                            break;
+                        }
+                    }
+//                    qWarning() << "   getting route label" << routeId << m_Route;
+                }
+                return m_Route;
+            }
             return QSqlTableModel::data(item, role);
             break;
         }
@@ -304,7 +334,7 @@ bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
     Q_ASSERT_X(!m_UID.isNull(), "DosageModel::insertRows", "before inserting row, you must specify the UID of the related drug");
     if (WarnDebuggingDatas)
         qWarning() << "DosageModel::insertRows (row:" << row << ";count" << count << ")" << parent;
-    QString userUuid = user()->value(Core::IUser::Uuid).toString();
+    QString userUuid = user()->uuid();
     int i;
     int createdRow;
     bool toReturn = true;
@@ -314,39 +344,41 @@ bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
             Utils::Log::addError(this, tr("Model Error : unable to insert a row"),__FILE__, __LINE__);
             toReturn = false;
         } else {
-            setData(index(createdRow, Dosages::Constants::Uuid) , QUuid::createUuid().toString());
+            setData(index(createdRow, Dosages::Constants::Uuid), Utils::Database::createUid());
             if (drugsBase()->actualDatabaseInformations())
-                setData(index(createdRow, Dosages::Constants::DrugsDatabaseIdentifiant) , drugsBase()->actualDatabaseInformations()->identifiant);
-            setData(index(createdRow, Dosages::Constants::DrugUid_LK) , m_UID);
-            setData(index(createdRow, Dosages::Constants::INN_LK) , -1);
-            setData(index(createdRow, Dosages::Constants::InnLinkedDosage) , "");
-            setData(index(createdRow, Dosages::Constants::IntakesTo) , 1);
-            setData(index(createdRow, Dosages::Constants::IntakesFrom) , 1);
-            setData(index(createdRow, Dosages::Constants::IntakesUsesFromTo) , false);
+                setData(index(createdRow, Dosages::Constants::DrugsDatabaseIdentifiant), drugsBase()->actualDatabaseInformations()->identifiant);
+            setData(index(createdRow, Dosages::Constants::DrugUid_LK), m_UID);
+            setData(index(createdRow, Dosages::Constants::INN_LK), -1);
+            setData(index(createdRow, Dosages::Constants::InnLinkedDosage), "");
+            setData(index(createdRow, Dosages::Constants::IntakesTo), 1);
+            setData(index(createdRow, Dosages::Constants::IntakesFrom), 1);
+            setData(index(createdRow, Dosages::Constants::IntakesUsesFromTo), false);
             QString s = settings()->value(DrugsDB::Constants::S_PROTOCOL_DEFAULT_SCHEMA).toString();
             if (s.isEmpty()) {
-                setData(index(createdRow, Dosages::Constants::IntakesScheme) , m_DrugsModel->drugData(m_UID, Drug::AvailableForms).toStringList().at(0));
+                QStringList list = m_DrugsModel->drugData(m_UID, Constants::Drug::AvailableForms).toStringList();
+                if (!list.isEmpty())
+                    setData(index(createdRow, Dosages::Constants::IntakesScheme), list.at(0));
             } else if (s=="||") {
-                setData(index(createdRow, Dosages::Constants::IntakesScheme) , tkTr(Trans::Constants::INTAKES, 1));
+                setData(index(createdRow, Dosages::Constants::IntakesScheme), tkTr(Trans::Constants::INTAKES, 1));
             } else {
-                setData(index(createdRow, Dosages::Constants::IntakesScheme) , s);
+                setData(index(createdRow, Dosages::Constants::IntakesScheme), s);
             }
             setData(index(createdRow, Dosages::Constants::Period), 1);
-            setData(index(createdRow, Dosages::Constants::PeriodScheme) , tkTr(Trans::Constants::DAY_S));
-            setData(index(createdRow, Dosages::Constants::DurationTo) , 1);
-            setData(index(createdRow, Dosages::Constants::DurationFrom) , 1);
-            setData(index(createdRow, Dosages::Constants::DurationUsesFromTo) , false);
-            setData(index(createdRow, Dosages::Constants::DurationScheme) , tkTr(Trans::Constants::MONTH_S));
-            setData(index(createdRow, Dosages::Constants::IntakesIntervalOfTime) , 0);
-            setData(index(createdRow, Dosages::Constants::MinAge) , 0);
-            setData(index(createdRow, Dosages::Constants::MaxAge) , 0);
-            setData(index(createdRow, Dosages::Constants::MinWeight) , 0);
-            setData(index(createdRow, Dosages::Constants::MinClearance) , 0);
-            setData(index(createdRow, Dosages::Constants::MaxClearance) , 0);
-            setData(index(createdRow, Dosages::Constants::SexLimitedIndex) , 0);
-            setData(index(createdRow, Dosages::Constants::Note) , QVariant());
-            setData(index(createdRow, Dosages::Constants::CreationDate) , QDateTime::currentDateTime());
-            setData(index(createdRow, Dosages::Constants::Transmitted) , QVariant());
+            setData(index(createdRow, Dosages::Constants::PeriodScheme), tkTr(Trans::Constants::DAY_S));
+            setData(index(createdRow, Dosages::Constants::DurationTo), 1);
+            setData(index(createdRow, Dosages::Constants::DurationFrom), 1);
+            setData(index(createdRow, Dosages::Constants::DurationUsesFromTo), false);
+            setData(index(createdRow, Dosages::Constants::DurationScheme), tkTr(Trans::Constants::MONTH_S));
+            setData(index(createdRow, Dosages::Constants::IntakesIntervalOfTime), 0);
+            setData(index(createdRow, Dosages::Constants::MinAge), 0);
+            setData(index(createdRow, Dosages::Constants::MaxAge), 0);
+            setData(index(createdRow, Dosages::Constants::MinWeight), 0);
+            setData(index(createdRow, Dosages::Constants::MinClearance), 0);
+            setData(index(createdRow, Dosages::Constants::MaxClearance), 0);
+            setData(index(createdRow, Dosages::Constants::SexLimitedIndex), 0);
+            setData(index(createdRow, Dosages::Constants::Note), QVariant());
+            setData(index(createdRow, Dosages::Constants::CreationDate), QDateTime::currentDateTime());
+            setData(index(createdRow, Dosages::Constants::Transmitted), QVariant());
         }
     }
     return toReturn;
@@ -404,25 +436,25 @@ bool DosageModel::submitAll()
         return true;
     } else {
         m_DirtyRows = safe;
-        Utils::Log::addQueryError(this, QSqlTableModel::query(), __FILE__, __LINE__);
+        LOG_QUERY_ERROR(query());
     }
     //    reset();
     return false;
 }
 
 /**
-  \brief Filter the model from the drug CIS and if possible for the inn prescriptions.
+  \brief Filter the model from the drug DID and if possible for the inn prescriptions.
 */
-bool DosageModel::setDrugUID(const QVariant &drugUid)
+bool DosageModel::setDrugId(const QVariant &drugId)
 {
-    if (drugUid == m_UID)
+    if (drugId == m_UID)
         return true;
-    m_UID = drugUid;
+    m_UID = drugId;
     QString filter = QString("%1='%2'").arg(record().fieldName(Dosages::Constants::DrugUid_LK)).arg(m_UID.toString());
 
     int inn = -1;
     if (m_DrugsModel)
-        inn = m_DrugsModel->drugData(drugUid, Constants::Drug::MainInnCode).toInt();
+        inn = m_DrugsModel->drugData(drugId, Constants::Drug::MainInnCode).toInt();
 
     if (inn!=-1) {
         // add INN_LK
@@ -432,20 +464,20 @@ bool DosageModel::setDrugUID(const QVariant &drugUid)
         innFilter = QString("(%1) AND (%2='%3')")
                     .arg(innFilter)
                     .arg(record().fieldName(Dosages::Constants::InnLinkedDosage))
-                    .arg(m_DrugsModel->drugData(drugUid, Constants::Drug::MainInnDosage).toString());
+                    .arg(m_DrugsModel->drugData(drugId, Constants::Drug::MainInnDosage).toString());
         filter = QString("((%1) OR (%2))").arg(filter).arg(innFilter);
     }        
 
     if (WarnDebuggingDatas)
-        qWarning() << "DosageModel filter" << filter << __FILE__ << __LINE__;
+        LOG("DosageModel filter" + filter);
 
     setFilter(filter);
     select();
     return true;
 }
 
-/** \brief Return the actual drug's CIS */
-QVariant DosageModel::drugUID()
+/** \brief Return the actual drug's DID */
+QVariant DosageModel::drugId()
 {
     return m_UID;
 }
@@ -492,26 +524,25 @@ void DosageModel::toPrescription(const int row)
 {
     Q_ASSERT(m_DrugsModel);
     Q_ASSERT(m_DrugsModel->containsDrug(m_UID));
-    /** \todo add a mutext ? */
     QHash<int,int> prescr_dosage;
-    prescr_dosage.insert(Constants::Prescription::UsedDosage ,           Dosages::Constants::Uuid);
-    prescr_dosage.insert(Constants::Prescription::IntakesFrom ,          Dosages::Constants::IntakesFrom);
-    prescr_dosage.insert(Constants::Prescription::IntakesTo ,            Dosages::Constants::IntakesTo);
-    prescr_dosage.insert(Constants::Prescription::IntakesUsesFromTo ,    Dosages::Constants::IntakesUsesFromTo);
-    prescr_dosage.insert(Constants::Prescription::IntakesScheme ,        Dosages::Constants::IntakesScheme);
-    prescr_dosage.insert(Constants::Prescription::Route ,                Dosages::Constants::Route);
-    prescr_dosage.insert(Constants::Prescription::Period ,               Dosages::Constants::Period);
-    prescr_dosage.insert(Constants::Prescription::PeriodScheme ,         Dosages::Constants::PeriodScheme);
-    prescr_dosage.insert(Constants::Prescription::DurationFrom ,         Dosages::Constants::DurationFrom);
-    prescr_dosage.insert(Constants::Prescription::DurationTo ,           Dosages::Constants::DurationTo);
-    prescr_dosage.insert(Constants::Prescription::DurationUsesFromTo,    Dosages::Constants::DurationUsesFromTo);
-    prescr_dosage.insert(Constants::Prescription::DurationScheme ,       Dosages::Constants::DurationScheme);
-    prescr_dosage.insert(Constants::Prescription::IntakesIntervalOfTime ,Dosages::Constants::IntakesIntervalOfTime);
-    prescr_dosage.insert(Constants::Prescription::IntakesIntervalScheme ,Dosages::Constants::IntakesIntervalScheme);
-    prescr_dosage.insert(Constants::Prescription::Note ,                 Dosages::Constants::Note);
-    prescr_dosage.insert(Constants::Prescription::DailyScheme ,          Dosages::Constants::DailyScheme);
-    prescr_dosage.insert(Constants::Prescription::MealTimeSchemeIndex ,  Dosages::Constants::MealScheme);
-    prescr_dosage.insert(Constants::Prescription::IsALD ,                Dosages::Constants::IsALD);
+    prescr_dosage.insert(Constants::Prescription::UsedDosage,           Dosages::Constants::Uuid);
+    prescr_dosage.insert(Constants::Prescription::IntakesFrom,          Dosages::Constants::IntakesFrom);
+    prescr_dosage.insert(Constants::Prescription::IntakesTo,            Dosages::Constants::IntakesTo);
+    prescr_dosage.insert(Constants::Prescription::IntakesUsesFromTo,    Dosages::Constants::IntakesUsesFromTo);
+    prescr_dosage.insert(Constants::Prescription::IntakesScheme,        Dosages::Constants::IntakesScheme);
+    prescr_dosage.insert(Constants::Prescription::RouteId,              Dosages::Constants::RouteId);
+    prescr_dosage.insert(Constants::Prescription::Period,               Dosages::Constants::Period);
+    prescr_dosage.insert(Constants::Prescription::PeriodScheme,         Dosages::Constants::PeriodScheme);
+    prescr_dosage.insert(Constants::Prescription::DurationFrom,         Dosages::Constants::DurationFrom);
+    prescr_dosage.insert(Constants::Prescription::DurationTo,           Dosages::Constants::DurationTo);
+    prescr_dosage.insert(Constants::Prescription::DurationUsesFromTo,   Dosages::Constants::DurationUsesFromTo);
+    prescr_dosage.insert(Constants::Prescription::DurationScheme,       Dosages::Constants::DurationScheme);
+    prescr_dosage.insert(Constants::Prescription::IntakesIntervalOfTime,Dosages::Constants::IntakesIntervalOfTime);
+    prescr_dosage.insert(Constants::Prescription::IntakesIntervalScheme,Dosages::Constants::IntakesIntervalScheme);
+    prescr_dosage.insert(Constants::Prescription::Note,                 Dosages::Constants::Note);
+    prescr_dosage.insert(Constants::Prescription::DailyScheme,          Dosages::Constants::DailyScheme);
+    prescr_dosage.insert(Constants::Prescription::MealTimeSchemeIndex,  Dosages::Constants::MealScheme);
+    prescr_dosage.insert(Constants::Prescription::IsALD,                Dosages::Constants::IsALD);
     foreach(const int i, prescr_dosage.keys()) {
         m_DrugsModel->setDrugData(m_UID, i, data(index(row, prescr_dosage.value(i))));
     }
