@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -37,7 +37,7 @@
 
 /**
  * \file dosagemodel.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.5.0
  * \date 23 Sept 2010
 */
@@ -86,8 +86,8 @@ public:
 
     void setTable(const QString &) {}
 
-    virtual bool setDrugUID(const QVariant &uid);
-    QVariant drugUID();
+    virtual bool setDrugId(const QVariant &drugId);
+    QVariant drugId();
 
     QStringList isDosageValid(const int row);
     bool isDirty(const int row) const;
@@ -138,6 +138,7 @@ private:
     QVariant m_UID;
     QSet<int> m_DirtyRows;
     QSet<int> m_DirtyInnLkRows;
+    mutable QString m_Route;
 };
 
 }  // End Internal
