@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -18,22 +18,46 @@
  *  along with this program (COPYING.FREEMEDFORMS file).                   *
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
+
+/**
+  \namespace DrugsDB
+  \brief Namespace reserved for the DrugsDB plugin.
+  The DrugsDB namespace includes:
+  - All database accesses
+  - All constants related to drugs
+  - Interaction engines
+  - Save/Load abilities (XML prescription files)
+  - Print abilities
+*/
+
 #include "drugsbaseplugin.h"
 #include "drugstemplateprinter.h"
 #include "drugsbase.h"
 #include "drugsdatabaseselector.h"
 
+#include "engines/drugdruginteractionengine.h"
+#include "engines/pimengine.h"
+#include "engines/allergyengine.h"
+
 #include <utils/log.h>
 
 #include <coreplugin/dialogs/pluginaboutpage.h>
 #include <coreplugin/icore.h>
+#include <coreplugin/itheme.h>
 #include <coreplugin/translators.h>
 
 #include <QtCore/QtPlugin>
 
 using namespace DrugsDB;
 
-DrugsBasePlugin::DrugsBasePlugin()
+static inline Core::ITheme *theme()  { return Core::ICore::instance()->theme(); }
+static inline void messageSplash(const QString &s) {theme()->messageSplashScreen(s); }
+
+DrugsBasePlugin::DrugsBasePlugin() :
+    IPlugin(),
+    m_DDIEngine(0),
+    m_PimEngine(0),
+    m_AllergyEngine(0)
 {
     if (Utils::Log::warnPluginsCreation()) {
 #ifdef FREEDIAMS
@@ -42,10 +66,35 @@ DrugsBasePlugin::DrugsBasePlugin()
         qWarning() << "creating FREEMEDFORMS::DrugsBasePlugin";
 #endif
     }
+
+    // Add Translator to the Application
+    Core::ICore::instance()->translators()->addNewTranslator("drugsbaseplugin");
+
+    // Create the drugs engines
+    m_AllergyEngine = new DrugsDB::Internal::DrugAllergyEngine(this);
+    addObject(m_AllergyEngine);
+    m_DDIEngine = new DrugsDB::Internal::DrugDrugInteractionEngine(this);
+    addObject(m_DDIEngine);
+    m_PimEngine = new DrugsDB::Internal::PimEngine(this);
+    addObject(m_PimEngine);
 }
 
 DrugsBasePlugin::~DrugsBasePlugin()
 {
+    removeObject(m_DDIEngine);
+    if (m_DDIEngine)
+        delete m_DDIEngine;
+    m_DDIEngine = 0;
+
+    removeObject(m_PimEngine);
+    if (m_PimEngine)
+        delete m_PimEngine;
+    m_PimEngine = 0;
+
+    removeObject(m_AllergyEngine);
+    if (m_AllergyEngine)
+        delete m_AllergyEngine;
+    m_AllergyEngine = 0;
 }
 
 bool DrugsBasePlugin::initialize(const QStringList &arguments, QString *errorString)
@@ -55,15 +104,6 @@ bool DrugsBasePlugin::initialize(const QStringList &arguments, QString *errorStr
     Q_UNUSED(arguments);
     Q_UNUSED(errorString);
 
-//    DrugsDatabaseSelector::instance();
-//    DrugsDatabaseSelector::instance()->getAllDatabaseInformations();
-
-    // Add Translator to the Application
-    Core::ICore::instance()->translators()->addNewTranslator("drugsbaseplugin");
-
-    // initialize DrugsBase
-    Internal::DrugsBase::instance();
-
     return true;
 }
 
@@ -72,8 +112,18 @@ void DrugsBasePlugin::extensionsInitialized()
     if (Utils::Log::warnPluginsCreation())
         qWarning() << "DrugsBasePlugin::extensionsInitialized";
 
+    messageSplash(tr("Initializing drugs database plugin..."));
+
+    // initialize DrugsBase
+    Internal::DrugsBase::instance();
+
     addAutoReleasedObject(new Core::PluginAboutPage(pluginSpec(), this));
     addAutoReleasedObject(new DrugsDB::Internal::DrugsTemplatePrinter(this));
+
+    // Initialize the drugs engines
+    m_DDIEngine->init();
+    m_PimEngine->init();
+    m_AllergyEngine->init();
 }
 
 
