@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -32,6 +32,7 @@
 #include <QString>
 #include <QDate>
 #include <QStringList>
+#include <QHash>
 
 QT_BEGIN_NAMESPACE
 class QTreeWidget;
@@ -41,25 +42,30 @@ namespace DrugsDB {
 namespace Internal {
 //class DatabaseInfosPrivate;
 class DrugsDatabaseSelectorPrivate;
+class DrugsBase;
 }
 
 class DRUGSBASE_EXPORT DatabaseInfos
 {
+    friend class DrugsDB::Internal::DrugsBase;
+
 public:
     DatabaseInfos();
-    void warn();
+//    void warn();
+
     QString translatedName() const;
-    QHash<QString, QString> names() const;
+
     void setDrugsNameConstructor(const QString &s);
     void toTreeWidget(QTreeWidget *tree) const;
 
-    QString name, identifiant, fileName, version, compatVersion, lang_country, connectionName;
+    QString identifiant, fileName, version, compatVersion, lang_country, connectionName;
     QString provider, author, license, drugsUidName, packUidName;
     QString drugsNameConstructor,  drugsNameConstructorSearchFilter;
     QString weblink, complementaryWebsite, authorComments, licenseTerms;
     bool atcCompatible, iamCompatible;
     QDate date;
-    int moleculeLinkCompletion;
+    int moleculeLinkCompletion, sid;
+    QHash<QString, QString> names;
 };
 
 
@@ -70,8 +76,8 @@ public:
     static DrugsDatabaseSelector *instance();
     ~DrugsDatabaseSelector();
 
-    void getAllDatabaseInformations(const QStringList &paths = QStringList()) const;
-    bool setCurrentDatabase(const QString &fileName);
+    void getAllDatabaseInformations() const;
+    bool setCurrentDatabase(const QString &dbUid);
     DatabaseInfos currentDatabase() const;
     QVector<DatabaseInfos *> availableDatabases() const;
 
@@ -99,6 +105,13 @@ private:
 //
 //};
 
+DRUGSBASE_EXPORT QDebug operator<<(QDebug dbg, const DrugsDB::DatabaseInfos &c);
+DRUGSBASE_EXPORT QDebug operator<<(QDebug dbg, const DrugsDB::DatabaseInfos *c);
+
+
 }  // End namespace DrugsDB
 
+
+
+
 #endif // DRUGSDATABASESELECTOR_H
