@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -27,24 +27,31 @@
 #ifndef MFDRUGSMODEL_H
 #define MFDRUGSMODEL_H
 
-// include drugswidget headers
 #include <drugsbaseplugin/drugsbase_exporter.h>
-#include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/dosagemodel.h>
 
-// include Qt headers
 #include <QAbstractTableModel>
 
 /**
  * \file drugsmodel.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 23 Fev 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 27 Sept 2011
 */
+
+namespace DrugsWidget {
+namespace Internal {
+class DrugsActionHandler;
+}
+}
+
 namespace DrugsDB {
 class DrugsIO;
-class InteractionsManager;
+class InteractionManager;
 class DosageModel;
+class IDrug;
+class DrugInteractionQuery;
+class DrugInteractionResult;
 
 namespace Internal {
 class DrugsModelPrivate;
@@ -57,8 +64,10 @@ namespace DrugsDB {
 class DRUGSBASE_EXPORT DrugsModel : public QAbstractTableModel
 {
     Q_OBJECT
-    friend class Internal::DosageModel;
-    friend class DrugsIO;
+    friend class DrugsDB::Internal::DosageModel;
+    friend class DrugsDB::DrugsIO;
+    friend class DrugsWidget::Internal::DrugsActionHandler;
+
 public:
     enum PrescriptionDeserializer {
         AddPrescription,
@@ -81,25 +90,31 @@ public:
     bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
     QVariant data(const QModelIndex &index, int role) const;
-    QVariant drugData(const QVariant &drugUid, const int column);
-    bool setDrugData(const QVariant &drugUid, const int column, const QVariant &value);
-    void resetModel();
+    QVariant drugData(const QVariant &drugId, const int column);
+    bool setDrugData(const QVariant &drugId, const int column, const QVariant &value);
     Qt::ItemFlags flags(const QModelIndex &index) const;
 
+    // GET INTERACTIONS SPECIFIC STRUCTURED DATAS
+    void setComputeDrugInteractions(bool compute);
     bool prescriptionHasInteractions();
+    DrugInteractionQuery *drugInteractionQuery() const;
+    DrugInteractionResult *drugInteractionResult() const;
+
+    // ALLERGIES INFORMATIONS
     bool prescriptionHasAllergies();
 
     // ADD / REMOVE DRUGS
-    void setDrugsList(QDrugsList &list);
-    const QDrugsList & drugsList() const;
+    void setDrugsList(const QList<IDrug *> &list);
+    const QList<IDrug *> &drugsList() const;
     void clearDrugsList();
     int addTextualPrescription(const QString &drugLabel, const QString &drugNote);
-    int addDrug(Internal::DrugsData *drug, bool automaticInteractionChecking = true);
-    int addDrug(const QVariant &drugUid, bool automaticInteractionChecking = true);
-    int removeDrug(const QVariant &drugUid);
+    int addDrug(IDrug *drug, bool automaticInteractionChecking = true);
+    int addDrug(const QVariant &drugId, bool automaticInteractionChecking = true);
+    int addDrugs(const QVector<IDrug *> &drugs, bool automaticInteractionChecking = true);
+    int removeDrug(const QVariant &drugId);
     int removeLastInsertedDrug();
-    bool containsDrug(const QVariant &drugUid) const;
-    Internal::DrugsData *getDrug(const QVariant &drugUid) const;
+    bool containsDrug(const QVariant &drugId) const;
+    IDrug *getDrug(const QVariant &drugId) const;
 
     // SORT / ORDER DRUGS INTO PRESCRIPTION
     void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
@@ -123,24 +138,20 @@ public:
 
     // FOR DOSAGE MANAGEMENT
     Internal::DosageModel *dosageModel(const QVariant &drugUid);
-    Internal::DosageModel *dosageModel(const QModelIndex & drugIndex);
-    InteractionsManager *currentInteractionManger() const;
+    Internal::DosageModel *dosageModel(const QModelIndex &drugIndex);
 
     // FOR PRESCRIPTION FORMATTING
-    static QString getFullPrescription(const Internal::DrugsData *drug, bool toHtml = false, const QString &mask = QString::null);
-
-    DrugsDB::InteractionsManager *interactionsManager() const;
-
-    void warn();
+    static QString getFullPrescription(const IDrug *drug, bool toHtml = false, const QString &mask = QString::null);
 
 Q_SIGNALS:
     void prescriptionResultChanged(const QString & html);
     void numberOfRowsChanged();
 
 protected:
-    QModelIndex createIndex(int row, int column, void * ptr = 0) const;
-    QModelIndex createIndex(int row, int column, quint32 id) const;
-    virtual void checkInteractions() const;
+    void checkInteractions();
+
+protected Q_SLOTS:
+    void resetModel();
 
 private Q_SLOTS:
     void dosageDatabaseChanged();
@@ -152,4 +163,8 @@ private:
 
 }  // End DrugsDB
 
+DRUGSBASE_EXPORT QDebug operator<<(QDebug dbg, const DrugsDB::DrugsModel *c);
+
+
+
 #endif
