@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -29,52 +29,71 @@
 
 #include <drugsbaseplugin/drugsbase_exporter.h>
 
-#include <QSqlTableModel>
+#include <QSqlQueryModel>
 #include <QObject>
 class QStandardItemModel;
 
 /**
  * \file globaldrugsmodel.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.5.0
- * \date 24 Aug 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 27 Sept 2011
 */
 
 namespace DrugsDB {
+class IDrug;
+
 namespace Internal {
 class GlobalDrugsModelPrivate;
-class DrugsData;
 }  // end namespace Internal
 
 
-class DRUGSBASE_EXPORT GlobalDrugsModel : public QSqlTableModel
+class DRUGSBASE_EXPORT GlobalDrugsModel : public QSqlQueryModel
 {
     Q_OBJECT
     friend class Internal::GlobalDrugsModelPrivate;
 
 public:
-    GlobalDrugsModel(QObject * parent = 0);
+    enum DataRepresentation {
+        BrandName = 0,
+        Strength,
+        Routes,
+        Forms,
+        Marketed,
+        DrugId,
+        ColumnCount
+    };
+
+    enum SearchMode {
+        SearchByBrandName = 0,
+        SearchByMolecularName,
+        SearchByInnName
+    };
+
+    GlobalDrugsModel(const SearchMode searchMode = SearchByBrandName, QObject * parent = 0);
     ~GlobalDrugsModel();
 
+    void setSearchMode(const int searchMode);
+
     static void updateAvailableDosages();
 
-    static bool hasAllergy(const DrugsDB::Internal::DrugsData *drug);
-    static bool hasIntolerance(const DrugsDB::Internal::DrugsData *drug);
+//    static QStandardItemModel *drugsPrecautionsModel();
 
-    static QStandardItemModel *drugsPrecautionsModel();
+    int columnCount(const QModelIndex & = QModelIndex()) const { return ColumnCount; }
 
     bool setData(const QModelIndex &, const QVariant &, int = Qt::EditRole) { return false; }
     QVariant data(const QModelIndex & item, int role = Qt::DisplayRole) const;
     Qt::ItemFlags flags(const QModelIndex &index) const;
 
+    void setFilter(const QString &searchFor);
+
 public Q_SLOTS:
     void updateCachedAvailableDosage();
     void onDrugsDatabaseChanged();
 
 private Q_SLOTS:
-    void refreshDrugsPrecautions(const QModelIndex &topleft, const QModelIndex &bottomright);
-//    void physiologyProcessed();
-//    void processPhysiology();
+    void refreshDrugsPrecautions(const QModelIndex &topleft, const QModelIndex &bottomright) {Q_UNUSED(topleft); Q_UNUSED(bottomright);}
+    void updateAllergies();
 
 private:
     Internal::GlobalDrugsModelPrivate *d;
