@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -34,7 +34,7 @@
 
 /**
  * \file interactionsbase.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.4.0
  * \date 23 Fev 2010
 */
@@ -74,14 +74,14 @@ public:
     QString selectInteractionsSql(const int &tableref, const QList<int> &fieldsref, const QHash<int, QString> &conditions) const;
 
     // link to DrugsBase
-    int getInnCodeForCodeMolecule(const int molecule_code) const;
-    QString getAtcLabel(const int inncode) const;
-    QString getAtcLabel(const QString &code) const;
-    QString getAtcCode(const int atc_id) const;
-    QString getInnDenominationFromSubstanceCode(const int molecule_code) const;
+//    int getInnCodeForCodeMolecule(const int molecule_code) const;
+//    QString getAtcLabel(const int atcId) const;
+//    QString getAtcLabel(const QString &code) const;
+//    QString getAtcCode(const int atcId) const;
+//    QString getInnDenominationFromSubstanceCode(const int molecule_code) const;
 
-    QStringList getIamClassDenomination(const int &molecule_code);
-    QSet<int> getAllInnAndIamClassesIndex(const int molecule_code);
+//    QStringList getIamClassDenomination(const int &molecule_code);
+//    QSet<int> getAllInnAndIamClassesIndex(const int molecule_code);
 
     // Interactions base
     QList<DrugsInteraction*> calculateInteractions(const QList<DrugsData *> &drugs);
