@@ -257,7 +257,7 @@ DosageCreatorDialog::DosageCreatorDialog(QWidget *parent, DrugsDB::Internal::Dos
     availableDosagesListView->setModelColumn(Dosages::Constants::Label);
     availableDosagesListView->setEditTriggers( QListView::NoEditTriggers );
 
-    d->createHelpMenu(tr("Help and Infos"), tr("Current database website"));
+    d->createHelpMenu(tr("Help and Info"), tr("Current database website"));
     d->createValidateMenu(tr("Prescribe only"), tr("Save protocol and prescribe"), tr("Save protocol only"), tr("Test interactions only"));
 
     // Create connections
