@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -27,22 +27,18 @@
 #ifndef DOSAGEVIEWER_H
 #define DOSAGEVIEWER_H
 
-// include drugwidget headers
-
-// include Qt headers
 #include <QWidget>
 
-// include Ui
+/** \todo aggregate the ui in the private part */
 #include "ui_mfDosageViewer.h"
 
 /**
  * \file mfDosageViewer.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.2.1
  * \date 26 Oct 2009
 */
 
-
 namespace DrugsDB {
 namespace Internal {
 class DosageModel;
@@ -64,7 +60,7 @@ public:
     ~DosageViewer();
 
     void setDosageModel(DrugsDB::Internal::DosageModel *model);
-    void useDrugsModel(const QVariant &drugUid, const int drugRow);
+    void useDrugsModel(const QVariant &drugId, const int drugRow);
 
 public Q_SLOTS:
     void done(int r);
