@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,19 +19,30 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
+/**
+  \namespace DrugsWidget
+  \brief Namespace reserved for the Drugs plugin.
+  The DrugsWidget namespace includes:
+  - All dialogs, widgets and views related to drugs (needs models classes issued from DrugsDB namespace)
+  - All preferences pages (constants are issued from DrugsDB namespace)
+  - Some private constants (reserved to the Drugs UI)
+*/
+
 #include "drugsplugin.h"
 #include "constants.h"
 #include "drugspreferences/mfDrugsPreferences.h"
 #include "drugspreferences/databaseselectorwidget.h"
 #include "drugspreferences/protocolpreferencespage.h"
+#include "drugspreferences/drugenginespreferences.h"
 
 #ifdef FREEMEDFORMS
 #    include "drugswidgetfactory.h"
+#    include "drugsmode.h"
 #endif
 
 #include <extensionsystem/pluginmanager.h>
@@ -39,6 +50,7 @@
 
 #include <coreplugin/dialogs/pluginaboutpage.h>
 #include <coreplugin/icore.h>
+#include <coreplugin/itheme.h>
 #include <coreplugin/isettings.h>
 #include <coreplugin/translators.h>
 
@@ -49,17 +61,20 @@
 
 using namespace DrugsWidget::Internal;
 
+static inline Core::ITheme *theme()  { return Core::ICore::instance()->theme(); }
+static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
+static inline void messageSplash(const QString &s) {theme()->messageSplashScreen(s); }
 static inline DrugsDB::Internal::DrugsBase *drugsBase() {return DrugsDB::Internal::DrugsBase::instance();}
 
 DrugsPlugin::DrugsPlugin() :
-        viewPage(0),
-        selectorPage(0),
-        printPage(0),
-        userPage(0),
-        extraPage(0),
-        databaseSelectorPage(0),
-        protocolPage(0)
-
+    viewPage(0),
+    selectorPage(0),
+    printPage(0),
+    userPage(0),
+    extraPage(0),
+    databaseSelectorPage(0),
+    protocolPage(0),
+    enginePage(0)
 {
     setObjectName("DrugsPlugin");
     if (Utils::Log::warnPluginsCreation())
@@ -69,6 +84,31 @@ DrugsPlugin::DrugsPlugin() :
 #ifdef FREEDIAMS
         qWarning() << "creating FREEDIAMS::DrugsPlugin";
 #endif
+
+    // Add Translator to the Application
+    Core::ICore::instance()->translators()->addNewTranslator("mfDrugsWidget");
+
+    viewPage = new DrugsViewOptionsPage(this);
+    selectorPage = new DrugsSelectorOptionsPage(this);
+    printPage = new DrugsPrintOptionsPage(this);
+#ifdef FREEDIAMS
+    userPage = new DrugsUserOptionsPage(this);
+#endif
+    extraPage = new DrugsExtraOptionsPage(this);
+    databaseSelectorPage = new DrugsDatabaseSelectorPage(this);
+    protocolPage = new ProtocolPreferencesPage(this);
+    enginePage = new DrugEnginesPreferencesPage(this);
+
+    addObject(viewPage);
+    addObject(selectorPage);
+    addObject(printPage);
+#ifdef FREEDIAMS
+    addObject(userPage);
+#endif
+    addObject(extraPage);
+    addObject(databaseSelectorPage);
+    addObject(protocolPage);
+    addObject(enginePage);
 }
 
 DrugsPlugin::~DrugsPlugin()
@@ -101,6 +141,10 @@ DrugsPlugin::~DrugsPlugin()
         removeObject(protocolPage);
         delete protocolPage; protocolPage=0;
     }
+    if (enginePage) {
+        removeObject(enginePage);
+        delete enginePage; enginePage=0;
+    }
 }
 
 bool DrugsPlugin::initialize(const QStringList &arguments, QString *errorMessage)
@@ -110,8 +154,7 @@ bool DrugsPlugin::initialize(const QStringList &arguments, QString *errorMessage
     if (Utils::Log::warnPluginsCreation())
         qWarning() << "DrugsPlugin::initialize";
 
-    // Add Translator to the Application
-    Core::ICore::instance()->translators()->addNewTranslator("mfDrugsWidget");
+    messageSplash(tr("Initializing drugs plugin..."));
 
     addAutoReleasedObject(new Core::PluginAboutPage(this->pluginSpec(), this));
 
@@ -119,18 +162,21 @@ bool DrugsPlugin::initialize(const QStringList &arguments, QString *errorMessage
     addAutoReleasedObject(new DrugsWidgetsFactory(this));
 #endif
 
-    viewPage = new DrugsViewOptionsPage(this);
-    selectorPage = new DrugsSelectorOptionsPage(this);
-    printPage = new DrugsPrintOptionsPage(this);
-#ifdef FREEDIAMS
-    userPage = new DrugsUserOptionsPage(this);
-#endif
-    extraPage = new DrugsExtraOptionsPage(this);
-    databaseSelectorPage = new DrugsDatabaseSelectorPage(this);
-    protocolPage = new ProtocolPreferencesPage(this);
+    // Initialize drugs database after the settings where checked
+//    drugsBase();
+
+    return true;
+}
+
+void DrugsPlugin::extensionsInitialized()
+{
+    if (Utils::Log::warnPluginsCreation())
+        qWarning() << "DrugsPlugin::extensionsInitialized";
+
+    messageSplash(tr("Initializing drugs plugin..."));
 
     // check settings
-    if (!Core::ICore::instance()->settings()->value(Constants::S_CONFIGURED, false).toBool()) {
+    if (!settings()->value(Constants::S_CONFIGURED, false).toBool()) {
         viewPage->writeDefaultSettings(Core::ICore::instance()->settings());
         selectorPage->writeDefaultSettings(Core::ICore::instance()->settings());
         printPage->writeDefaultSettings(Core::ICore::instance()->settings());
@@ -140,6 +186,9 @@ bool DrugsPlugin::initialize(const QStringList &arguments, QString *errorMessage
         extraPage->writeDefaultSettings(Core::ICore::instance()->settings());
         databaseSelectorPage->writeDefaultSettings(Core::ICore::instance()->settings());
         protocolPage->writeDefaultSettings(Core::ICore::instance()->settings());
+        enginePage->writeDefaultSettings(Core::ICore::instance()->settings());
+        settings()->setValue(Constants::S_CONFIGURED, true);
+        settings()->sync();
     } else {
         viewPage->checkSettingsValidity();
         selectorPage->checkSettingsValidity();
@@ -150,28 +199,21 @@ bool DrugsPlugin::initialize(const QStringList &arguments, QString *errorMessage
         extraPage->checkSettingsValidity();
         databaseSelectorPage->checkSettingsValidity();
         protocolPage->checkSettingsValidity();
+        enginePage->checkSettingsValidity();
     }
 
-    addObject(viewPage);
-    addObject(selectorPage);
-    addObject(printPage);
-#ifdef FREEDIAMS
-    addObject(userPage);
-#endif
-    addObject(extraPage);
-    addObject(databaseSelectorPage);
-    addObject(protocolPage);
-
-    // Initialize drugs database after the settings where checked
-    drugsBase();
-
-    return true;
+    connect(Core::ICore::instance(), SIGNAL(coreOpened()), this, SLOT(postCoreOpened()));
 }
 
-void DrugsPlugin::extensionsInitialized()
+void DrugsPlugin::postCoreOpened()
 {
     if (Utils::Log::warnPluginsCreation())
-        qWarning() << "DrugsPlugin::extensionsInitialized";
+        qWarning() << Q_FUNC_INFO;
+#ifdef FREEMEDFORMS
+    // Add drug mode. DrugsMode manages its inclusion in pluginManager itself.
+    DrugsMode *mode = new DrugsMode(this);
+    Q_UNUSED(mode);
+#endif
 }
 
 Q_EXPORT_PLUGIN(DrugsPlugin)
