@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -30,28 +30,26 @@
 #include <extensionsystem/iplugin.h>
 
 /**
- * \file drugswidgetmanager.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.2.1
- * \date 26 Oct 2009
+ * \file drugsplugin.h
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 07 Sept 2011
  * \internal
 */
 
 
 namespace DrugsWidget {
+namespace Internal {
 class DrugsViewOptionsPage;
 class DrugsSelectorOptionsPage;
 class DrugsPrintOptionsPage;
 class DrugsUserOptionsPage;
 class DrugsExtraOptionsPage;
-class DrugsDatabaseSelectorPage;
 class ProtocolPreferencesPage;
-}
+class DrugsDatabaseSelectorPage;
+class DrugEnginesPreferencesPage;
 
 
-namespace DrugsWidget {
-namespace Internal {
-
 class DrugsPlugin : public ExtensionSystem::IPlugin
 {
     Q_OBJECT
@@ -62,15 +60,18 @@ public:
 
     bool initialize(const QStringList &arguments, QString *errorMessage = 0);
     void extensionsInitialized();
+private Q_SLOTS:
+    void postCoreOpened();
 
 private:
-    DrugsWidget::DrugsViewOptionsPage *viewPage;
-    DrugsWidget::DrugsSelectorOptionsPage *selectorPage;
-    DrugsWidget::DrugsPrintOptionsPage *printPage;
-    DrugsWidget::DrugsUserOptionsPage *userPage;
-    DrugsWidget::DrugsExtraOptionsPage *extraPage;
-    DrugsWidget::DrugsDatabaseSelectorPage *databaseSelectorPage;
-    DrugsWidget::ProtocolPreferencesPage *protocolPage;
+    DrugsViewOptionsPage *viewPage;
+    DrugsSelectorOptionsPage *selectorPage;
+    DrugsPrintOptionsPage *printPage;
+    DrugsUserOptionsPage *userPage;
+    DrugsExtraOptionsPage *extraPage;
+    DrugsDatabaseSelectorPage *databaseSelectorPage;
+    ProtocolPreferencesPage *protocolPage;
+    DrugEnginesPreferencesPage *enginePage;
 };
 
 } // namespace Internal
