@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -35,9 +35,9 @@
 
 /**
  * \file databaseselectorwidget.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 02 Mar 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 07 Sept 2011
 */
 
 
@@ -73,20 +73,13 @@ protected:
     void changeEvent(QEvent *e);
 
 private Q_SLOTS:
-    void getAllAvailableDatabases();
     void updateDatabaseInfos(int row);
-    void addPath();
-    void removePath();
-    void tooglePaths();
 
 private:
     Ui::DatabaseSelectorWidget *ui;
     DatabaseSelectorWidgetPrivate *d;
 };
 
-}  // End namespace Internal
-
-
 class DrugsDatabaseSelectorPage : public Core::IOptionsPage
 {
     Q_OBJECT
@@ -97,6 +90,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -113,6 +107,7 @@ private:
     QPointer<Internal::DatabaseSelectorWidget> m_Widget;
 };
 
+}  // End namespace Internal
 }  // End namespace DrugsWidget
 
 
