@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -28,9 +28,9 @@
 
 #include <drugsplugin/constants.h>
 #include <drugsplugin/drugswidgetmanager.h>
-#include <drugsplugin/drugswidget/mfDrugSelector.h>
+#include <drugsplugin/drugswidget/drugselector.h>
+#include <drugsbaseplugin/idrug.h>
 
-#include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/drugsmodel.h>
 #include <drugsbaseplugin/drugsbase.h>
 
@@ -49,7 +49,7 @@
 #include <QPixmap>
 
 using namespace DrugsWidget;
-using namespace DrugsWidget::Internal;
+using namespace Internal;
 using namespace DrugsWidget::Constants;
 using namespace Trans::ConstantTranslations;
 
@@ -71,6 +71,7 @@ DrugsViewOptionsPage::~DrugsViewOptionsPage()
 QString DrugsViewOptionsPage::id() const { return objectName(); }
 QString DrugsViewOptionsPage::name() const { return tr("View"); }
 QString DrugsViewOptionsPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString DrugsViewOptionsPage::title() const {return tr("Drug's view preferences");}
 
 void DrugsViewOptionsPage::resetToDefaults()
 {
@@ -105,12 +106,12 @@ void DrugsViewOptionsPage::checkSettingsValidity()
     defaultvalues.insert(S_DRUGHISTORY, QVariant());
     defaultvalues.insert(S_DRUGFONT,QFont());
     defaultvalues.insert(S_PRESCRIPTIONFONT,QFont());
-    defaultvalues.insert(DrugsDB::Constants::S_LEVELOFWARNING, 1);
+    defaultvalues.insert(DrugsDB::Constants::S_LEVELOFWARNING_STATICALERT, DrugsDB::Constants::MaximumLevelOfWarning);
     defaultvalues.insert(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION,true);
     defaultvalues.insert(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     defaultvalues.insert(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
-    defaultvalues.insert(S_DYNAMICALERTS, true);
-    defaultvalues.insert(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication);
+    defaultvalues.insert(DrugsDB::Constants::S_USEDYNAMICALERTS, true);
+    defaultvalues.insert(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT, DrugsDB::Constants::MinimumLevelOfWarning);
     defaultvalues.insert(S_PATIENTNAMESORDER, 0);
 
     foreach(const QString &k, defaultvalues.keys()) {
@@ -143,6 +144,7 @@ DrugsSelectorOptionsPage::~DrugsSelectorOptionsPage()
 QString DrugsSelectorOptionsPage::id() const { return objectName(); }
 QString DrugsSelectorOptionsPage::name() const { return tr("Selector"); }
 QString DrugsSelectorOptionsPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString DrugsSelectorOptionsPage::title() const {return tr("Drug's selector preferences");}
 
 void DrugsSelectorOptionsPage::resetToDefaults()
 {
@@ -177,8 +179,8 @@ void DrugsSelectorOptionsPage::checkSettingsValidity()
     defaultvalues.insert(DrugsDB::Constants::S_SELECTOR_SHOWMOLECULES, false);
     defaultvalues.insert(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     defaultvalues.insert(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
-    defaultvalues.insert(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, "red");
-    defaultvalues.insert(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, "yellow");
+    defaultvalues.insert(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, QColor("red"));
+    defaultvalues.insert(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, QColor("yellow"));
 
     foreach(const QString &k, defaultvalues.keys()) {
         if (settings()->value(k) == QVariant())
@@ -211,6 +213,7 @@ DrugsPrintOptionsPage::~DrugsPrintOptionsPage()
 QString DrugsPrintOptionsPage::id() const { return objectName(); }
 QString DrugsPrintOptionsPage::name() const { return tr("Printing"); }
 QString DrugsPrintOptionsPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString DrugsPrintOptionsPage::title() const {return tr("Drug's printing preferences");}
 
 void DrugsPrintOptionsPage::resetToDefaults()
 {
@@ -259,7 +262,7 @@ void DrugsPrintOptionsPage::checkSettingsValidity()
     if (settings()->value(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_PLAIN).isNull() ||
         settings()->value(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML).isNull() ||
         t.toPlainText().simplified().isEmpty()) {
-        Utils::Log::addMessage(this, "Restoring prescription sentence to its defaults");
+        LOG("Restoring prescription sentence to its defaults");
         settings()->setValue(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_PLAIN,
                              qApp->translate(Constants::DRUGCONSTANTS_TR_CONTEXT, DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING));
         settings()->setValue(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML,
@@ -301,6 +304,7 @@ DrugsUserOptionsPage::~DrugsUserOptionsPage()
 QString DrugsUserOptionsPage::id() const { return objectName(); }
 QString DrugsUserOptionsPage::name() const { return tr("User's documents"); }
 QString DrugsUserOptionsPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString DrugsUserOptionsPage::title() const {return tr("User preferences");}
 
 void DrugsUserOptionsPage::resetToDefaults()
 {
@@ -365,6 +369,7 @@ DrugsExtraOptionsPage::~DrugsExtraOptionsPage()
 QString DrugsExtraOptionsPage::id() const { return objectName(); }
 QString DrugsExtraOptionsPage::name() const { return tr("Extras"); }
 QString DrugsExtraOptionsPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString DrugsExtraOptionsPage::title() const {return tr("Drug's extra preferences");}
 
 void DrugsExtraOptionsPage::resetToDefaults()
 {
@@ -437,20 +442,20 @@ void DrugsViewWidget::setDatasToUi()
 
     viewFontSizeSpin->setValue(s->value(S_VIEWFONTSIZE, 12).toInt());
     historicSizeSpin->setValue(s->value(S_HISTORYSIZE).toInt());
-    levelOfWarningCombo->setCurrentIndex(s->value(DrugsDB::Constants::S_LEVELOFWARNING).toInt());
+    levelOfWarningCombo->setCurrentIndex(s->value(DrugsDB::Constants::S_LEVELOFWARNING_STATICALERT).toInt());
 
     viewFontCombo->setCurrentFont(s->value(S_VIEWFONT).toString());
     viewFontSizeSpin->setValue(s->value(S_VIEWFONTSIZE).toInt());
     patientNameOrder->setCurrentIndex(s->value(S_PATIENTNAMESORDER, 0).toInt());
     showIconsCheck->setChecked(s->value(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION).toBool());
 
-    dynamicAlerts->setChecked(s->value(S_DYNAMICALERTS).toBool());
-    int level = s->value(S_DYNAMICALERTS_LEVEL).toInt();
+    dynamicAlerts->setChecked(s->value(DrugsDB::Constants::S_USEDYNAMICALERTS).toBool());
+    int level = s->value(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT).toInt();
     switch (level)
     {
-    case DrugsDB::Constants::Interaction::ContreIndication: dynamicAlertsLevel->setCurrentIndex(2); break;
-    case DrugsDB::Constants::Interaction::Deconseille: dynamicAlertsLevel->setCurrentIndex(1); break;
-    case 0: dynamicAlertsLevel->setCurrentIndex(0); break;
+    case DrugsDB::Constants::MinimumLevelOfWarning: dynamicAlertsLevel->setCurrentIndex(2); break;
+    case DrugsDB::Constants::ModerateLevelOfWarning: dynamicAlertsLevel->setCurrentIndex(1); break;
+    case DrugsDB::Constants::MaximumLevelOfWarning: dynamicAlertsLevel->setCurrentIndex(0); break;
     }
 }
 
@@ -474,7 +479,7 @@ void DrugsViewWidget::saveToSettings(Core::ISettings *sets)
     // manage history size
     s->setValue(S_HISTORYSIZE, historicSizeSpin->value());
     s->setValue(S_DRUGHISTORY, QVariant());
-    s->setValue(DrugsDB::Constants::S_LEVELOFWARNING , levelOfWarningCombo->currentIndex());
+    s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_STATICALERT , levelOfWarningCombo->currentIndex());
 
     s->setValue(S_VIEWFONT , viewFontCombo->currentFont());
     s->setValue(S_VIEWFONTSIZE, viewFontSizeSpin->value());
@@ -486,34 +491,32 @@ void DrugsViewWidget::saveToSettings(Core::ISettings *sets)
     s->setValue(S_PATIENTNAMESORDER, patientNameOrder->currentIndex());
     s->setValue(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION, showIconsCheck->isChecked());
 
-    s->setValue(S_DYNAMICALERTS, dynamicAlerts->isChecked());
+    s->setValue(DrugsDB::Constants::S_USEDYNAMICALERTS, dynamicAlerts->isChecked());
     switch (dynamicAlertsLevel->currentIndex())
     {
-    case 2: s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication); break;
-    case 1: s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::Deconseille); break;
-    case 0: s->setValue(S_DYNAMICALERTS_LEVEL, 0); break;
+    case 2: s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT, DrugsDB::Constants::MinimumLevelOfWarning); break;
+    case 1: s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT, DrugsDB::Constants::ModerateLevelOfWarning); break;
+    case 0: s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT, DrugsDB::Constants::MaximumLevelOfWarning); break;
     }
 }
 
 void DrugsViewWidget::writeDefaultSettings(Core::ISettings *s)
 {
 //    qWarning() << "---------> writedefaults";
-    Utils::Log::addMessage("DrugsViewWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsWidget"));
+    LOG_FOR("DrugsViewWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsWidget"));
     s->setValue(S_CONFIGURED, true);
     s->setValue(S_VIEWFONT , QFont());
     s->setValue(S_VIEWFONTSIZE, QFont().pointSize());
     s->setValue(S_HISTORYSIZE, 20);
     s->setValue(S_DRUGHISTORY, QVariant());
-    s->setValue(DrugsDB::Constants::S_LEVELOFWARNING , 0);
+    s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_STATICALERT , DrugsDB::Constants::MaximumLevelOfWarning);
     s->setValue(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION , true);
-    s->setValue(S_DYNAMICALERTS, true);
-    s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication);
+    s->setValue(DrugsDB::Constants::S_USEDYNAMICALERTS, true);
+    s->setValue(DrugsDB::Constants::S_LEVELOFWARNING_DYNAMICALERT, DrugsDB::Constants::MinimumLevelOfWarning);
     s->setValue(S_PATIENTNAMESORDER, 0);
 
     s->setValue(S_DRUGFONT , QFont().toString());
     s->setValue(S_PRESCRIPTIONFONT , QFont().toString());
-
-    s->sync();
 }
 
 void DrugsViewWidget::changeEvent(QEvent *e)
@@ -571,7 +574,6 @@ void DrugsSelectorWidget::saveToSettings(Core::ISettings *sets)
     s->setValue(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, backgroundAllergiesButton->color());
     s->setValue(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, backgroundIntoleranceButton->color());
 
-    s->sync();
     if (DrugsWidget::DrugsWidgetManager::instance()->currentView())
         DrugsWidget::DrugsWidgetManager::instance()->currentView()->drugSelector()->updateDrugsViewColumns();
 }
@@ -579,7 +581,7 @@ void DrugsSelectorWidget::saveToSettings(Core::ISettings *sets)
 void DrugsSelectorWidget::writeDefaultSettings(Core::ISettings *s)
 {
 //    qWarning() << "---------> writedefaults";
-    Utils::Log::addMessage("DrugsSelectorWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsSelectorWidget"));
+    LOG_FOR("DrugsSelectorWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsSelectorWidget"));
 
     s->setValue(DrugsDB::Constants::S_SELECTOR_SHOWDRUGSNAME, true);
     s->setValue(DrugsDB::Constants::S_SELECTOR_SHOWROUTE, false);
@@ -589,12 +591,10 @@ void DrugsSelectorWidget::writeDefaultSettings(Core::ISettings *s)
 
     s->setValue(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     s->setValue(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
-    s->setValue(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, "red");
-    s->setValue(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, "yellow");
+    s->setValue(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, QColor("red"));
+    s->setValue(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, QColor("yellow"));
 
-    s->sync();
-
-//    DrugsWidget::DrugsWidgetManager::instance()->currentView()->drugSelector()->updateDrugsViewColumns();
+    //    DrugsWidget::DrugsWidgetManager::instance()->currentView()->drugSelector()->updateDrugsViewColumns();
 }
 
 void DrugsSelectorWidget::changeEvent(QEvent *e)
@@ -620,7 +620,6 @@ DrugsPrintWidget::DrugsPrintWidget(QWidget *parent) :
 
     // Create a virtual drug and prescription
     using namespace DrugsDB::Constants;
-    /** \todo Change the UID */
     drug = DrugsDB::Internal::DrugsBase::instance()->getDrugByUID("-1");
     if (!drug) {
         Utils::Log::addError(this, "Unable to retreive a drug from the database", __FILE__, __LINE__);
@@ -670,7 +669,7 @@ void DrugsPrintWidget::resetToDefaultFormatting()
     prescriptionFormatting->setHtml(qApp->translate("mfDrugsConstants", DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING));
 }
 
-static inline QString getFullPrescription(DrugsDB::Internal::DrugsData *drug, bool toHtml, const QString &tmp)
+static inline QString getFullPrescription(DrugsDB::IDrug *drug, bool toHtml, const QString &tmp)
 { return DrugsDB::DrugsModel::getFullPrescription(drug,toHtml,tmp); }
 
 void DrugsPrintWidget::updateFormatting()
@@ -695,13 +694,12 @@ void DrugsPrintWidget::saveToSettings(Core::ISettings *sets)
     s->setValue(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_PLAIN, prescriptionFormatting->textEdit()->toPlainText());
     s->setValue(DrugsDB::Constants::S_PRINTLINEBREAKBETWEENDRUGS, lineBreakCheck->isChecked());
     s->setValue(DrugsDB::Constants::S_PRINTDUPLICATAS, printDuplicataCheck->isChecked());
-    s->sync();
 }
 
 void DrugsPrintWidget::writeDefaultSettings(Core::ISettings *s)
 {
 //    qWarning() << "---------> writedefaults";
-    Utils::Log::addMessage("DrugsPrintWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsPrintWidget"));
+    LOG_FOR("DrugsPrintWidget", tkTr(Trans::Constants::CREATING_DEFAULT_SETTINGS_FOR_1).arg("DrugsPrintWidget"));
     s->setValue(S_CONFIGURED, true);
     s->setValue(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML,
                 qApp->translate(Constants::DRUGCONSTANTS_TR_CONTEXT, DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING));
@@ -709,7 +707,6 @@ void DrugsPrintWidget::writeDefaultSettings(Core::ISettings *s)
                 qApp->translate(Constants::DRUGCONSTANTS_TR_CONTEXT, DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING_PLAIN));
     s->setValue(DrugsDB::Constants::S_PRINTLINEBREAKBETWEENDRUGS, true);
     s->setValue(DrugsDB::Constants::S_PRINTDUPLICATAS, true);
-    s->sync();
 }
 
 void DrugsPrintWidget::changeEvent(QEvent *e)
@@ -770,7 +767,6 @@ void DrugsUserWidget::writeDefaultSettings(Core::ISettings *s)
     s->setValue(DrugsDB::Constants::S_WATERMARK_HTML, DrugsDB::Constants::S_DEF_WATEMARKHTML);
     s->setValue(DrugsDB::Constants::S_USERHEADER, DrugsDB::Constants::S_DEF_USERHEADER);
     s->setValue(DrugsDB::Constants::S_USERFOOTER, "");
-    s->sync();
 }
 
 void DrugsUserWidget::changeEvent(QEvent *e)
@@ -793,8 +789,8 @@ DrugsExtraWidget::DrugsExtraWidget(QWidget *parent) :
         QWidget(parent)
 {
     setupUi(this);
-    ALDBefore->setTypes(Editor::TextEditor::Full);
-    ALDAfter->setTypes(Editor::TextEditor::Full);
+    ALDBefore->setTypes(Editor::TextEditor::Simple | Editor::TextEditor::WithIO | Editor::TextEditor::WithTables);
+    ALDAfter->setTypes(Editor::TextEditor::Simple | Editor::TextEditor::WithIO | Editor::TextEditor::WithTables);
     setDatasToUi();
 }
 
@@ -828,7 +824,6 @@ void DrugsExtraWidget::writeDefaultSettings(Core::ISettings *s)
 
     s->setValue(DrugsDB::Constants::S_ALD_PRE_HTML, DrugsDB::Constants::S_DEF_ALD_PRE_HTML);
     s->setValue(DrugsDB::Constants::S_ALD_POST_HTML, DrugsDB::Constants::S_DEF_ALD_POST_HTML);
-    s->sync();
 }
 
 void DrugsExtraWidget::changeEvent(QEvent *e)
