@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -39,9 +39,9 @@
 
 /**
  * \file mfDrugsPreferences.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.5.0
- * \date 11 Nov 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 07 Sept 2011
 */
 
 namespace Core {
@@ -53,9 +53,7 @@ class PrinterPreviewer;
 }
 
 namespace DrugsDB {
-namespace Internal {
-class DrugsData;
-}
+class IDrug;
 }
 
 namespace DrugsWidget {
@@ -120,7 +118,7 @@ protected:
     virtual void changeEvent(QEvent *e);
 
 private:
-    DrugsDB::Internal::DrugsData *drug;
+    DrugsDB::IDrug *drug;
 };
 
 class DrugsUserWidget : public QWidget, private Ui::DrugsUserWidget
@@ -162,10 +160,6 @@ protected:
     virtual void changeEvent(QEvent *e);
 };
 
-
-}  // End Internal
-
-
 class DrugsViewOptionsPage : public Core::IOptionsPage
 {
     Q_OBJECT
@@ -176,6 +170,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -202,6 +197,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -230,6 +226,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -255,6 +252,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -279,6 +277,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -293,6 +292,7 @@ private:
     QPointer<Internal::DrugsExtraWidget> m_Widget;
 };
 
-}  // End Drugs
+}  // End namespace Internal
+}  // End namespace Drugs
 
 #endif // MFDRUGSPREFERENCES_H
