@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -58,6 +58,7 @@ ProtocolPreferencesPage::~ProtocolPreferencesPage()
 QString ProtocolPreferencesPage::id() const { return objectName(); }
 QString ProtocolPreferencesPage::name() const { return tkTr(Trans::Constants::PROTOCOLS); }
 QString ProtocolPreferencesPage::category() const { return tkTr(Trans::Constants::DRUGS); }
+QString ProtocolPreferencesPage::title() const {return tr("Drug's protocole preferences");}
 
 void ProtocolPreferencesPage::resetToDefaults()
 {
@@ -158,7 +159,6 @@ void ProtocolPreferencesWidget::writeDefaultSettings(Core::ISettings *s)
     set->setValue(Constants::S_PROTOCOLCREATOR_DEFAULTBUTTON, Constants::S_VALUE_PRESCRIBEONLY);
     set->setValue(Constants::S_PROTOCOLCREATOR_AUTOCHANGE, true);
     set->setValue(Constants::S_PROTOCOLCREATOR_AUTOCHANGE_BUTTON, Constants::S_VALUE_SAVEPRESCRIBE);
-    set->sync();
 }
 
 void ProtocolPreferencesWidget::saveToSettings(Core::ISettings *s)
