@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -35,9 +35,9 @@
 
 /**
  * \file protocolpreferencespage.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.5.0
- * \date 11 Nov 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 07 Sept 2011
 */
 
 
@@ -54,6 +54,7 @@ namespace Internal {
 namespace Ui {
 class ProtocolPreferencesWidget;
 }
+
 class ProtocolPreferencesWidget : public QWidget
 {
     Q_OBJECT
@@ -75,9 +76,6 @@ private:
     QHash<QString, QString> m_ButtonChoices;
 };
 
-}  // End namespace Internal
-
-
 class ProtocolPreferencesPage : public Core::IOptionsPage
 {
     Q_OBJECT
@@ -88,6 +86,7 @@ public:
     QString id() const;
     QString name() const;
     QString category() const;
+    QString title() const;
 
     void resetToDefaults();
     void checkSettingsValidity();
@@ -104,7 +103,7 @@ private:
     QPointer<Internal::ProtocolPreferencesWidget> m_Widget;
 };
 
+}  // End namespace Internal
 }  // End namespace DrugsWidget
 
-
 #endif // PROTOCOLPREFERENCESPAGE_H
