@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -29,7 +29,6 @@
 
 #include <utils/messagesender.h>
 
-// include Qt headers
 #include <QDialog>
 #include <QObject>
 
@@ -38,16 +37,14 @@
 
 
 /**
- * \file druginfo.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.5.0
- * \date 12 Oct 2010
+ * \file druginfo_p.h
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 26 Feb 2011
 */
 
 namespace DrugsDB {
-namespace Internal {
-class DrugsInteraction;
-}
+class IDrugInteraction;
 }
 
 
@@ -74,7 +71,7 @@ public:
      QDialog *m_Parent;
      QVariant m_DrugUid;
      Utils::MessageSender m_Sender;
-     QList<DrugsDB::Internal::DrugsInteraction *> m_InteractionsList;         // should not be deleted
+     QList<DrugsDB::IDrugInteraction *> m_InteractionsList;         // should not be deleted
      bool m_INNSent, m_InteractSent;
 };
 
