@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,34 +19,40 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 #include "drugswidgetmanager.h"
 
-// include drugs widget headers
 #include <drugsplugin/constants.h>
-#include <drugsplugin/drugswidget/mfDrugsCentralWidget.h>
-#include <drugsplugin/drugswidget/mfPrescriptionViewer.h>
-#include <drugsplugin/drugswidget/mfDrugSelector.h>
+#include <drugsplugin/drugswidget/drugscentralwidget.h>
+#include <drugsplugin/drugswidget/prescriptionviewer.h>
+#include <drugsplugin/drugswidget/drugselector.h>
 
-#include <drugsbaseplugin/drugsbasemanager.h>
-
-#include <utils/log.h>
-#include <utils/global.h>
-#include <translationutils/constanttranslations.h>
+#include <drugsbaseplugin/engines/allergyengine.h>
 
 #include <coreplugin/constants_icons.h>
 #include <coreplugin/constants_menus.h>
 #include <coreplugin/icore.h>
 #include <coreplugin/isettings.h>
 #include <coreplugin/itheme.h>
+#include <coreplugin/imainwindow.h>
 #include <coreplugin/contextmanager/contextmanager.h>
 #include <coreplugin/actionmanager/actionmanager.h>
 #include <coreplugin/uniqueidmanager.h>
 
+#include <utils/log.h>
+#include <utils/global.h>
+#include <translationutils/constanttranslations.h>
+#include <extensionsystem/pluginmanager.h>
+
+#include <QDockWidget>
+#include <QGridLayout>
+#include <QTreeView>
+#include <QStandardItemModel>
+
 using namespace DrugsWidget::Constants;
 using namespace DrugsWidget;
 using namespace DrugsWidget::Internal;
@@ -54,6 +60,8 @@ using namespace Trans::ConstantTranslations;
 
 inline static Core::ActionManager *actionManager() {return Core::ICore::instance()->actionManager();}
 static inline Core::ContextManager *contextManager() { return Core::ICore::instance()->contextManager(); }
+static inline Core::ISettings *settings() {return Core::ICore::instance()->settings();}
+static inline ExtensionSystem::PluginManager *pluginManager() {return ExtensionSystem::PluginManager::instance();}
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 /////////////////////////////////////////      MANAGER      ///////////////////////////////////////////////
@@ -140,14 +148,15 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
         aToTemplate(0),
         aDrugsDatabaseInformations(0),
         aDosagesDatabaseInformations(0),
-        aIamDatabaseInformations(0),
         gModes(0),
         aPrescriberMode(0),
         aSelectOnlyMode(0),
         aOpenDosageDialog(0),
         aOpenPrescriptionSentencePreferences(0),
         aResetPrescriptionSentenceToDefault(0),
-        m_CurrentView(0)
+        aShowDrugPrecautions(0),
+        m_CurrentView(0),
+        m_PrecautionDock(0)
 {
     setObjectName("DrugsActionHandler");
 //    Utils::Log::addMessage(this, "Instance created");
@@ -172,7 +181,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     }
     Q_ASSERT(menu);
 #ifdef FREEDIAMS
-    actionManager()->actionContainer(Core::Constants::MENUBAR)->addMenu(menu, DrugsWidget::Constants::G_PLUGINS_DRUGS);
+    actionManager()->actionContainer(Core::Constants::MENUBAR)->addMenu(menu, Core::Constants::G_PLUGINS);
 #else
     actionManager()->actionContainer(Core::Constants::M_PLUGINS)->addMenu(menu, Core::Constants::G_PLUGINS_DRUGS);
 #endif
@@ -222,7 +231,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     connect(a, SIGNAL(triggered()), this, SLOT(sortDrugs()));
 
     a = aViewInteractions = new QAction(this);
-    a->setIcon(th->icon(Core::Constants::ICONEYES));
+    a->setIcon(th->icon(DrugsDB::Constants::I_DRUGENGINE));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_VIEW_INTERACTIONS, ctx);
     cmd->setTranslations(Trans::Constants::VIEWINTERACTIONS_TEXT);
     menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_INTERACTIONS);
@@ -256,33 +265,34 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     Q_ASSERT(searchmenu);
 
     gSearchMethod = new QActionGroup(this);
+    int m = settings()->value(Constants::S_SEARCHMETHOD).toInt();
     a = aSearchCommercial = new QAction(this);
     a->setCheckable(true);
-    a->setChecked(false);
+    a->setChecked(m==Constants::SearchCommercial);
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHCOMMERCIAL));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_COMMERCIAL, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHCOMMERCIAL_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
-    cmd->setAttribute(Core::Command::CA_UpdateText);
+//    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
 
     a = aSearchMolecules = new QAction(this);
     a->setCheckable(true);
-    a->setChecked(false);
+    a->setChecked(m==Constants::SearchMolecules);
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHMOLS));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_MOLECULES, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHMOLECULES_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
-    cmd->setAttribute(Core::Command::CA_UpdateText);
+//    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
 
     a = aSearchInn = new QAction(this);
     a->setCheckable(true);
-    a->setChecked(false);
+    a->setChecked(m==Constants::SearchInn);
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHINN));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_INN, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHINN_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
-    cmd->setAttribute(Core::Command::CA_UpdateText);
+//    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
     connect(gSearchMethod,SIGNAL(triggered(QAction*)),this,SLOT(searchActionChanged(QAction*)));
@@ -356,17 +366,6 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     }
     connect(aDosagesDatabaseInformations,SIGNAL(triggered()), this, SLOT(showDosagesDatabaseInformations()));
 
-    a = aIamDatabaseInformations = new QAction(this);
-    a->setIcon(th->icon(Core::Constants::ICONHELP));
-    cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_IAMDATABASE_INFORMATIONS, QList<int>() << Core::Constants::C_GLOBAL_ID);
-    cmd->setTranslations(Trans::Constants::INTERACTIONS_DATABASE_INFORMATIONS);
-    cmd->retranslate();
-    if (hmenu) {
-        hmenu->addAction(cmd, Core::Constants::G_HELP_DATABASES);
-    }
-    connect(aIamDatabaseInformations,SIGNAL(triggered()), this, SLOT(showInteractionsDatabaseInformations()));
-
-
     // Mode menu
     Core::ActionContainer *modemenu = actionManager()->actionContainer(DrugsWidget::Constants::M_PLUGINS_MODES);
     if (!modemenu) {
@@ -417,6 +416,14 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     menu->addAction(cmd, G_PLUGINS_DRUGS);
     connect(aResetPrescriptionSentenceToDefault,SIGNAL(triggered()),this,SLOT(resetPrescriptionSentenceToDefault()));
 
+    a = aShowDrugPrecautions = new QAction(this);
+    a->setObjectName("aShowDrugPrecautions");
+        a->setIcon(th->icon(DrugsDB::Constants::I_ALLERGYENGINE));
+    cmd = actionManager()->registerAction(a, Constants::A_SHOWDRUGPRECAUTIONS, ctx);
+    cmd->setTranslations(Constants::SHOWDRUGPRECAUTIONS_TEXT, Constants::SHOWDRUGPRECAUTIONS_TEXT, Constants::DRUGCONSTANTS_TR_CONTEXT);
+    menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_VIEWS);
+    connect(aShowDrugPrecautions, SIGNAL(triggered()), this, SLOT(showDrugPrecautions()));
+
     contextManager()->updateContext();
     actionManager()->retranslateMenusAndActions();
 }
@@ -487,8 +494,11 @@ void DrugsActionHandler::updateActions()
 
 void DrugsActionHandler::toggleDrugSelector()
 {
-    if (m_CurrentView)
-        m_CurrentView->drugSelector()->setVisible(!m_CurrentView->drugSelector()->isVisible());
+    if (m_CurrentView) {
+        bool setToVisible = !m_CurrentView->drugSelector()->isVisible();
+        m_CurrentView->setMinimumHeight(setToVisible ? 600 : 200);
+        m_CurrentView->drugSelector()->setVisible(setToVisible);
+    }
 }
 
 bool DrugsActionHandler::canMoveUp()
@@ -619,13 +629,6 @@ void DrugsActionHandler::showDosagesDatabaseInformations()
     }
 }
 
-void DrugsActionHandler::showInteractionsDatabaseInformations()
-{
-    if (m_CurrentView) {
-        m_CurrentView->showInteractionsDatabaseInformations();
-    }
-}
-
 void DrugsActionHandler::setEditMode(const Modes mode)
 {
     // no change
@@ -695,8 +698,6 @@ void DrugsActionHandler::openProtocolPreferencesDialog()
     }
 }
 
-static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
-
 void DrugsActionHandler::resetPrescriptionSentenceToDefault()
 {
     settings()->setValue(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML,
@@ -709,3 +710,24 @@ void DrugsActionHandler::resetPrescriptionSentenceToDefault()
                                  DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING_PLAIN));
     DrugsDB::DrugsModel::activeModel()->resetModel();
 }
+
+void DrugsActionHandler::showDrugPrecautions()
+{
+    DrugsDB::Internal::DrugAllergyEngine *engine = pluginManager()->getObject<DrugsDB::Internal::DrugAllergyEngine>();
+    if (!engine) {
+        LOG_ERROR("No allergy engine");
+        return;
+    }
+    if (!m_PrecautionDock) {
+        m_PrecautionDock = new QDockWidget(QCoreApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, Constants::DRUGPRECAUTIONS_TEXT), Core::ICore::instance()->mainWindow());
+        QTreeView *tree = new QTreeView(m_PrecautionDock);
+        tree->header()->hide();
+        tree->setModel(engine->drugPrecautionModel());
+        tree->expandAll();
+        m_PrecautionDock->setWidget(tree);
+        m_PrecautionDock->setFloating(false);
+        m_PrecautionDock->setAllowedAreas(Qt::RightDockWidgetArea);
+        Core::ICore::instance()->mainWindow()->addDockWidget(Qt::RightDockWidgetArea, m_PrecautionDock);
+    }
+    m_PrecautionDock->show();
+}
