@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -29,7 +29,7 @@
 
 #include <drugsplugin/drugs_exporter.h>
 
-#include <drugsplugin/drugswidget/mfDrugsCentralWidget.h>
+#include <drugsplugin/drugswidget/drugscentralwidget.h>
 #include <drugsbaseplugin/drugsmodel.h>
 
 #include <coreplugin/contextmanager/icontext.h>
@@ -38,17 +38,17 @@
 #include <QObject>
 #include <QAction>
 #include <QPointer>
+#include <QDockWidget>
 
 /**
  * \file drugswidgetmanager.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 06 Mar 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 27 Sept 2011
  * \internal
 */
 
 namespace DrugsWidget {
-class InteractionsManager;
 namespace Internal {
 
 class DrugsContext : public Core::IContext
@@ -104,13 +104,14 @@ private Q_SLOTS:
 
     void showDrugsDatabaseInformations();
     void showDosagesDatabaseInformations();
-    void showInteractionsDatabaseInformations();
 
     void modeActionChanged(QAction *a);
     void openDosageDialog();
     void openProtocolPreferencesDialog();
     void resetPrescriptionSentenceToDefault();
 
+    void showDrugPrecautions();
+
 private:
     bool canMoveUp();
     bool canMoveDown();
@@ -138,17 +139,19 @@ protected:
     QAction *aToTemplate;
     QAction *aDrugsDatabaseInformations;
     QAction *aDosagesDatabaseInformations;
-    QAction *aIamDatabaseInformations;
     QActionGroup *gModes;
     QAction *aPrescriberMode;
     QAction *aSelectOnlyMode;
     QAction *aOpenDosageDialog;
     QAction *aOpenPrescriptionSentencePreferences;
     QAction *aResetPrescriptionSentenceToDefault;
+    QAction *aShowDrugPrecautions;
 
     QPointer<DrugsCentralWidget> m_CurrentView;
 
     bool m_SelectionOnlyMode;
+
+    QDockWidget *m_PrecautionDock;
 };
 
 }  // End Internal
@@ -166,7 +169,6 @@ public:
 
     DrugsWidget::DrugsCentralWidget  *currentView() const;
     DrugsDB::DrugsModel              *currentDrugsModel() const { return DrugsDB::DrugsModel::activeModel(); }
-    DrugsDB::InteractionsManager     *currentInteractionManager() const { return currentView()->currentDrugsModel()->currentInteractionManger(); }
 
 private Q_SLOTS:
     void updateContext(Core::IContext *object);
