@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -27,6 +27,8 @@
 #define LISTVIEW_H
 
 #include <listviewplugin/listview_exporter.h>
+#include <listviewplugin/extendedview.h>
+#include <listviewplugin/constants.h>
 
 #include <QWidget>
 #include <QListView>
@@ -37,10 +39,11 @@
 
 /**
  * \file listview.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.0.11
- * \date 08 Sept 2009
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.5.0
+ * \date 03 Feb 2011
 */
+
 namespace Views {
 namespace Internal {
 class ListViewPrivate;
@@ -50,37 +53,25 @@ class LISTVIEW_EXPORT ListView : public QListView
 {
     Q_OBJECT
     friend class ListViewPrivate;
+
 public:
-
-    /** \brief Enumerates the available default actions that can be added. Actions are pop-upped. */
-    enum AvailableAction {
-        AddRemove      = 0x01,
-        MoveUpDown     = 0x02,
-        Edit           = 0x04,
-        DefaultActions = AddRemove,
-        AllActions     = AddRemove | MoveUpDown
-    };
-    Q_DECLARE_FLAGS( AvailableActions, AvailableAction );
-
-    ListView(QWidget *parent = 0, AvailableActions actions = DefaultActions);
+    ListView(QWidget *parent = 0, Views::Constants::AvailableActions actions = Views::Constants::DefaultActions);
     virtual ~ListView();
 
-    void setObjectName(const QString &name);
-
-    void setActions( AvailableActions actions );
+    void setActions(Views::Constants::AvailableActions actions);
+    void setCommands(const QStringList &commandsUid);
+    void addContext(const int id);
+    void addContexts(const QList<int> &id);
 
     void hideButtons() const;
     void showButtons();
     void useContextMenu(bool state = true);
 
 public Q_SLOTS:
-    virtual QMenu *getContextMenu();
-    virtual void contextMenu(const QPoint & );
     virtual void addItem();
     virtual void removeItem();
     virtual void moveDown();
     virtual void moveUp();
-    virtual void on_edit_triggered();
 
 Q_SIGNALS:
     void addRequested();
@@ -94,6 +85,5 @@ private:
 
 }  // End Views
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(Views::ListView::AvailableActions)
 
-#endif // TKLISTVIEW_H
+#endif // LISTVIEW_H
