@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -32,6 +32,7 @@
 
 #include <coreplugin/dialogs/pluginaboutpage.h>
 #include <coreplugin/icore.h>
+#include <coreplugin/isettings.h>
 #include <coreplugin/translators.h>
 
 #include <QtCore/QtPlugin>
@@ -41,16 +42,25 @@
 
 using namespace Print;
 
+static inline Core::ISettings *settings() { return Core::ICore::instance()->settings(); }
+
 PrinterPlugin::PrinterPlugin() :
         prefPage(0), docPrinter(0)
 {
     setObjectName("PrinterPlugin");
     if (Utils::Log::warnPluginsCreation())
         qWarning() << "creating PrinterPlugin";
+
+    // Add preferences pages, printer manager
+    prefPage = new Print::Internal::PrinterPreferencesPage(this);
+    addObject(prefPage);
+    docPrinter = new Internal::DocumentPrinter(this);
+    addObject(docPrinter);
 }
 
 PrinterPlugin::~PrinterPlugin()
 {
+    qWarning() << "PrinterPlugin::~PrinterPlugin()";
     if (prefPage) {
         removeObject(prefPage);
         delete prefPage; prefPage=0;
@@ -81,21 +91,14 @@ void PrinterPlugin::extensionsInitialized()
 
     addAutoReleasedObject(new Core::PluginAboutPage(pluginSpec(), this));
 
-    // Add preferences pages, printer manager
-    prefPage = new Print::Internal::PrinterPreferencesPage(this);
-    addObject(prefPage);
-    docPrinter = new Internal::DocumentPrinter(this);
-    addObject(docPrinter);
-
     // Check system for existing printers
-//    if (QPrinterInfo::availablePrinters().count()) {
-    if (QPrinterInfo::availablePrinters().isEmpty()) {
-        Utils::Log::addError(this, "No printer installed in this system.", __FILE__, __LINE__);
-        Utils::warningMessageBox(tr("No printer"),
-                                 tr("No printer is configured in your system. The print preview and printing will not work."),
-                                 tr("You must configure at least on printer. Please refer to your system documentation. \n"),
-                                 qApp->applicationName());
-    }
+//    if (QPrinterInfo::availablePrinters().isEmpty()) {
+//        LOG_ERROR("No printer installed in this system.");
+//        Utils::warningMessageBox(tr("No printer"),
+//                                 tr("No printer is configured in your system. The print preview and printing will not work."),
+//                                 tr("You must configure at least on printer. Please refer to your system documentation. \n"),
+//                                 qApp->applicationName());
+//    }
 }
 
 
