@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -46,7 +46,6 @@ PrinterPreferencesPage::PrinterPreferencesPage(QObject *parent) :
         IOptionsPage(parent), m_Widget(0)
 {
     setObjectName("PrinterPreferencesPage");
-    checkSettingsValidity();
 }
 
 PrinterPreferencesPage::~PrinterPreferencesPage()
@@ -58,6 +57,7 @@ PrinterPreferencesPage::~PrinterPreferencesPage()
 QString PrinterPreferencesPage::id() const { return objectName(); }
 QString PrinterPreferencesPage::name() const { return tkTr(Trans::Constants::DEFAULTS); }
 QString PrinterPreferencesPage::category() const { return tkTr(Trans::Constants::PRINTING); }
+QString PrinterPreferencesPage::title() const {return tr("Printer preferences");}
 
 void PrinterPreferencesPage::resetToDefaults()
 {
@@ -89,7 +89,6 @@ void PrinterPreferencesPage::checkSettingsValidity()
         if (settings()->value(k) == QVariant())
             settings()->setValue(k, defaultvalues.value(k));
     }
-    settings()->sync();
 }
 
 QWidget *PrinterPreferencesPage::createPage(QWidget *parent)
