@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,7 +19,7 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  *       NAME <MAIL@ADRESS>                                                *
@@ -29,11 +29,13 @@
 
 #include <utils/global.h>
 #include <utils/log.h>
+#include <utils/databaseconnector.h>
 #include <translationutils/constanttranslations.h>
 
 #include <coreplugin/isettings.h>
 #include <coreplugin/icore.h>
 #include <coreplugin/constants_tokensandsettings.h>
+#include <coreplugin/icommandline.h>
 
 #include <QCoreApplication>
 #include <QSqlDatabase>
@@ -48,9 +50,8 @@ using namespace Templates;
 //using namespace Templates::Internal;
 using namespace Trans::ConstantTranslations;
 
-
 static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
-
+static inline Core::ICommandLine *commandLine()  { return Core::ICore::instance()->commandLine(); }
 
 namespace Templates {
 namespace Internal {
@@ -74,7 +75,7 @@ public:
             if (query.next())
                 version = query.value(0).toString();
         } else {
-            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
+            LOG_QUERY_ERROR_FOR(q, query);
         }
         query.finish();
         bool updateVersionNumber = false;
@@ -85,7 +86,7 @@ public:
             // For SQLite :
             // --> USER_UID from int to varchar
             // --> Adding GROUP_UID for templates and categories
-            Utils::Log::addMessage(q, "Updating templates database version (0.3.0 to 0.4.0)");
+            LOG_FOR(q, "Updating templates database version (0.3.0 to 0.4.0)");
 
             // 1. Rename old tables
             QStringList reqs;
@@ -94,13 +95,11 @@ public:
                     << "ALTER TABLE `TEMPLATES` RENAME TO `OLD_TEMPLATES`;";
 
             if (!q->executeSQL(reqs, q->database()))
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
-                                     __FILE__, __LINE__);
+                LOG_ERROR_FOR(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
 
             // 2. Recreate the db schema
             if (!q->createTables())
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
-                                     __FILE__, __LINE__);
+                LOG_ERROR_FOR(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
 
             reqs.clear();
             reqs << QString("INSERT INTO `CATEGORIES` (%1) SELECT %1 FROM `OLD_CATEGORIES`;")
@@ -134,8 +133,7 @@ public:
 
             // Reinsert datas to new tables
             if (!q->executeSQL(reqs, q->database()))
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
-                                     __FILE__, __LINE__);
+                LOG_ERROR_FOR(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
 
             // Refresh db version
             version = "0.4.0";
@@ -147,7 +145,7 @@ public:
             query.bindValue(0, Constants::DB_ACTUAL_VERSION);
             query.exec();
             if (!query.isActive()) {
-                Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
+                LOG_QUERY_ERROR_FOR(q, query);
             }
             query.finish();
         }
@@ -209,24 +207,7 @@ TemplateBase::TemplateBase(QObject *parent)
     addField(Table_Templates, TEMPLATE_THEMEDICON,       "THEMED_ICON_FILENAME", FieldIsShortText);
     addField(Table_Templates, TEMPLATE_TRANSMISSIONDATE, "TRANSMISSION_DATE",    FieldIsDate);
 
-    /** \todo DB schema :: Update Templates::USER_UID from int to varchar */
-    /** \todo DB schema :: Add UserGroupUid */
-
-//            "CREATE TABLE IF NOT EXISTS `TEMPLATES` ("
-//            "`TEMPLATE_ID`              INTEGER        PRIMARY KEY AUTOINCREMENT,"
-//            "`TEMPLATE_UUID`            varchar(40)    NULL,"
-//            "`USER_UUID`                int(11)        NULL,"           //  NEEDS UPDATE FROM 0.3.0 TO 0.4.0
-//            "`ID_CATEGORY`              int(11)        DEFAULT -1,"
-//            "`LABEL`                    varchar(300)   NULL,"
-//            "`SUMMARY`                  varchar(500)   NULL,"
-//            "`CONTENT`                  blob           NULL,"
-//            "`CONTENT_MIMETYPES`        varchar(300)   NULL,"
-//            "`DATE_CREATION`            date           NULL,"
-//            "`DATE_MODIFICATION`        date           NULL,"
-//            "`THEMED_ICON_FILENAME`     varchar(50)    NULL,"
-//            "`TRANSMISSION_DATE`        date           NULL"
-//            ");"
-
+    /** \todo code here : use the category plugin */
     addField(Table_Categories,  CATEGORIES_ID,               "CATEGORY_ID",          FieldIsUniquePrimaryKey);
     addField(Table_Categories,  CATEGORIES_UUID,             "CATEGORY_UUID",        FieldIsUUID);
     addField(Table_Categories,  CATEGORIES_USER_UID,         "USER_UUID",            FieldIsUUID);
@@ -242,26 +223,8 @@ TemplateBase::TemplateBase(QObject *parent)
 
     /** \todo DB Schema :: Add USerGroupUid */
 
-//            "CREATE TABLE IF NOT EXISTS `CATEGORIES` ("
-//            "`CATEGORY_ID`              INTEGER        PRIMARY KEY AUTOINCREMENT,"
-//            "`CATEGORY_UUID`            varchar(40)    NULL,"
-//            "`USER_UUID`                int(11)        NULL,"          //  NEEDS UPDATE FROM 0.3.0 TO 0.4.0
-//            "`PARENT_CATEGORY`          int(11)        DEFAULT -1,"
-//            "`LABEL`                    varchar(300)   NULL,"
-//            "`SUMMARY`                  varchar(500)   NULL,"
-//            "`MIMETYPES`                varchar(300)   NULL,"
-//            "`DATE_CREATION`            date           NULL,"
-//            "`DATE_MODIFICATION`        date           NULL,"
-//            "`THEMED_ICON_FILENAME`     varchar(50)    NULL,"
-//            "`TRANSMISSION_DATE`        date           NULL"
-//            ");";
-
     addField(Table_Version, VERSION_ACTUAL, "ACTUAL", FieldIsShortText);
 
-//            "CREATE TABLE IF NOT EXISTS `VERSION` ("
-//            "`ACTUAL`                  varchar(10)"
-//            ");";
-
     connect(Core::ICore::instance(), SIGNAL(databaseServerChanged()), this, SLOT(onCoreDatabaseServerChanged()));
 
     init();
@@ -280,26 +243,32 @@ bool TemplateBase::init()
     if (m_initialized)
         return true;
 
-    // Check settings --> SQLite or MySQL ?
-    if (settings()->value(Core::Constants::S_USE_EXTERNAL_DATABASE, false).toBool()) {
-        createConnection(Templates::Constants::DB_TEMPLATES_NAME,
-                         Templates::Constants::DB_TEMPLATES_NAME,
-                         QString(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_HOST, QByteArray("localhost").toBase64()).toByteArray())),
-                         Utils::Database::ReadWrite,
-                         Utils::Database::MySQL,
-                         QString(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_LOG, QByteArray("root").toBase64()).toByteArray())),
-                         QString(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_PASS, QByteArray("").toBase64()).toByteArray())),
-                         QString(QByteArray::fromBase64(settings()->value(Core::Constants::S_EXTERNAL_DATABASE_PORT, QByteArray("").toBase64()).toByteArray())).toInt(),
-                         Utils::Database::CreateDatabase);
+    // connect
+    if (commandLine()->value(Core::ICommandLine::ClearUserDatabases).toBool()) {
+        createConnection(Templates::Constants::DB_TEMPLATES_NAME, Templates::Constants::DB_TEMPLATES_NAME,
+                         settings()->databaseConnector(),
+                         Utils::Database::DeleteAndRecreateDatabase);
     } else {
-        createConnection(Templates::Constants::DB_TEMPLATES_NAME,
-                         Templates::Constants::DB_TEMPLATES_FILENAME,
-                         settings()->path(Core::ISettings::ReadWriteDatabasesPath) + QDir::separator() + QString(Templates::Constants::DB_TEMPLATES_NAME),
-                         Utils::Database::ReadWrite,
-                         Utils::Database::SQLite,
-                         "log", "pas", 0,
+        createConnection(Templates::Constants::DB_TEMPLATES_NAME, Templates::Constants::DB_TEMPLATES_NAME,
+                         settings()->databaseConnector(),
                          Utils::Database::CreateDatabase);
     }
+
+    if (!database().isOpen()) {
+        if (!database().open()) {
+            LOG_ERROR(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(Templates::Constants::DB_TEMPLATES_NAME).arg(database().lastError().text()));
+        } else {
+            LOG(tkTr(Trans::Constants::CONNECTED_TO_DATABASE_1_DRIVER_2).arg(database().connectionName()).arg(database().driverName()));
+        }
+    } else {
+        LOG(tkTr(Trans::Constants::CONNECTED_TO_DATABASE_1_DRIVER_2).arg(database().connectionName()).arg(database().driverName()));
+    }
+
+    if (!checkDatabaseScheme()) {
+        LOG_ERROR(tkTr(Trans::Constants::DATABASE_1_SCHEMA_ERROR).arg(Templates::Constants::DB_TEMPLATES_NAME));
+        return false;
+    }
+
     d->checkDatabaseVersion();
 
     m_initialized = true;
@@ -307,7 +276,9 @@ bool TemplateBase::init()
 }
 
 void TemplateBase::logChronos(bool state)
-{}
+{
+    Q_UNUSED(state);
+}
 
 bool TemplateBase::createDatabase(const QString &connectionName , const QString &dbName,
                     const QString &pathOrHostName,
@@ -317,57 +288,63 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
                     CreationOption /*createOption*/
                    )
 {
+    Q_UNUSED(access);
     if (connectionName != Templates::Constants::DB_TEMPLATES_NAME)
         return false;
 
-    Utils::Log::addMessage(this, tkTr(Trans::Constants::TRYING_TO_CREATE_1_PLACE_2)
-                           .arg(dbName).arg(pathOrHostName));
+    LOG(tkTr(Trans::Constants::TRYING_TO_CREATE_1_PLACE_2)
+        .arg(dbName).arg(pathOrHostName));
 
     // create an empty database and connect
     QSqlDatabase DB;
     if (driver == SQLite) {
         DB = QSqlDatabase::addDatabase("QSQLITE", connectionName);
-        if (!QDir(pathOrHostName).exists()) {
-            if (!QDir().mkpath(pathOrHostName)) {
-                Utils::Log::addError(this, tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(pathOrHostName),
-                                     __FILE__, __LINE__);
-            } else {
-                Utils::Log::addMessage(this, tkTr(Trans::Constants::CREATE_DIR_1).arg(pathOrHostName));
-            }
-        }
+        if (!QDir(pathOrHostName).exists())
+            if (!QDir().mkpath(pathOrHostName))
+                tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(pathOrHostName);
         DB.setDatabaseName(QDir::cleanPath(pathOrHostName + QDir::separator() + dbName));
         if (!DB.open())
-            Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2).arg(dbName).arg(DB.lastError().text()),
-                                 __FILE__, __LINE__);
+            LOG(tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2).arg(dbName).arg(DB.lastError().text()));
         setDriver(Utils::Database::SQLite);
     }
     else if (driver == MySQL) {
         DB = QSqlDatabase::database(connectionName);
         if (!DB.open()) {
-            QSqlDatabase d = QSqlDatabase::addDatabase("QMYSQL", "CREATOR");
+            QSqlDatabase d = QSqlDatabase::addDatabase("QMYSQL", "__TEMPLATES_CREATOR");
             d.setHostName(pathOrHostName);
             d.setUserName(login);
             d.setPassword(pass);
             d.setPort(port);
             if (!d.open()) {
-                Utils::warningMessageBox(tr("Unable to connect the Templates host."),tr("Please contact dev team."));
+                Utils::warningMessageBox(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                         .arg(DB.connectionName()).arg(DB.lastError().text()),
+                                         tr("Please contact dev team."));
                 return false;
             }
             QSqlQuery q(QString("CREATE DATABASE `%1`").arg(dbName), d);
             if (!q.isActive()) {
-                Utils::Log::addQueryError("TemplateBase", q, __FILE__, __LINE__);
-                Utils::warningMessageBox(tr("Unable to create the Templates database."),tr("Please contact dev team."));
+                LOG_QUERY_ERROR(q);
+                Utils::warningMessageBox(tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2)
+                                         .arg(DB.connectionName()).arg(DB.lastError().text()),
+                                         tr("Please contact dev team."));
                 return false;
             }
             if (!DB.open()) {
-                Utils::warningMessageBox(tr("Unable to connect the Templates database."),tr("Please contact dev team."));
+                Utils::warningMessageBox(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                         .arg(DB.connectionName()).arg(DB.lastError().text()),
+                                         tr("Please contact dev team."));
                 return false;
             }
             DB.setDatabaseName(dbName);
         }
-        if (QSqlDatabase::connectionNames().contains("CREATOR"))
-            QSqlDatabase::removeDatabase("CREATOR");
-        DB.open();
+        if (QSqlDatabase::connectionNames().contains("__TEMPLATES_CREATOR"))
+            QSqlDatabase::removeDatabase("__TEMPLATES_CREATOR");
+        if (!DB.open()) {
+            Utils::warningMessageBox(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                     .arg(DB.connectionName()).arg(DB.lastError().text()),
+                                     tr("Please contact dev team."));
+            return false;
+        }
         setDriver(Utils::Database::MySQL);
     }
 
@@ -376,11 +353,10 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
     setConnectionName(connectionName);
 
     if (createTables()) {
-        Utils::Log::addMessage(this, tkTr(Trans::Constants::DATABASE_1_CORRECTLY_CREATED).arg(dbName));
+        LOG(tkTr(Trans::Constants::DATABASE_1_CORRECTLY_CREATED).arg(dbName));
     } else {
-        Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2)
-                         .arg(dbName, DB.lastError().text()),
-                         __FILE__, __LINE__);
+        LOG_ERROR(tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2)
+                  .arg(dbName, DB.lastError().text()));
         return false;
     }
 
@@ -395,6 +371,15 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
         return false;
     }
 
+    // inform the version
+    QSqlQuery query(database());
+    query.prepare(prepareInsertQuery(Constants::Table_Version));
+    query.bindValue(Constants::VERSION_ACTUAL, Constants::DB_ACTUAL_VERSION);
+    if (!query.exec()) {
+        LOG_QUERY_ERROR(query);
+        return false;
+    }
+
     return true;
 }
 
