@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -18,6 +18,12 @@
  *  along with this program (COPYING.FREEMEDFORMS file).                   *
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
+
+/**
+  \namespace Templates
+  \brief Namespace reserved for the Templates plugin.
+*/
+
 #include "templatesplugin.h"
 #include "templatesmodel.h"
 #include "templatebase.h"
@@ -27,6 +33,7 @@
 
 #include <coreplugin/dialogs/pluginaboutpage.h>
 #include <coreplugin/icore.h>
+#include <coreplugin/isettings.h>
 #include <coreplugin/translators.h>
 
 #include <utils/log.h>
@@ -36,10 +43,15 @@
 
 using namespace Templates;
 
+static inline Core::ISettings *settings() { return Core::ICore::instance()->settings(); }
+
 TemplatesPlugin::TemplatesPlugin()
 {
     if (Utils::Log::warnPluginsCreation())
         qWarning() << "creating TemplatesPlugin";
+
+    prefPage = new Internal::TemplatesPreferencesPage(this);
+    addObject(prefPage);
 }
 
 TemplatesPlugin::~TemplatesPlugin()
@@ -61,15 +73,6 @@ bool TemplatesPlugin::initialize(const QStringList &arguments, QString *errorStr
     // Add Translator to the Application
     Core::ICore::instance()->translators()->addNewTranslator("templatesplugin");
 
-    // add plugin info page
-    addAutoReleasedObject(new Core::PluginAboutPage(pluginSpec(), this));
-    prefPage = new Internal::TemplatesPreferencesPage(this);
-    prefPage->checkSettingsValidity();
-    addObject(prefPage);
-
-    // Initialize template database
-    Templates::TemplateBase::instance();
-
     return true;
 }
 
@@ -78,6 +81,14 @@ void TemplatesPlugin::extensionsInitialized()
     if (Utils::Log::warnPluginsCreation())
         qWarning() << "TemplatesPlugin::extensionsInitialized";
 
+    // Initialize template database
+    Templates::TemplateBase::instance();
+
+    // add plugin info page
+    addAutoReleasedObject(new Core::PluginAboutPage(pluginSpec(), this));
+
+    prefPage->checkSettingsValidity();
+
     // Initialize TemplatesViewManager
     Templates::Internal::TemplatesViewManager::instance(this);
 }
