@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -19,9 +19,10 @@
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
+ *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 #include "editoractionhandler.h"
 #include "texteditor.h"
@@ -39,6 +40,7 @@
 #include <coreplugin/idocumentprinter.h>
 
 #include <extensionsystem/pluginmanager.h>
+#include <utils/log.h>
 
 #include <QAction>
 #include <QApplication>
@@ -116,19 +118,22 @@ static inline QAction *createAction(QObject *parent, const QString &name, const
 }
 
 EditorActionHandler::EditorActionHandler(QObject *parent) :
-        QObject(parent),
-        aOpen(0), aSave(0), aPrint(0),
-        aUndo(0), aRedo(0),
-        aCut(0), aCopy(0), aPaste(0),
-        aBold(0), aUnderline(0), aStrike(0),
-        aItalic(0), aColor(0),
-        aFontFormat(0), aFontBigger(0), aFontSmaller(0),
-        aLeft(0), aCenter(0), aRight(0), aJustify(0),
-        aAddTable(0), aTableProperties(0),
-        aAddRow(0),aAddCol(0),
-        aRemoveRow(0), aRemoveCol(0),
-        aMergeCells(0), aSplitCells(0),
-        m_CurrentEditor(0)
+    QObject(parent),
+    aOpen(0), aSave(0), aPrint(0),
+    aUndo(0), aRedo(0),
+    aCut(0), aCopy(0), aPaste(0),
+    aBold(0), aUnderline(0), aStrike(0),
+    aItalic(0), aColor(0),
+    aFontFormat(0), aFontBigger(0), aFontSmaller(0),
+    aLeft(0), aCenter(0), aRight(0), aJustify(0),
+    aAddTable(0), aTableProperties(0),
+    aAddRow(0),aAddCol(0),
+    aRemoveRow(0), aRemoveCol(0),
+    aMergeCells(0), aSplitCells(0),
+    aAddDate(0),
+    aAddUserName(0),
+    aAddPatientName(0),
+    m_CurrentEditor(0)
 {
     createContexts();
     createMenus();
@@ -145,6 +150,7 @@ void EditorActionHandler::createContexts()
     basicContext = QList<int>() << uid()->uniqueIdentifier(Core::Constants::C_EDITOR_BASIC);
     ioContext = QList<int>() << uid()->uniqueIdentifier(Core::Constants::C_EDITOR_IO);
     tableContext = QList<int>() << uid()->uniqueIdentifier(Core::Constants::C_EDITOR_TABLE);
+    textAdderContext = QList<int>() << uid()->uniqueIdentifier(Core::Constants::C_EDITOR_ADDTEXT);
     allContexts = QList<int>() << basicContext << ioContext << tableContext;
 }
 
@@ -158,26 +164,35 @@ void EditorActionHandler::createMenus()
     // Menu structure -- rootMenu is menubar if exists otherwise it is a specific editor's menu Core::Constants::M_EDITOR
     Core::ActionContainer *rootMenu;
 
-    if ((actionManager()->actionContainer(Core::Constants::MENUBAR)) && (!actionManager()->actionContainer(Core::Constants::M_EDITOR))) {
-        rootMenu = m_ContextualMenu;//actionManager()->createMenu(Core::Constants::M_EDITOR);
-        rootMenu->appendGroup(Core::Constants::G_EDIT);
-        m_EditMenu = actionManager()->createMenu(Core::Constants::M_EDITOR_EDIT);
-        m_EditMenu->setTranslations(Trans::Constants::M_EDIT_TEXT);
-        rootMenu->addMenu(m_EditMenu, Core::Constants::G_EDIT);
-        m_EditMenu->appendGroup(Core::Constants::G_EDIT_UNDOREDO);
-        m_EditMenu->appendGroup(Core::Constants::G_EDIT_COPYPASTE);
-        m_EditMenu->appendGroup(Core::Constants::G_EDIT_FIND);
-        m_FileMenu = actionManager()->createMenu(Core::Constants::M_EDITOR_FILE);
-        m_FileMenu->appendGroup(Core::Constants::G_FILE_OPEN);
-        m_FileMenu->appendGroup(Core::Constants::G_FILE_SAVE);
-        m_FileMenu->appendGroup(Core::Constants::G_FILE_PRINT);
-        // create edition actions
-    } else {
+//    if ((actionManager()->actionContainer(Core::Constants::MENUBAR)) && (!actionManager()->actionContainer(Core::Constants::M_EDITOR))) {
+////        qWarning() << "using contextual menu";
+//        rootMenu = m_ContextualMenu;//actionManager()->createMenu(Core::Constants::M_EDITOR);
+//        rootMenu->appendGroup(Core::Constants::G_EDIT);
+//        m_EditMenu = actionManager()->createMenu(Core::Constants::M_EDITOR_EDIT);
+//        m_EditMenu->setTranslations(Trans::Constants::M_EDIT_TEXT);
+//        rootMenu->addMenu(m_EditMenu, Core::Constants::G_EDIT);
+//        m_EditMenu->appendGroup(Core::Constants::G_EDIT_UNDOREDO);
+//        m_EditMenu->appendGroup(Core::Constants::G_EDIT_COPYPASTE);
+//        m_EditMenu->appendGroup(Core::Constants::G_EDIT_FIND);
+//        m_EditMenu->appendGroup(Core::Constants::G_EDIT_EDITOR);
+//        m_FileMenu = actionManager()->createMenu(Core::Constants::M_EDITOR_FILE);
+//        m_FileMenu->appendGroup(Core::Constants::G_FILE_OPEN);
+//        m_FileMenu->appendGroup(Core::Constants::G_FILE_SAVE);
+//        m_FileMenu->appendGroup(Core::Constants::G_FILE_PRINT);
+//        // create edition actions
+//    } else {
+//        qWarning() << "using menubar menus";
         rootMenu = actionManager()->actionContainer(Core::Constants::MENUBAR);
         m_EditMenu = actionManager()->actionContainer(Core::Constants::M_EDIT);
         m_FileMenu = actionManager()->actionContainer(Core::Constants::M_FILE);
-        qWarning() << rootMenu << m_EditMenu << m_FileMenu;
-    }
+        if (!m_FileMenu)
+            m_FileMenu = actionManager()->actionContainer(Core::Constants::M_GENERAL);
+        if (!m_EditMenu || !m_FileMenu || !rootMenu) {
+            LOG_ERROR("No menu for texteditor widgets");
+        }
+//        qWarning() << rootMenu << m_EditMenu << m_FileMenu;
+//    }
+
     // Menu Edit --> text formats
     m_FormatMenu = actionManager()->actionContainer(Core::Constants::M_FORMAT);
     if (!m_FormatMenu) {
@@ -218,6 +233,13 @@ void EditorActionHandler::createMenus()
         m_TableMenu->appendGroup(Core::Constants::G_FORMAT_TABLE);
 //        m_TableMenu->setEmptyAction(ActionContainer::EA_Hide);
     }
+
+    m_AddTextMenu = actionManager()->actionContainer(Core::Constants::M_EDITOR_ADDTEXT);
+    if (!m_AddTextMenu) {
+        m_AddTextMenu = actionManager()->createMenu(Core::Constants::M_EDITOR_ADDTEXT);
+        m_EditMenu->addMenu(m_AddTextMenu, Core::Constants::G_EDIT_EDITOR);
+        m_AddTextMenu->setTranslations(Trans::Constants::EDITOR_ADDTEXTMENU_TEXT);
+    }
 }
 
 void EditorActionHandler::createActions()
@@ -272,7 +294,7 @@ void EditorActionHandler::createActions()
     // Font actions
     aBold = createAction(this, "aBold", ICONBOLD, A_FORMAT_BOLD, allContexts, FORMATBOLD_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_BASE, QKeySequence::Bold, true);
     aItalic = createAction(this, "aItalic", ICONITALIC, A_FORMAT_ITALIC, allContexts, FORMATITALIC_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_BASE, QKeySequence::Italic, true);
-    aUnderline = createAction(this, "aUnderline", ICONUNDERLINE, A_FORMAT_UNDERLINE, allContexts, FORMATUNDERLINE_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_BASE, QKeySequence::Italic, true);
+    aUnderline = createAction(this, "aUnderline", ICONUNDERLINE, A_FORMAT_UNDERLINE, allContexts, FORMATUNDERLINE_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_BASE, QKeySequence::Underline, true);
     aStrike = createAction(this, "aStrike", ICONSTRIKE, A_FORMAT_STRIKE, allContexts, FORMATSTRIKE_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_BASE, QKeySequence::UnknownKey, true);
     aFontBigger = createAction(this, "aFontBigger", ICONFONTBIGGER, A_FORMAT_BIGGER, allContexts, FORMATBIGGER_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_SIZE);
     aFontSmaller = createAction(this, "aFontSmaller", ICONFONTSMALLER, A_FORMAT_SMALLER, allContexts, FORMATSMALLER_TEXT, cmd, m_FontMenu, G_FORMAT_FONT_SIZE);
@@ -325,10 +347,15 @@ void EditorActionHandler::createActions()
 ////    connect(aNew, SIGNAL(triggered()), this, SLOT(newFile()));
 
     // File Actions
-    aOpen = createAction(this, "aOpen", Core::Constants::ICONOPEN, A_EDITOR_FILEOPEN, ioContext, EDITOR_FILEOPEN_TEXT, cmd, m_FileMenu, G_FILE_OPEN);
-    aSave = createAction(this, "aSave", ICONSAVE, A_EDITOR_FILESAVE, ioContext, EDITOR_FILESAVE_TEXT, cmd, m_FileMenu, G_FILE_SAVE);
+    aOpen = createAction(this, "aOpen", Core::Constants::ICONOPEN, A_EDITOR_FILEOPEN, ioContext, EDITOR_FILEOPEN_TEXT, cmd, m_FileMenu, G_GENERAL_FILE);
+    aSave = createAction(this, "aSave", ICONSAVE, A_EDITOR_FILESAVE, ioContext, EDITOR_FILESAVE_TEXT, cmd, m_FileMenu, G_GENERAL_FILE);
     actionManager()->command(A_FORMAT_FONTCOLOR)->setAttribute(Core::Command::CA_UpdateText);
 
+    // Text autocompletion
+    aAddDate = createAction(this, "aAddDate", "", A_EDITOR_ADDDATE, textAdderContext, EDITOR_ADDDATE_TEXT, cmd, m_AddTextMenu, Core::Constants::G_DEFAULT_ONE);
+    aAddUserName = createAction(this, "aAddUserName", "", A_EDITOR_ADDUSERNAME, textAdderContext, EDITOR_ADDUSERNAME_TEXT, cmd, m_AddTextMenu, Core::Constants::G_DEFAULT_ONE);
+    aAddPatientName = createAction(this, "aAddPatientName", "", A_EDITOR_ADDPATIENTNAME, textAdderContext, EDITOR_ADDPATIENTNAME_TEXT, cmd, m_AddTextMenu, Core::Constants::G_DEFAULT_ONE);
+
     actionManager()->retranslateMenusAndActions();
 }
 
@@ -363,6 +390,10 @@ void EditorActionHandler::connectActions()
     connect(aSplitCells, SIGNAL(triggered()), this, SLOT(tableSplitCells()));
     connect(aOpen, SIGNAL(triggered()), this, SLOT(fileOpen()));
     connect(aSave, SIGNAL(triggered()), this, SLOT(saveAs()));
+    connect(aAddDate, SIGNAL(triggered()), this, SLOT(addDate()));
+    connect(aAddUserName, SIGNAL(triggered()), this, SLOT(addUserName()));
+    connect(aAddPatientName, SIGNAL(triggered()), this, SLOT(addPatientName()));
+
     connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(clipboardDataChanged()));
 }
 
@@ -413,7 +444,6 @@ void EditorActionHandler::updateActions()
     updateTableActions();
 }
 
-
 void EditorActionHandler::updateColorActions()
 {
     if (m_CurrentEditor) {
@@ -466,7 +496,6 @@ void EditorActionHandler::setCurrentEditor(TextEditor *editor)
     updateColorActions();
 }
 
-
 void EditorActionHandler::currentCharFormatChanged( const QTextCharFormat &format )
 {
     fontChanged( format.font() );
@@ -533,17 +562,45 @@ void EditorActionHandler::fileOpen()
 void EditorActionHandler::saveAs()
 { if (m_CurrentEditor) m_CurrentEditor->saveAs(); }
 
-    void EditorActionHandler::copy()
-{ if (m_CurrentEditor) m_CurrentEditor->textEdit()->copy(); }
-    void EditorActionHandler::cut()
-{ if (m_CurrentEditor) m_CurrentEditor->textEdit()->cut(); }
-    void EditorActionHandler::paste()
-{ if (m_CurrentEditor) m_CurrentEditor->textEdit()->paste(); }
-    void EditorActionHandler::undo()
-{ if (m_CurrentEditor) m_CurrentEditor->textEdit()->undo(); }
+void EditorActionHandler::copy()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->textEdit()->copy();
+        m_CurrentEditor->textEdit()->setFocus();
+    }
+}
 
-    void EditorActionHandler::redo()
-{ if (m_CurrentEditor) m_CurrentEditor->textEdit()->redo(); }
+void EditorActionHandler::cut()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->textEdit()->cut();
+        m_CurrentEditor->textEdit()->setFocus();
+    }
+}
+
+void EditorActionHandler::paste()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->textEdit()->paste();
+        m_CurrentEditor->textEdit()->setFocus();
+    }
+}
+
+void EditorActionHandler::undo()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->textEdit()->undo();
+        m_CurrentEditor->textEdit()->setFocus();
+    }
+}
+
+void EditorActionHandler::redo()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->textEdit()->redo();
+        m_CurrentEditor->textEdit()->setFocus();
+    }
+}
 
 
 void EditorActionHandler::textBold()
@@ -552,6 +609,7 @@ void EditorActionHandler::textBold()
         return;
     QAction *a = qobject_cast<QAction*>(sender());
     m_CurrentEditor->textBold(a->isChecked());
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::textUnderline()
@@ -560,6 +618,7 @@ void EditorActionHandler::textUnderline()
         return;
     QAction *a = qobject_cast<QAction*>(sender());
     m_CurrentEditor->textUnderline(a->isChecked());
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::textItalic()
@@ -568,6 +627,7 @@ void EditorActionHandler::textItalic()
         return;
     QAction *a = qobject_cast<QAction*>(sender());
     m_CurrentEditor->textItalic(a->isChecked());
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::textStrike()
@@ -576,26 +636,30 @@ void EditorActionHandler::textStrike()
         return;
     QAction *a = qobject_cast<QAction*>(sender());
     m_CurrentEditor->textStrike(a->isChecked());
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::fontBigger()
 {
     if (m_CurrentEditor)
         m_CurrentEditor->fontBigger();
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::fontSmaller()
 {
     if (m_CurrentEditor)
         m_CurrentEditor->fontSmaller();
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::textColor()
 {
     if (m_CurrentEditor) {
         m_CurrentEditor->textColor();
-        /** \todo update color in action */
+        /** \todo update color in action */        
     }
+    m_CurrentEditor->textEdit()->setFocus();
 }
 
 void EditorActionHandler::fontFormat()
@@ -607,6 +671,7 @@ void EditorActionHandler::fontFormat()
 void EditorActionHandler::textAlign()
 {
     if (m_CurrentEditor) {
+        bool focus = m_CurrentEditor->textEdit()->hasFocus();
         QAction *a = qobject_cast<QAction*>(sender());
         if ( a == aLeft )
             m_CurrentEditor->textEdit()->setAlignment( Qt::AlignLeft );
@@ -616,6 +681,8 @@ void EditorActionHandler::textAlign()
             m_CurrentEditor->textEdit()->setAlignment( Qt::AlignRight );
         else if ( a == aJustify )
             m_CurrentEditor->textEdit()->setAlignment( Qt::AlignJustify );
+        if (focus)
+            m_CurrentEditor->textEdit()->setFocus();
     }
 }
 
@@ -638,3 +705,23 @@ void EditorActionHandler::tableMergeCells()
 void EditorActionHandler::tableSplitCells()
 { if (m_CurrentEditor) m_CurrentEditor->tableSplitCells (); }
 
+void EditorActionHandler::addDate()
+{
+    if (m_CurrentEditor)
+        m_CurrentEditor->addDate();
+}
+
+void EditorActionHandler::addUserName()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->addUserName();
+    }
+}
+
+void EditorActionHandler::addPatientName()
+{
+    if (m_CurrentEditor) {
+        m_CurrentEditor->addPatientName();
+    }
+}
+
