@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -21,11 +21,11 @@
 /***************************************************************************
  *   This code is inspired of the Qt example : Text Edit                   *
  *   Adaptations to FreeMedForms and improvments by : Eric Maeker, MD      *
- *   eric.maeker@free.fr                                                   *
+ *   eric.maeker@gmail.com                                                   *
  ***************************************************************************/
 
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -44,9 +44,9 @@
 
 /**
  * \file editoractionhandler.h
- * \author Eric MAEKER <eric.maeker@free.fr>
- * \version 0.4.0
- * \date 29 Apr 2010
+ * \author Eric MAEKER <eric.maeker@gmail.com>
+ * \version 0.6.0
+ * \date 22 Sept 2011
 */
 
 
@@ -117,6 +117,10 @@ private Q_SLOTS:
     void tableMergeCells();
     void tableSplitCells();
 
+    void addDate();
+    void addUserName();
+    void addPatientName();
+
 private:
     QAction *aToggleToolBar;
 
@@ -152,6 +156,10 @@ private:
     QAction *aMergeCells;
     QAction *aSplitCells;
 
+    QAction *aAddDate;
+    QAction *aAddUserName;
+    QAction *aAddPatientName;
+
     Core::ActionContainer *m_ContextualMenu;
     Core::ActionContainer *m_FileMenu;
     Core::ActionContainer *m_EditMenu;
@@ -159,8 +167,9 @@ private:
     Core::ActionContainer *m_FontMenu;
     Core::ActionContainer *m_ParagraphMenu;
     Core::ActionContainer *m_TableMenu;
+    Core::ActionContainer *m_AddTextMenu;
 
-    QList<int> basicContext, ioContext, tableContext, allContexts;
+    QList<int> basicContext, ioContext, tableContext, textAdderContext, allContexts;
 
 private:
     void createContexts();
