@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -18,6 +18,12 @@
  *  along with this program (COPYING.FREEMEDFORMS file).                   *
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
+/***************************************************************************
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
+ *   Contributors :                                                        *
+ *       NAME <MAIL@ADRESS>                                                *
+ *       NAME <MAIL@ADRESS>                                                *
+ ***************************************************************************/
 #include "tableeditor.h"
 #include "tabledialog.h"
 #include "tablepropertieswidget.h"
@@ -26,7 +32,7 @@
 #include <QTextCursor>
 #include <QTextTable>
 #include <QTextTableFormat>
-
+#include <QMouseEvent>
 
 #include <QDebug>
 
@@ -45,9 +51,9 @@ void TableEditor::addTable()
     TableDialog dialog(this);
     if ( dialog.exec() == QDialog::Rejected ) return;
 
-    QTextCursor cursor( textEdit()->textCursor() );
+    QTextCursor cursor(textEdit()->textCursor());
 
-    QTextTable *table = cursor.insertTable( dialog.rows(), dialog.cols(), dialog.format() );
+    QTextTable *table = cursor.insertTable(dialog.rows(), dialog.cols(), dialog.format());
 
     // Set Font Header to bold
     if ( dialog.format().headerRowCount() ) {
