@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -18,10 +18,18 @@
  *  along with this program (COPYING.FREEMEDFORMS file).                   *
  *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
+/***************************************************************************
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
+ *   Contributors :                                                        *
+ *       NAME <MAIL@ADRESS>                                                *
+ *       NAME <MAIL@ADRESS>                                                *
+ ***************************************************************************/
 #include "tablepropertieswidget.h"
 #include "ui_tablepropertieswidget.h"
 #include "ui_tablepropertiesdialog.h"
 
+#include <QDebug>
+
 using namespace Editor::Internal;
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -53,6 +61,7 @@ TablePropertiesWidget::~TablePropertiesWidget()
 
 void TablePropertiesWidget::setFormat(const QTextTableFormat &format)
 {
+    m_InitialFormat = format;
     m_ui->borderWidthSpin->setValue(format.border());
     m_ui->borderStyleCombo->setCurrentIndex(format.borderStyle());
     m_ui->cellPaddingSpin->setValue(format.cellPadding());
@@ -68,8 +77,16 @@ void TablePropertiesWidget::setFormat(const QTextTableFormat &format)
         m_ui->topMarginSpin->setValue(format.topMargin());
         m_ui->bottomMarginSpin->setValue(format.bottomMargin());
     }
-    m_ui->borderColorButton->setColor(format.borderBrush().color());
-    m_ui->cellBackgroundColorButton->setColor(format.background().color());
+    if (format.borderBrush().style()==Qt::NoBrush) {
+        m_ui->borderColorButton->setColor(QColor(255,255,255,255));
+    } else {
+        m_ui->borderColorButton->setColor(format.borderBrush().color());
+    }
+    if (format.background().style()==Qt::NoBrush) {
+        m_ui->cellBackgroundColorButton->setColor(QColor(255,255,255,255));
+    } else {
+        m_ui->cellBackgroundColorButton->setColor(format.background().color());
+    }
 }
 
 int TablePropertiesWidget::cellPadding() const
@@ -92,7 +109,7 @@ int TablePropertiesWidget::borderWidth() const
 
 QTextTableFormat TablePropertiesWidget::format() const
 {
-    QTextTableFormat format;
+    QTextTableFormat format = m_InitialFormat;
 
     // Border
     format.setBorder(borderWidth());
