@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -21,11 +21,11 @@
 /***************************************************************************
  *   This code is inspired of the Qt example : Text Edit                   *
  *   Adaptations to FreeMedForms and improvments by : Eric Maeker, MD      *
- *   eric.maeker@free.fr                                                   *
+ *   eric.maeker@gmail.com                                                   *
  ***************************************************************************/
 
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -46,8 +46,11 @@
 #include <coreplugin/actionmanager/actionmanager.h>
 #include <coreplugin/icore.h>
 #include <coreplugin/itheme.h>
+#include <coreplugin/iuser.h>
+#include <coreplugin/ipatient.h>
 #include <coreplugin/uniqueidmanager.h>
 #include <coreplugin/constants_menus.h>
+#include <coreplugin/isettings.h>
 
 // include Qt headers
 #include <QLocale>
@@ -77,6 +80,10 @@ using namespace Editor;
 using namespace Editor::Internal;
 using namespace Trans::ConstantTranslations;
 
+static inline Core::IUser *user() {return Core::ICore::instance()->user();}
+static inline Core::IPatient *patient() {return Core::ICore::instance()->patient();}
+static inline Core::ISettings *settings() {return Core::ICore::instance()->settings();}
+
 namespace Editor {
 namespace Internal {
 
@@ -108,7 +115,7 @@ public:
     {
         textEdit = new QTextEdit(m_Parent);
         //textEdit = new TextEditorHtmlPaster(m_Parent);
-        textEdit->setContextMenuPolicy( Qt::CustomContextMenu );
+        textEdit->setContextMenuPolicy(Qt::CustomContextMenu);
     }
 
     ~TextEditorPrivate()
@@ -120,7 +127,7 @@ public:
     void createToolBar()
     {
         m_ToolBar = new QToolBar(m_Parent);
-#if QT_VERSION < 0x040600
+#if QT_VERSION > 0x040600
         m_ToolBar->setIconSize(QSize(16,16));
 #endif
         m_ToolBar->setFocusPolicy(Qt::ClickFocus);
@@ -205,13 +212,13 @@ public:
     }
 
 
-    void mergeFormatOnWordOrSelection( const QTextCharFormat &format )
+    void mergeFormatOnWordOrSelection(const QTextCharFormat &format)
     {
         QTextCursor cursor = textEdit->textCursor();
-        if ( !cursor.hasSelection() )
-            cursor.select( QTextCursor::WordUnderCursor );
-        cursor.mergeCharFormat( format );
-        textEdit->mergeCurrentCharFormat( format );
+        if (!cursor.hasSelection())
+            cursor.select(QTextCursor::WordUnderCursor);
+        cursor.mergeCharFormat(format);
+        textEdit->mergeCurrentCharFormat(format);
     }           
     
 public:
@@ -236,7 +243,7 @@ TextEditor::TextEditor(QWidget *parent, Types type)
 {
     static int handler = 0;
     handler++;
-    setObjectName( "TextEditor_" + QString::number(handler) );
+    setObjectName("TextEditor_" + QString::number(handler));
 
     // instanciate private part
     d = new TextEditorPrivate(this, type);
@@ -254,13 +261,13 @@ TextEditor::TextEditor(QWidget *parent, Types type)
     toogleToolbar(false);
 
     // create QWidget
-    QVBoxLayout * vb = new QVBoxLayout( this );
-    vb->setObjectName( "TextEditorLayout" );
-    vb->setSpacing( 0 );
-    vb->setMargin( 0 );
+    QVBoxLayout * vb = new QVBoxLayout(this);
+    vb->setObjectName("TextEditorLayout");
+    vb->setSpacing(0);
+    vb->setMargin(0);
 
-    vb->addWidget( d->m_ToolBar );
-    vb->addWidget( d->textEdit );
+    vb->addWidget(d->m_ToolBar);
+    vb->addWidget(d->textEdit);
 }
 
 TextEditor::~TextEditor()
@@ -287,9 +294,12 @@ void TextEditor::setTypes(Types type)
     if (type & TextEditor::WithIO) {
         d->m_Context->addContext(uid->uniqueIdentifier(Core::Constants::C_EDITOR_IO));
     }
+    if (type & TextEditor::WithTextCompleter) {
+        d->m_Context->addContext(uid->uniqueIdentifier(Core::Constants::C_EDITOR_ADDTEXT));
+    }
 }
 
-QMenu* TextEditor::getContextMenu()
+QMenu *TextEditor::getContextMenu()
 {
     QMenu *mc = new QMenu(this);
     Core::ActionManager *am = Core::ICore::instance()->actionManager();
@@ -309,6 +319,25 @@ QMenu* TextEditor::getContextMenu()
         mc->addSeparator();
     }
 
+    if (d->m_Type & WithTextCompleter) {
+        QMenu *m = new QMenu(this);
+        m->setTitle(tkTr(Trans::Constants::EDITOR_ADDTEXTMENU_TEXT));
+        actions << Core::Constants::A_EDITOR_ADDDATE
+                << Core::Constants::A_EDITOR_ADDUSERNAME
+                << Core::Constants::A_EDITOR_ADDPATIENTNAME
+                ;
+        foreach(const QString &a, actions) {
+            cmd = am->command(a);
+            if (cmd)
+                m->addAction(cmd->action());
+        }
+        mc->addMenu(m);
+    }
+    mc->addSeparator();
+    actions.clear();
+
+    actions.clear();
+
     if (d->m_Type & WithIO) {
         QMenu *m = new QMenu(this);
         m->setTitle(tkTr(Trans::Constants::M_FILE_TEXT));
@@ -385,9 +414,13 @@ QMenu* TextEditor::getContextMenu()
     return mc;
 }
 
-void TextEditor::contextMenu( const QPoint &pos )
+void TextEditor::contextMenu(const QPoint &pos)
 {
-    QMenu * p = getContextMenu();
+    if (textEdit()->underMouse()) {
+        QTextCursor c = textEdit()->cursorForPosition(pos);
+        textEdit()->setTextCursor(c);
+    }
+    QMenu *p = getContextMenu();
     p->exec(mapToGlobal(pos));
 }
 
@@ -420,12 +453,21 @@ void TextEditor::fileOpen()
         title = tkTr(Trans::Constants::EDITORMENU_TEXT);
     else
         title = a->text();
-    QString file = QFileDialog::getOpenFileName( this, title,
-                                               QString(), tr( "HTML files (*.htm *.html);;Text files (*.txt);;All Files (*)" ) );
-    if ( file.isEmpty() )
+    QStringList filters;
+    filters << tkTr(Trans::Constants::FILE_FILTER_HTML)
+            << tkTr(Trans::Constants::FILE_FILTER_TXT)
+            << tkTr(Trans::Constants::FILE_FILTER_RTF)
+            << tkTr(Trans::Constants::FILE_FILTER_ALL_FILES);
+    QString selected = tkTr(Trans::Constants::FILE_FILTER_HTML);
+
+    QString file = QFileDialog::getOpenFileName(this, title,
+                                                settings()->path(Core::ISettings::UserDocumentsPath),
+                                                filters.join(";;"),
+                                                &selected);
+    if (file.isEmpty())
         return;
     QString str = Utils::readTextFile(file, Utils::WarnUser, this);
-    if ( Qt::mightBeRichText(str) ) {
+    if (Qt::mightBeRichText(str)) {
         textEdit()->setHtml(str);
     } else {
         textEdit()->setPlainText(str);
@@ -440,13 +482,32 @@ void TextEditor::saveAs()
         title = tkTr(Trans::Constants::EDITORMENU_TEXT);
     else
         title = a->text();
-    QString fileName = QFileDialog::getSaveFileName( this, title,
-                                                     QString(), tr( "HTML-Files (*.htm *.html);;All Files (*)" ) );
-    if ( fileName.isEmpty() )
-        return ;
-    if (Utils::saveStringToFile(Utils::toHtmlAccent(textEdit()->document()->toHtml("UTF-8")),
-                                fileName, Utils::Overwrite, Utils::WarnUser, this ))
-        textEdit()->document()->setModified( false );
+    QStringList filters;
+    filters << tkTr(Trans::Constants::FILE_FILTER_HTML)
+            << tkTr(Trans::Constants::FILE_FILTER_TXT);
+    QString selected = tkTr(Trans::Constants::FILE_FILTER_HTML);
+    QString fileName = QFileDialog::getSaveFileName(this, title,
+                                                    settings()->path(Core::ISettings::UserDocumentsPath),
+                                                    filters.join(";;"),
+                                                    &selected);
+    if (fileName.isEmpty())
+        return;
+    if (selected==tkTr(Trans::Constants::FILE_FILTER_HTML)) {
+        if (Utils::saveStringToFile(Utils::toHtmlAccent(textEdit()->document()->toHtml("UTF-8")),
+                                    fileName, Utils::Overwrite, Utils::WarnUser, this))
+            textEdit()->document()->setModified(false);
+    } else if (selected==tkTr(Trans::Constants::FILE_FILTER_TXT)) {
+        bool yes = Utils::yesNoMessageBox(tr("Save in pure textual format ?"),
+                                          tr("The conversion of the document to a pure textual format will cause "
+                                             "the lost of the paragraph and characters format. Do you really want "
+                                             "to save in pure textual format ?"));
+        if (yes) {
+            if (Utils::saveStringToFile(textEdit()->document()->toPlainText(),
+                                        fileName, Utils::Overwrite, Utils::WarnUser, this))
+                textEdit()->document()->setModified(false);
+        }
+
+    }
 }
 
 //--------------------------------------------------------------------------------------------------------
@@ -466,8 +527,8 @@ void TextEditor::fontFormat()
     // 3. apply, if accepted, font style
     if (ok) {
         QTextCharFormat fmt;
-        fmt.setFont( selectedfont );
-        d->mergeFormatOnWordOrSelection( fmt );
+        fmt.setFont(selectedfont);
+        d->mergeFormatOnWordOrSelection(fmt);
     }
 }
 
@@ -475,69 +536,69 @@ void TextEditor::fontBigger()
 {
     QFont font = textEdit()->textCursor().charFormat().font();
     QTextCharFormat fmt;
-    font.setPointSize( font.pointSize() + 1 );
-    fmt.setFont( font);
-    d->mergeFormatOnWordOrSelection( fmt );
+    font.setPointSize(font.pointSize() + 1);
+    fmt.setFont(font);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
 void TextEditor::fontSmaller()
 {
     QFont font = textEdit()->textCursor().charFormat().font();
     QTextCharFormat fmt;
-    font.setPointSize( font.pointSize() - 1 );
-    fmt.setFont( font);
-    d->mergeFormatOnWordOrSelection( fmt );
+    font.setPointSize(font.pointSize() - 1);
+    fmt.setFont(font);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
-void TextEditor::textBold( bool checked )
+void TextEditor::textBold(bool checked)
 {
     QTextCharFormat fmt;
-    fmt.setFontWeight( checked ? QFont::Bold : QFont::Normal );
-    d->mergeFormatOnWordOrSelection( fmt );
+    fmt.setFontWeight(checked ? QFont::Bold : QFont::Normal);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
-void TextEditor::textUnderline( bool checked )
+void TextEditor::textUnderline(bool checked)
 {
     QTextCharFormat fmt;
-    fmt.setFontUnderline( checked );
-    d->mergeFormatOnWordOrSelection( fmt );
+    fmt.setFontUnderline(checked);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
-void TextEditor::textItalic( bool checked )
+void TextEditor::textItalic(bool checked)
 {
     QTextCharFormat fmt;
-    fmt.setFontItalic( checked );
-    d->mergeFormatOnWordOrSelection( fmt );
+    fmt.setFontItalic(checked);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
-void TextEditor::textStrike( bool checked )
+void TextEditor::textStrike(bool checked)
 {
     QTextCharFormat fmt;
-    fmt.setFontStrikeOut( checked );
-    d->mergeFormatOnWordOrSelection( fmt );
+    fmt.setFontStrikeOut(checked);
+    d->mergeFormatOnWordOrSelection(fmt);
 }
 
-//void TextEditor::textFamily( const QString &f )
+//void TextEditor::textFamily(const QString &f)
 //{
 //    QTextCharFormat fmt;
-//    fmt.setFontFamily( f );
-//    mergeFormatOnWordOrSelection( fmt );
+//    fmt.setFontFamily(f);
+//    mergeFormatOnWordOrSelection(fmt);
 //}
 //
-//void TextEditor::textSize( const QString &p )
+//void TextEditor::textSize(const QString &p)
 //{
 //    QTextCharFormat fmt;
-//    fmt.setFontPointSize( p.toFloat() );
-//    mergeFormatOnWordOrSelection( fmt );
+//    fmt.setFontPointSize(p.toFloat());
+//    mergeFormatOnWordOrSelection(fmt);
 //}
 //
-//void TextEditor::textStyle( int styleIndex )
+//void TextEditor::textStyle(int styleIndex)
 //{
 //    QTextCursor cursor = textEdit->textCursor();
 //
-//    if ( styleIndex != 0 )  {
+//    if (styleIndex != 0)  {
 //        QTextListFormat::Style style = QTextListFormat::ListDisc;
-//        switch ( styleIndex )
+//        switch (styleIndex)
 //        {
 //               default:
 //               case 1:
@@ -566,45 +627,60 @@ void TextEditor::textStrike( bool checked )
 //
 //        QTextListFormat listFmt;
 //
-//        if ( cursor.currentList() ) {
+//        if (cursor.currentList()) {
 //            listFmt = cursor.currentList()->format();
 //        } else {
-//            listFmt.setIndent( blockFmt.indent() + 1 );
-//            blockFmt.setIndent( 0 );
-//            cursor.setBlockFormat( blockFmt );
+//            listFmt.setIndent(blockFmt.indent() + 1);
+//            blockFmt.setIndent(0);
+//            cursor.setBlockFormat(blockFmt);
 //        }
-//        listFmt.setStyle( style );
-//        cursor.createList( listFmt );
+//        listFmt.setStyle(style);
+//        cursor.createList(listFmt);
 //        cursor.endEditBlock();
 //    } else {
 //        // ####
 //        QTextBlockFormat bfmt;
-//        bfmt.setObjectIndex( -1 );
-//        cursor.mergeBlockFormat( bfmt );
+//        bfmt.setObjectIndex(-1);
+//        cursor.mergeBlockFormat(bfmt);
 //    }
 //}
 
 void TextEditor::textColor()
 {
-    QColor col = QColorDialog::getColor( textEdit()->textColor(), this );
-    if ( !col.isValid() )
+    QColor col = QColorDialog::getColor(textEdit()->textColor(), this);
+    if (!col.isValid())
         return;
     QTextCharFormat fmt;
-    fmt.setForeground( col );
-    d->mergeFormatOnWordOrSelection( fmt );
+    fmt.setForeground(col);
+    d->mergeFormatOnWordOrSelection(fmt);
+}
+
+void TextEditor::addDate()
+{
+    textEdit()->insertHtml(QDateTime::currentDateTime().toString(QLocale().dateTimeFormat(QLocale::LongFormat)));
+}
+
+void TextEditor::addUserName()
+{
+    textEdit()->insertHtml(user()->value(Core::IUser::FullName).toString());
+}
+
+void TextEditor::addPatientName()
+{
+    textEdit()->insertHtml(patient()->data(Core::IPatient::FullName).toString());
 }
 
 //void TextEditorPrivate::about()
 //{
-//    QMessageBox::about( m_Parent, tkTr(ABOUT_TEXT),
-//                        tr( "This rich text editor is part of FreeMedForms Project. " ) );
+//    QMessageBox::about(m_Parent, tkTr(ABOUT_TEXT),
+//                        tr("This rich text editor is part of FreeMedForms Project. "));
 //}
 
 
-//void TextEditorPrivate::colorChanged( const QColor &c )
+//void TextEditorPrivate::colorChanged(const QColor &c)
 //{
-//    QPixmap pix( 16, 16 );
-//    pix.fill( c );
-////    actionTextColor->setIcon( pix );
+//    QPixmap pix(16, 16);
+//    pix.fill(c);
+////    actionTextColor->setIcon(pix);
 //}
 
