@@ -1,7 +1,7 @@
 /***************************************************************************
  *  The FreeMedForms project is a set of free, open source medical         *
  *  applications.                                                          *
- *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  (C) 2008-2011 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
  *  All rights reserved.                                                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -21,11 +21,11 @@
 /***************************************************************************
  *   This code is inspired of the Qt example : Text Edit                   *
  *   Adaptations to FreeMedForms and improvments by : Eric Maeker, MD      *
- *   eric.maeker@free.fr                                                   *
+ *   eric.maeker@gmail.com                                                   *
  ***************************************************************************/
 
 /***************************************************************************
- *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
+ *   Main Developper : Eric MAEKER, <eric.maeker@gmail.com>                *
  *   Contributors :                                                        *
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
@@ -43,7 +43,7 @@ class QMenu;
 
 /**
  * \file texteditor.h
- * \author Eric MAEKER <eric.maeker@free.fr>
+ * \author Eric MAEKER <eric.maeker@gmail.com>
  * \version 0.2.1
  * \date 25 Oct 2009
 */
@@ -65,12 +65,13 @@ class EDITOR_EXPORT TextEditor : public TableEditor
 public:
     enum Type
     {
-        Simple     = 0x01,
-        WithTables = 0x02,
-        WithIO     = 0x04,
-        Full       = Simple | WithTables | WithIO
+        Simple            = 0x01,
+        WithTables        = 0x02,
+        WithIO            = 0x04,
+        WithTextCompleter = 0x08,
+        Full       = Simple | WithTables | WithIO | WithTextCompleter
     };
-    Q_DECLARE_FLAGS(Types, Type);
+    Q_DECLARE_FLAGS(Types, Type)
 
     TextEditor(QWidget *parent = 0, Types type = Simple);
     ~TextEditor();
@@ -105,10 +106,14 @@ protected Q_SLOTS:
     void textColor();
     void fontFormat();
 
+    void addDate();
+    void addUserName();
+    void addPatientName();
+
     virtual void contextMenu(const QPoint &pos);
 
 protected:
-    virtual QMenu* getContextMenu();
+    virtual QMenu *getContextMenu();
     virtual bool toolbarIsVisible() const;
     virtual void hideToolbar();
 
