@@ -63,22 +63,33 @@ doc \
 freediams \
 global_resources/databases/drugs/master.db \
 global_resources/doc/freediams \
-global_resources/textfiles/freediams.desktop \
-global_resources/pixmap \
 global_resources/package_helpers/freediams* \
 global_resources/package_helpers/freemedforms.url \
-global_resources/profiles \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
+global_resources/textfiles/freediams.desktop \
 global_resources/textfiles/boys_surnames.csv \
 global_resources/textfiles/default_user_footer.htm \
 global_resources/textfiles/default_user_header.htm \
 global_resources/textfiles/girls_surnames.csv \
 global_resources/textfiles/listemotsfr.txt \
 global_resources/textfiles/surnames.txt \
-global_resources/textfiles/pays.txt \
-global_resources/textfiles/zipcodes.csv \
 global_resources/translations/*.ts \
 global_resources/translations/qt*.qm \
-libs \
+libs/aggregation \
+libs/extensionsystem \
+libs/translationutils \
+libs/utils \
+libs/medintuxutils \
+libs/medicalutils \
+libs/*.pri \
 contrib \
 plugins/fmf_plugins.pri \
 plugins/coreplugin \
@@ -103,14 +114,28 @@ global_resources/doc/freeicd \
 global_resources/textfiles/freeicd.desktop \
 global_resources/textfiles/default_user_header.htm \
 global_resources/textfiles/default_user_footer.htm \
-global_resources/pixmap \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
 global_resources/package_helpers/freeicd* \
 global_resources/package_helpers/freemedforms.url \
 global_resources/translations/*.ts \
 global_resources/translations/qt*.qm \
 global_resources/databases/icd10/icd10.db \
 global_resources/sql/icd10/icd10.sql \
-libs \
+libs/aggregation \
+libs/extensionsystem \
+libs/translationutils \
+libs/utils \
+libs/medintuxutils \
+libs/medicalutils \
+libs/*.pri \
 contrib \
 plugins/fmf_plugins.pri \
 plugins/coreplugin \
@@ -129,7 +154,15 @@ doc \
 freepad \
 global_resources/doc/freepad \
 global_resources/textfiles/freepad.desktop \
-global_resources/pixmap \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
 global_resources/package_helpers/freepad* \
 global_resources/package_helpers/freemedforms.url \
 global_resources/translations/*.ts \
@@ -162,7 +195,15 @@ freetoolbox/plugins/zipcodes \
 freetoolbox/plugins/*.pro \
 global_resources/doc/freetoolbox \
 global_resources/textfiles/freetoolbox.desktop \
-global_resources/pixmap \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
 global_resources/package_helpers/freetool* \
 global_resources/package_helpers/freemedforms.url \
 global_resources/translations/*.ts \
@@ -186,7 +227,15 @@ freeaccount \
 global_resources/databases/zipcodes/zipcodes.db \
 global_resources/doc/freeaccount \
 global_resources/textfiles/freeaccount.desktop \
-global_resources/pixmap \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
 global_resources/package_helpers/freeaccount* \
 global_resources/package_helpers/freemedforms.url \
 global_resources/profiles \
@@ -198,10 +247,15 @@ global_resources/textfiles/girls_surnames.csv \
 global_resources/textfiles/listemotsfr.txt \
 global_resources/textfiles/surnames.txt \
 global_resources/textfiles/pays.txt \
-global_resources/textfiles/zipcodes.csv \
 global_resources/translations/*.ts \
 global_resources/translations/qt*.qm \
-libs \
+libs/aggregation \
+libs/extensionsystem \
+libs/translationutils \
+libs/utils \
+libs/medintuxutils \
+libs/medicalutils \
+libs/*.pri \
 contrib \
 plugins/fmf_plugins.pri \
 plugins/coreplugin \
@@ -227,7 +281,16 @@ global_resources/databases/zipcodes/zipcodes.db \
 global_resources/doc/freemedforms \
 global_resources/forms \
 global_resources/package_helpers \
-global_resources/pixmap \
+global_resources/pixmap/16x16 \
+global_resources/pixmap/32x32 \
+global_resources/pixmap/48x48 \
+global_resources/pixmap/64x64 \
+global_resources/pixmap/splashscreens \
+global_resources/pixmap/svg/*.svg \
+global_resources/pixmap/svg/*.icns \
+global_resources/pixmap/svg/*.ico \
+global_resources/pixmap/svg/*.bmp \
+global_resources/pixmap/svg/*.bmp \
 global_resources/profiles \
 global_resources/sql/account \
 global_resources/sql/server_config \
@@ -301,6 +364,14 @@ fi
 }
 
 
+# $1 bundle name
+# $2 app version
+# $3 svn version
+changeVersionNumbering()
+{
+  # modify package helpers: .ISS windows files
+  echo "Not yet coded"
+}
 
 createSource()
 {
@@ -331,6 +402,12 @@ echo "**** UNPACK SOURCES PACKAGE TO CREATED DIR ****"
 tar xf $PACKPATH/sources.tar -C $PACKPATH
 rm $PACKPATH/sources.tar
 find $PACKPATH -type f -exec chmod -R 666 {} \;
+
+echo "   * DEFINING *.ISS FILES APP VERSION"
+cd $PACKPATH/global_resources/package_helpers
+sed -i "bkup" 's#__version__#'$APP_VERSION'#' $1.iss
+rm *.*bkup
+
 echo "   * ADDING SVN VERSION NUMBER"
 cd $PACKPATH/buildspecs
 SVN=`svn info -r HEAD $SCRIPT_PATH"/.." | grep 'Changed\ Rev' | cut -b 19-`
@@ -357,6 +434,7 @@ echo "SVN version: "$SVN
 # $2: fromSVNVersion
 createBranch()
 {
+  echo "Create SVN branch not yet coded"
   # Manage Branch name
   SVN_FROM=""
   BRANCH_NAME=$1"_"$APP_VERSION
@@ -365,18 +443,46 @@ createBranch()
      SVN_FROM="-r "$SVN_REVISION
   fi
 
-  # create branch
+  # go to trunk root path
   cd $SCRIPT_PATH/../..
+  # create branch
   if [ ! -e branches/$BRANCH_NAME ] ; then
-    mkdir branches/$BRANCH_NAME
+    echo mkdir branches/$BRANCH_NAME
+    echo svn add branches
     # todo: else clear the branch ??
   fi
   for n in $SELECTED_SOURCES ; do
     echo svn copy $SVN_FROM https://freemedforms.googlecode.com/svn/trunk/$n branches/$BRANCH_NAME/$n
   done
-
 }
 
+# params:
+# $1: bundleName
+# $2: fromSVNVersion
+createTag()
+{
+  echo "Create SVN tag not yet coded"
+  # Manage Branch name
+  SVN_FROM=""
+  BRANCH_NAME=$1"_"$APP_VERSION
+  if [ ! -e $SVN_REVISION ] ; then
+     BRANCH_NAME=$BRANCH_NAME"-"$SVN_REVISION
+     SVN_FROM="-r "$SVN_REVISION
+  fi
+
+  # go to trunk root path
+  cd $SCRIPT_PATH/../..
+  # create branch
+  if [ ! -e tags/$BRANCH_NAME ] ; then
+    echo mkdir tags
+    echo svn add tags
+    echo mkdir tags/$BRANCH_NAME
+    # todo: else clear the branch ??
+  fi
+  for n in $SELECTED_SOURCES ; do
+    echo svn copy $SVN_FROM https://freemedforms.googlecode.com/svn/trunk/$n tags/$BRANCH_NAME/$n
+  done
+}
 
 #########################################################################################
 ## Analyse options
@@ -396,7 +502,7 @@ do
     ;;
     c) createBranch $BUNDLE_NAME
     ;;
-    t) createTag
+    t) createTag $BUNDLE_NAME
   esac
 done
 
